(self.rspackChunkcalendar=self.rspackChunkcalendar||[]).push([["defaultVendors-node_modules_nextcloud_vue_dist_assets_NcDateTimePickerNative-BP6eg8aU_css-nod-ea584e"],{8025(t,e,r){"use strict";r.r(e);var n=r(71354),i=r.n(n),a=r(76314),o=r.n(a)()(i());o.push([t.id,`/**
 * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/**
 * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/*
* Ensure proper alignment of the vue material icons
*/
.material-design-icon[data-v-43230e98] {
  display: flex;
  align-self: center;
  justify-self: center;
  align-items: center;
  justify-content: center;
}

/**
 * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/* Default global values */
button[data-v-43230e98]:not(.button-vue),
input[data-v-43230e98]:not([type=range]),
textarea[data-v-43230e98] {
  margin: 0;
  padding: 7px 6px;
  cursor: text;
  color: var(--color-main-text);
  border: 1px solid var(--color-border-dark);
  border-radius: var(--border-radius-element);
  outline: none;
  background-color: var(--color-main-background);
  font-size: 13px;
}
button[data-v-43230e98]:not(.button-vue):not(:disabled):not(.primary):hover, button[data-v-43230e98]:not(.button-vue):not(:disabled):not(.primary):focus, button:not(.button-vue):not(:disabled):not(.primary).active[data-v-43230e98],
input[data-v-43230e98]:not([type=range]):not(:disabled):not(.primary):hover,
input[data-v-43230e98]:not([type=range]):not(:disabled):not(.primary):focus,
input:not([type=range]):not(:disabled):not(.primary).active[data-v-43230e98],
textarea[data-v-43230e98]:not(:disabled):not(.primary):hover,
textarea[data-v-43230e98]:not(:disabled):not(.primary):focus,
textarea:not(:disabled):not(.primary).active[data-v-43230e98] {
  /* active class used for multiselect */
  border-color: var(--color-primary-element);
  outline: none;
}
button[data-v-43230e98]:not(.button-vue):not(:disabled):not(.primary):active,
input[data-v-43230e98]:not([type=range]):not(:disabled):not(.primary):active,
textarea[data-v-43230e98]:not(:disabled):not(.primary):active {
  color: var(--color-main-text);
  outline: none;
  background-color: var(--color-main-background);
}
button[data-v-43230e98]:not(.button-vue):disabled,
input[data-v-43230e98]:not([type=range]):disabled,
textarea[data-v-43230e98]:disabled {
  cursor: default;
  opacity: 0.5;
  color: var(--color-text-maxcontrast);
  background-color: var(--color-background-dark);
}
button[data-v-43230e98]:not(.button-vue):required,
input[data-v-43230e98]:not([type=range]):required,
textarea[data-v-43230e98]:required {
  box-shadow: none;
}
button[data-v-43230e98]:not(.button-vue):invalid,
input[data-v-43230e98]:not([type=range]):invalid,
textarea[data-v-43230e98]:invalid {
  border-color: var(--color-border-error, var(--color-error));
  box-shadow: none !important;
}
button[data-v-43230e98]:not(.button-vue),
input[data-v-43230e98]:not([type=range]),
textarea[data-v-43230e98] {
  /* Primary action button, use sparingly */
}
button:not(.button-vue).primary[data-v-43230e98],
input:not([type=range]).primary[data-v-43230e98],
textarea.primary[data-v-43230e98] {
  cursor: pointer;
  color: var(--color-primary-element-text);
  border-color: var(--color-primary-element);
  background-color: var(--color-primary-element);
}
button:not(.button-vue).primary[data-v-43230e98]:not(:disabled):hover, button:not(.button-vue).primary[data-v-43230e98]:not(:disabled):focus, button:not(.button-vue).primary[data-v-43230e98]:not(:disabled):active,
input:not([type=range]).primary[data-v-43230e98]:not(:disabled):hover,
input:not([type=range]).primary[data-v-43230e98]:not(:disabled):focus,
input:not([type=range]).primary[data-v-43230e98]:not(:disabled):active,
textarea.primary[data-v-43230e98]:not(:disabled):hover,
textarea.primary[data-v-43230e98]:not(:disabled):focus,
textarea.primary[data-v-43230e98]:not(:disabled):active {
  border-color: var(--color-primary-element-light);
  background-color: var(--color-primary-element-light);
}
button:not(.button-vue).primary[data-v-43230e98]:not(:disabled):active,
input:not([type=range]).primary[data-v-43230e98]:not(:disabled):active,
textarea.primary[data-v-43230e98]:not(:disabled):active {
  color: var(--color-primary-element-text-dark);
}
button:not(.button-vue).primary[data-v-43230e98]:disabled,
input:not([type=range]).primary[data-v-43230e98]:disabled,
textarea.primary[data-v-43230e98]:disabled {
  cursor: default;
  color: var(--color-primary-element-text-dark);
  background-color: var(--color-primary-element);
}

/**
 * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
li.action[data-v-43230e98]:hover, li.action.active[data-v-43230e98] {
  border-radius: 6px;
  padding: 0;
}
li.action[data-v-43230e98]:hover {
  background-color: var(--color-background-hover);
}
.action--disabled[data-v-43230e98] {
  pointer-events: none;
  opacity: 0.5;
}
.action--disabled[data-v-43230e98]:hover, .action--disabled[data-v-43230e98]:focus {
  cursor: default;
  opacity: 0.5;
}
.action--disabled[data-v-43230e98] * {
  opacity: 1 !important;
}
.action-input[data-v-43230e98] {
  display: flex;
  align-items: flex-start;
  width: 100%;
  height: auto;
  margin: 0;
  padding: 0;
  cursor: pointer;
  white-space: nowrap;
  color: var(--color-main-text);
  border: 0;
  border-radius: 0;
  background-color: transparent;
  box-shadow: none;
  font-weight: var(--font-weight-default, normal);
}
.action-input__icon-wrapper[data-v-43230e98] {
  display: flex;
  align-self: center;
  align-items: center;
  justify-content: center;
}
.action-input__icon-wrapper[data-v-43230e98] .material-design-icon {
  width: var(--default-clickable-area);
  height: var(--default-clickable-area);
  opacity: 1;
}
.action-input__icon-wrapper[data-v-43230e98] .material-design-icon .material-design-icon__svg {
  vertical-align: middle;
}
.action-input > span[data-v-43230e98] {
  cursor: pointer;
  white-space: nowrap;
}
.action-input__icon[data-v-43230e98] {
  min-width: 0; /* Overwrite icons*/
  min-height: 0;
  padding: calc(var(--default-clickable-area) / 2) 0 calc(var(--default-clickable-area) / 2) var(--default-clickable-area);
  background-position: calc((var(--default-clickable-area) - 16px) / 2) center;
  background-size: 16px;
}
.action-input__form[data-v-43230e98] {
  display: flex;
  align-items: center;
  flex: 1 1 auto;
  margin: 4px 0;
  padding-inline-end: calc((var(--default-clickable-area) - 16px) / 2);
}
.action-input__container[data-v-43230e98] {
  position: relative;
  width: 100%;
}
.action-input__input-container[data-v-43230e98] {
  display: flex;
}
.action-input__input-container .colorpicker__trigger[data-v-43230e98], .action-input__input-container .colorpicker__preview[data-v-43230e98] {
  width: 100%;
}
.action-input__input-container .colorpicker__preview[data-v-43230e98] {
  width: 100%;
  height: 36px;
  border-radius: var(--border-radius-element);
  border: 2px solid var(--color-border-maxcontrast);
  box-shadow: none !important;
}
.action-input__text-label[data-v-43230e98] {
  padding: 4px 0;
  display: block;
}
.action-input__text-label--hidden[data-v-43230e98] {
  position: absolute;
  inset-inline-start: 0;
  width: 1px;
  height: 1px;
  overflow: hidden;
  z-index: -1;
  opacity: 0;
}
.action-input__datetimepicker[data-v-43230e98] {
  width: 100%;
}
.action-input__datetimepicker[data-v-43230e98] .mx-input {
  margin: 0;
}
.action-input__multi[data-v-43230e98] {
  width: 100%;
}
li:last-child > .action-input[data-v-43230e98] {
  padding-bottom: calc((var(--default-clickable-area) - 16px) / 2 - 4px);
}
li:first-child > .action-input[data-v-43230e98]:not(.action-input--visible-label) {
  padding-top: calc((var(--default-clickable-area) - 16px) / 2 - 4px);
}`,"",{version:3,sources:["webpack://./node_modules/@nextcloud/vue/dist/assets/NcActionInput-t9WvlgV0.css"],names:[],mappings:"AAAA;;;EAGE;AACF;;;EAGE;AACF;;CAEC;AACD;EACE,aAAa;EACb,kBAAkB;EAClB,oBAAoB;EACpB,mBAAmB;EACnB,uBAAuB;AACzB;;AAEA;;;EAGE;AACF,0BAA0B;AAC1B;;;EAGE,SAAS;EACT,gBAAgB;EAChB,YAAY;EACZ,6BAA6B;EAC7B,0CAA0C;EAC1C,2CAA2C;EAC3C,aAAa;EACb,8CAA8C;EAC9C,eAAe;AACjB;AACA;;;;;;;EAOE,sCAAsC;EACtC,0CAA0C;EAC1C,aAAa;AACf;AACA;;;EAGE,6BAA6B;EAC7B,aAAa;EACb,8CAA8C;AAChD;AACA;;;EAGE,eAAe;EACf,YAAY;EACZ,oCAAoC;EACpC,8CAA8C;AAChD;AACA;;;EAGE,gBAAgB;AAClB;AACA;;;EAGE,2DAA2D;EAC3D,2BAA2B;AAC7B;AACA;;;EAGE,yCAAyC;AAC3C;AACA;;;EAGE,eAAe;EACf,wCAAwC;EACxC,0CAA0C;EAC1C,8CAA8C;AAChD;AACA;;;;;;;EAOE,gDAAgD;EAChD,oDAAoD;AACtD;AACA;;;EAGE,6CAA6C;AAC/C;AACA;;;EAGE,eAAe;EACf,6CAA6C;EAC7C,8CAA8C;AAChD;;AAEA;;;EAGE;AACF;EACE,kBAAkB;EAClB,UAAU;AACZ;AACA;EACE,+CAA+C;AACjD;AACA;EACE,oBAAoB;EACpB,YAAY;AACd;AACA;EACE,eAAe;EACf,YAAY;AACd;AACA;EACE,qBAAqB;AACvB;AACA;EACE,aAAa;EACb,uBAAuB;EACvB,WAAW;EACX,YAAY;EACZ,SAAS;EACT,UAAU;EACV,eAAe;EACf,mBAAmB;EACnB,6BAA6B;EAC7B,SAAS;EACT,gBAAgB;EAChB,6BAA6B;EAC7B,gBAAgB;EAChB,+CAA+C;AACjD;AACA;EACE,aAAa;EACb,kBAAkB;EAClB,mBAAmB;EACnB,uBAAuB;AACzB;AACA;EACE,oCAAoC;EACpC,qCAAqC;EACrC,UAAU;AACZ;AACA;EACE,sBAAsB;AACxB;AACA;EACE,eAAe;EACf,mBAAmB;AACrB;AACA;EACE,YAAY,EAAE,mBAAmB;EACjC,aAAa;EACb,wHAAwH;EACxH,4EAA4E;EAC5E,qBAAqB;AACvB;AACA;EACE,aAAa;EACb,mBAAmB;EACnB,cAAc;EACd,aAAa;EACb,oEAAoE;AACtE;AACA;EACE,kBAAkB;EAClB,WAAW;AACb;AACA;EACE,aAAa;AACf;AACA;EACE,WAAW;AACb;AACA;EACE,WAAW;EACX,YAAY;EACZ,2CAA2C;EAC3C,iDAAiD;EACjD,2BAA2B;AAC7B;AACA;EACE,cAAc;EACd,cAAc;AAChB;AACA;EACE,kBAAkB;EAClB,qBAAqB;EACrB,UAAU;EACV,WAAW;EACX,gBAAgB;EAChB,WAAW;EACX,UAAU;AACZ;AACA;EACE,WAAW;AACb;AACA;EACE,SAAS;AACX;AACA;EACE,WAAW;AACb;AACA;EACE,sEAAsE;AACxE;AACA;EACE,mEAAmE;AACrE",sourcesContent:["/**\n * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/**\n * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/*\n* Ensure proper alignment of the vue material icons\n*/\n.material-design-icon[data-v-43230e98] {\n  display: flex;\n  align-self: center;\n  justify-self: center;\n  align-items: center;\n  justify-content: center;\n}\n\n/**\n * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/* Default global values */\nbutton[data-v-43230e98]:not(.button-vue),\ninput[data-v-43230e98]:not([type=range]),\ntextarea[data-v-43230e98] {\n  margin: 0;\n  padding: 7px 6px;\n  cursor: text;\n  color: var(--color-main-text);\n  border: 1px solid var(--color-border-dark);\n  border-radius: var(--border-radius-element);\n  outline: none;\n  background-color: var(--color-main-background);\n  font-size: 13px;\n}\nbutton[data-v-43230e98]:not(.button-vue):not(:disabled):not(.primary):hover, button[data-v-43230e98]:not(.button-vue):not(:disabled):not(.primary):focus, button:not(.button-vue):not(:disabled):not(.primary).active[data-v-43230e98],\ninput[data-v-43230e98]:not([type=range]):not(:disabled):not(.primary):hover,\ninput[data-v-43230e98]:not([type=range]):not(:disabled):not(.primary):focus,\ninput:not([type=range]):not(:disabled):not(.primary).active[data-v-43230e98],\ntextarea[data-v-43230e98]:not(:disabled):not(.primary):hover,\ntextarea[data-v-43230e98]:not(:disabled):not(.primary):focus,\ntextarea:not(:disabled):not(.primary).active[data-v-43230e98] {\n  /* active class used for multiselect */\n  border-color: var(--color-primary-element);\n  outline: none;\n}\nbutton[data-v-43230e98]:not(.button-vue):not(:disabled):not(.primary):active,\ninput[data-v-43230e98]:not([type=range]):not(:disabled):not(.primary):active,\ntextarea[data-v-43230e98]:not(:disabled):not(.primary):active {\n  color: var(--color-main-text);\n  outline: none;\n  background-color: var(--color-main-background);\n}\nbutton[data-v-43230e98]:not(.button-vue):disabled,\ninput[data-v-43230e98]:not([type=range]):disabled,\ntextarea[data-v-43230e98]:disabled {\n  cursor: default;\n  opacity: 0.5;\n  color: var(--color-text-maxcontrast);\n  background-color: var(--color-background-dark);\n}\nbutton[data-v-43230e98]:not(.button-vue):required,\ninput[data-v-43230e98]:not([type=range]):required,\ntextarea[data-v-43230e98]:required {\n  box-shadow: none;\n}\nbutton[data-v-43230e98]:not(.button-vue):invalid,\ninput[data-v-43230e98]:not([type=range]):invalid,\ntextarea[data-v-43230e98]:invalid {\n  border-color: var(--color-border-error, var(--color-error));\n  box-shadow: none !important;\n}\nbutton[data-v-43230e98]:not(.button-vue),\ninput[data-v-43230e98]:not([type=range]),\ntextarea[data-v-43230e98] {\n  /* Primary action button, use sparingly */\n}\nbutton:not(.button-vue).primary[data-v-43230e98],\ninput:not([type=range]).primary[data-v-43230e98],\ntextarea.primary[data-v-43230e98] {\n  cursor: pointer;\n  color: var(--color-primary-element-text);\n  border-color: var(--color-primary-element);\n  background-color: var(--color-primary-element);\n}\nbutton:not(.button-vue).primary[data-v-43230e98]:not(:disabled):hover, button:not(.button-vue).primary[data-v-43230e98]:not(:disabled):focus, button:not(.button-vue).primary[data-v-43230e98]:not(:disabled):active,\ninput:not([type=range]).primary[data-v-43230e98]:not(:disabled):hover,\ninput:not([type=range]).primary[data-v-43230e98]:not(:disabled):focus,\ninput:not([type=range]).primary[data-v-43230e98]:not(:disabled):active,\ntextarea.primary[data-v-43230e98]:not(:disabled):hover,\ntextarea.primary[data-v-43230e98]:not(:disabled):focus,\ntextarea.primary[data-v-43230e98]:not(:disabled):active {\n  border-color: var(--color-primary-element-light);\n  background-color: var(--color-primary-element-light);\n}\nbutton:not(.button-vue).primary[data-v-43230e98]:not(:disabled):active,\ninput:not([type=range]).primary[data-v-43230e98]:not(:disabled):active,\ntextarea.primary[data-v-43230e98]:not(:disabled):active {\n  color: var(--color-primary-element-text-dark);\n}\nbutton:not(.button-vue).primary[data-v-43230e98]:disabled,\ninput:not([type=range]).primary[data-v-43230e98]:disabled,\ntextarea.primary[data-v-43230e98]:disabled {\n  cursor: default;\n  color: var(--color-primary-element-text-dark);\n  background-color: var(--color-primary-element);\n}\n\n/**\n * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\nli.action[data-v-43230e98]:hover, li.action.active[data-v-43230e98] {\n  border-radius: 6px;\n  padding: 0;\n}\nli.action[data-v-43230e98]:hover {\n  background-color: var(--color-background-hover);\n}\n.action--disabled[data-v-43230e98] {\n  pointer-events: none;\n  opacity: 0.5;\n}\n.action--disabled[data-v-43230e98]:hover, .action--disabled[data-v-43230e98]:focus {\n  cursor: default;\n  opacity: 0.5;\n}\n.action--disabled[data-v-43230e98] * {\n  opacity: 1 !important;\n}\n.action-input[data-v-43230e98] {\n  display: flex;\n  align-items: flex-start;\n  width: 100%;\n  height: auto;\n  margin: 0;\n  padding: 0;\n  cursor: pointer;\n  white-space: nowrap;\n  color: var(--color-main-text);\n  border: 0;\n  border-radius: 0;\n  background-color: transparent;\n  box-shadow: none;\n  font-weight: var(--font-weight-default, normal);\n}\n.action-input__icon-wrapper[data-v-43230e98] {\n  display: flex;\n  align-self: center;\n  align-items: center;\n  justify-content: center;\n}\n.action-input__icon-wrapper[data-v-43230e98] .material-design-icon {\n  width: var(--default-clickable-area);\n  height: var(--default-clickable-area);\n  opacity: 1;\n}\n.action-input__icon-wrapper[data-v-43230e98] .material-design-icon .material-design-icon__svg {\n  vertical-align: middle;\n}\n.action-input > span[data-v-43230e98] {\n  cursor: pointer;\n  white-space: nowrap;\n}\n.action-input__icon[data-v-43230e98] {\n  min-width: 0; /* Overwrite icons*/\n  min-height: 0;\n  padding: calc(var(--default-clickable-area) / 2) 0 calc(var(--default-clickable-area) / 2) var(--default-clickable-area);\n  background-position: calc((var(--default-clickable-area) - 16px) / 2) center;\n  background-size: 16px;\n}\n.action-input__form[data-v-43230e98] {\n  display: flex;\n  align-items: center;\n  flex: 1 1 auto;\n  margin: 4px 0;\n  padding-inline-end: calc((var(--default-clickable-area) - 16px) / 2);\n}\n.action-input__container[data-v-43230e98] {\n  position: relative;\n  width: 100%;\n}\n.action-input__input-container[data-v-43230e98] {\n  display: flex;\n}\n.action-input__input-container .colorpicker__trigger[data-v-43230e98], .action-input__input-container .colorpicker__preview[data-v-43230e98] {\n  width: 100%;\n}\n.action-input__input-container .colorpicker__preview[data-v-43230e98] {\n  width: 100%;\n  height: 36px;\n  border-radius: var(--border-radius-element);\n  border: 2px solid var(--color-border-maxcontrast);\n  box-shadow: none !important;\n}\n.action-input__text-label[data-v-43230e98] {\n  padding: 4px 0;\n  display: block;\n}\n.action-input__text-label--hidden[data-v-43230e98] {\n  position: absolute;\n  inset-inline-start: 0;\n  width: 1px;\n  height: 1px;\n  overflow: hidden;\n  z-index: -1;\n  opacity: 0;\n}\n.action-input__datetimepicker[data-v-43230e98] {\n  width: 100%;\n}\n.action-input__datetimepicker[data-v-43230e98] .mx-input {\n  margin: 0;\n}\n.action-input__multi[data-v-43230e98] {\n  width: 100%;\n}\nli:last-child > .action-input[data-v-43230e98] {\n  padding-bottom: calc((var(--default-clickable-area) - 16px) / 2 - 4px);\n}\nli:first-child > .action-input[data-v-43230e98]:not(.action-input--visible-label) {\n  padding-top: calc((var(--default-clickable-area) - 16px) / 2 - 4px);\n}"],sourceRoot:""}]),r.d(e,{},{default:o})},1406(t,e,r){"use strict";r.r(e);var n=r(71354),i=r.n(n),a=r(76314),o=r.n(a)()(i());o.push([t.id,`/**
 * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/**
 * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/*
* Ensure proper alignment of the vue material icons
*/
.material-design-icon[data-v-7cec4a3e] {
  display: flex;
  align-self: center;
  justify-self: center;
  align-items: center;
  justify-content: center;
}
.vue-crumb[data-v-7cec4a3e] {
  background-image: none;
  display: inline-flex;
  height: var(--default-clickable-area);
  padding: 0;
}
.vue-crumb[data-v-7cec4a3e]:last-child {
  min-width: 0;
}
.vue-crumb:last-child .vue-crumb__separator[data-v-7cec4a3e] {
  display: none;
}
.vue-crumb--hidden[data-v-7cec4a3e] {
  display: none;
}
.vue-crumb__separator[data-v-7cec4a3e] {
  padding: 0;
  color: var(--color-text-maxcontrast);
}
.vue-crumb.vue-crumb--hovered[data-v-7cec4a3e] .button-vue {
  background-color: var(--color-background-dark);
  color: var(--color-main-text);
}
.vue-crumb[data-v-7cec4a3e]:not(:last-child)  .button-vue {
  color: var(--color-text-maxcontrast);
}
.vue-crumb[data-v-7cec4a3e]:not(:last-child)  .button-vue:hover, .vue-crumb[data-v-7cec4a3e]:not(:last-child)  .button-vue:focus {
  background-color: var(--color-background-dark);
  color: var(--color-main-text);
}
.vue-crumb[data-v-7cec4a3e]:not(:last-child)  .button-vue__text {
  font-weight: var(--font-weight-element, normal);
}
.vue-crumb[data-v-7cec4a3e] .button-vue__text {
  margin: 0;
}
.vue-crumb[data-v-7cec4a3e]:not(.dropdown) .action-item {
  max-width: 100%;
}
.vue-crumb[data-v-7cec4a3e]:not(.dropdown) .action-item .button-vue {
  padding: 0 4px 0 16px;
  max-width: 100%;
}
.vue-crumb[data-v-7cec4a3e]:not(.dropdown) .action-item .button-vue__wrapper {
  flex-direction: row-reverse;
}
.vue-crumb[data-v-7cec4a3e]:not(.dropdown) .action-item.action-item--open .action-item__menutoggle {
  background-color: var(--color-background-dark);
  color: var(--color-main-text);
}`,"",{version:3,sources:["webpack://./node_modules/@nextcloud/vue/dist/assets/NcBreadcrumb-BxhZKQlW.css"],names:[],mappings:"AAAA;;;EAGE;AACF;;;EAGE;AACF;;CAEC;AACD;EACE,aAAa;EACb,kBAAkB;EAClB,oBAAoB;EACpB,mBAAmB;EACnB,uBAAuB;AACzB;AACA;EACE,sBAAsB;EACtB,oBAAoB;EACpB,qCAAqC;EACrC,UAAU;AACZ;AACA;EACE,YAAY;AACd;AACA;EACE,aAAa;AACf;AACA;EACE,aAAa;AACf;AACA;EACE,UAAU;EACV,oCAAoC;AACtC;AACA;EACE,8CAA8C;EAC9C,6BAA6B;AAC/B;AACA;EACE,oCAAoC;AACtC;AACA;EACE,8CAA8C;EAC9C,6BAA6B;AAC/B;AACA;EACE,+CAA+C;AACjD;AACA;EACE,SAAS;AACX;AACA;EACE,eAAe;AACjB;AACA;EACE,qBAAqB;EACrB,eAAe;AACjB;AACA;EACE,2BAA2B;AAC7B;AACA;EACE,8CAA8C;EAC9C,6BAA6B;AAC/B",sourcesContent:["/**\n * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/**\n * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/*\n* Ensure proper alignment of the vue material icons\n*/\n.material-design-icon[data-v-7cec4a3e] {\n  display: flex;\n  align-self: center;\n  justify-self: center;\n  align-items: center;\n  justify-content: center;\n}\n.vue-crumb[data-v-7cec4a3e] {\n  background-image: none;\n  display: inline-flex;\n  height: var(--default-clickable-area);\n  padding: 0;\n}\n.vue-crumb[data-v-7cec4a3e]:last-child {\n  min-width: 0;\n}\n.vue-crumb:last-child .vue-crumb__separator[data-v-7cec4a3e] {\n  display: none;\n}\n.vue-crumb--hidden[data-v-7cec4a3e] {\n  display: none;\n}\n.vue-crumb__separator[data-v-7cec4a3e] {\n  padding: 0;\n  color: var(--color-text-maxcontrast);\n}\n.vue-crumb.vue-crumb--hovered[data-v-7cec4a3e] .button-vue {\n  background-color: var(--color-background-dark);\n  color: var(--color-main-text);\n}\n.vue-crumb[data-v-7cec4a3e]:not(:last-child)  .button-vue {\n  color: var(--color-text-maxcontrast);\n}\n.vue-crumb[data-v-7cec4a3e]:not(:last-child)  .button-vue:hover, .vue-crumb[data-v-7cec4a3e]:not(:last-child)  .button-vue:focus {\n  background-color: var(--color-background-dark);\n  color: var(--color-main-text);\n}\n.vue-crumb[data-v-7cec4a3e]:not(:last-child)  .button-vue__text {\n  font-weight: var(--font-weight-element, normal);\n}\n.vue-crumb[data-v-7cec4a3e] .button-vue__text {\n  margin: 0;\n}\n.vue-crumb[data-v-7cec4a3e]:not(.dropdown) .action-item {\n  max-width: 100%;\n}\n.vue-crumb[data-v-7cec4a3e]:not(.dropdown) .action-item .button-vue {\n  padding: 0 4px 0 16px;\n  max-width: 100%;\n}\n.vue-crumb[data-v-7cec4a3e]:not(.dropdown) .action-item .button-vue__wrapper {\n  flex-direction: row-reverse;\n}\n.vue-crumb[data-v-7cec4a3e]:not(.dropdown) .action-item.action-item--open .action-item__menutoggle {\n  background-color: var(--color-background-dark);\n  color: var(--color-main-text);\n}"],sourceRoot:""}]),r.d(e,{},{default:o})},90737(t,e,r){"use strict";r.r(e);var n=r(71354),i=r.n(n),a=r(76314),o=r.n(a)()(i());o.push([t.id,`/**
 * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/**
 * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/*
* Ensure proper alignment of the vue material icons
*/
.material-design-icon[data-v-0015282c] {
  display: flex;
  align-self: center;
  justify-self: center;
  align-items: center;
  justify-content: center;
}
.breadcrumb[data-v-0015282c] {
  width: 100%;
  flex-grow: 1;
  display: inline-flex;
  align-items: center;
}
.breadcrumb--collapsed[data-v-0015282c] .vue-crumb:last-child {
  min-width: 100px;
}
.breadcrumb nav[data-v-0015282c] {
  flex-shrink: 1;
  min-width: 0;
}
.breadcrumb .breadcrumb__crumbs[data-v-0015282c] {
  max-width: 100%;
}
.breadcrumb .breadcrumb__crumbs[data-v-0015282c], .breadcrumb .breadcrumb__actions[data-v-0015282c] {
  display: inline-flex;
}`,"",{version:3,sources:["webpack://./node_modules/@nextcloud/vue/dist/assets/NcBreadcrumbs-5gl8Syfa.css"],names:[],mappings:"AAAA;;;EAGE;AACF;;;EAGE;AACF;;CAEC;AACD;EACE,aAAa;EACb,kBAAkB;EAClB,oBAAoB;EACpB,mBAAmB;EACnB,uBAAuB;AACzB;AACA;EACE,WAAW;EACX,YAAY;EACZ,oBAAoB;EACpB,mBAAmB;AACrB;AACA;EACE,gBAAgB;AAClB;AACA;EACE,cAAc;EACd,YAAY;AACd;AACA;EACE,eAAe;AACjB;AACA;EACE,oBAAoB;AACtB",sourcesContent:["/**\n * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/**\n * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/*\n* Ensure proper alignment of the vue material icons\n*/\n.material-design-icon[data-v-0015282c] {\n  display: flex;\n  align-self: center;\n  justify-self: center;\n  align-items: center;\n  justify-content: center;\n}\n.breadcrumb[data-v-0015282c] {\n  width: 100%;\n  flex-grow: 1;\n  display: inline-flex;\n  align-items: center;\n}\n.breadcrumb--collapsed[data-v-0015282c] .vue-crumb:last-child {\n  min-width: 100px;\n}\n.breadcrumb nav[data-v-0015282c] {\n  flex-shrink: 1;\n  min-width: 0;\n}\n.breadcrumb .breadcrumb__crumbs[data-v-0015282c] {\n  max-width: 100%;\n}\n.breadcrumb .breadcrumb__crumbs[data-v-0015282c], .breadcrumb .breadcrumb__actions[data-v-0015282c] {\n  display: inline-flex;\n}"],sourceRoot:""}]),r.d(e,{},{default:o})},6462(t,e,r){"use strict";r.r(e);var n=r(71354),i=r.n(n),a=r(76314),o=r.n(a)()(i());o.push([t.id,`/**
 * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/**
 * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/*
* Ensure proper alignment of the vue material icons
*/
.material-design-icon[data-v-b97e1f7a] {
  display: flex;
  align-self: center;
  justify-self: center;
  align-items: center;
  justify-content: center;
}
.native-datetime-picker[data-v-b97e1f7a] {
  display: flex;
  flex-direction: column;
}
.native-datetime-picker .native-datetime-picker__label[data-v-b97e1f7a] {
  margin-block-end: 2px;
}
.native-datetime-picker .native-datetime-picker__input[data-v-b97e1f7a] {
  --input-border-width-offset: calc(var(--border-width-input-focused, 2px) - var(--border-width-input, 2px));
  width: 100%;
  flex: 0 0 auto;
  margin: 0;
  padding-inline-start: calc(var(--border-radius-element) + var(--input-border-width-offset));
  padding-inline-end: calc(var(--default-grid-baseline) + var(--input-border-width-offset));
  border: var(--border-width-input, 2px) solid var(--color-border-maxcontrast);
}
.native-datetime-picker .native-datetime-picker__input[data-v-b97e1f7a]:active:not([disabled]), .native-datetime-picker .native-datetime-picker__input[data-v-b97e1f7a]:hover:not([disabled]), .native-datetime-picker .native-datetime-picker__input[data-v-b97e1f7a]:focus:not([disabled]), .native-datetime-picker .native-datetime-picker__input[data-v-b97e1f7a]:focus-within:not([disabled]) {
  border-color: var(--color-main-text);
  border-width: var(--border-width-input-focused, 2px);
  box-shadow: 0 0 0 2px var(--color-main-background) !important;
  --input-border-width-offset: 0px;
}
[data-theme-light] .native-datetime-picker__input[data-v-b97e1f7a],
[data-themes*=light] .native-datetime-picker__input[data-v-b97e1f7a] {
  color-scheme: light;
}
[data-theme-dark] .native-datetime-picker__input[data-v-b97e1f7a],
[data-themes*=dark] .native-datetime-picker__input[data-v-b97e1f7a] {
  color-scheme: dark;
}
@media (prefers-color-scheme: light) {
[data-theme-default] .native-datetime-picker__input[data-v-b97e1f7a],
  [data-themes*=default] .native-datetime-picker__input[data-v-b97e1f7a] {
    color-scheme: light;
}
}
@media (prefers-color-scheme: dark) {
[data-theme-default] .native-datetime-picker__input[data-v-b97e1f7a],
  [data-themes*=default] .native-datetime-picker__input[data-v-b97e1f7a] {
    color-scheme: dark;
}
}`,"",{version:3,sources:["webpack://./node_modules/@nextcloud/vue/dist/assets/NcDateTimePickerNative-BP6eg8aU.css"],names:[],mappings:"AAAA;;;EAGE;AACF;;;EAGE;AACF;;CAEC;AACD;EACE,aAAa;EACb,kBAAkB;EAClB,oBAAoB;EACpB,mBAAmB;EACnB,uBAAuB;AACzB;AACA;EACE,aAAa;EACb,sBAAsB;AACxB;AACA;EACE,qBAAqB;AACvB;AACA;EACE,0GAA0G;EAC1G,WAAW;EACX,cAAc;EACd,SAAS;EACT,2FAA2F;EAC3F,yFAAyF;EACzF,4EAA4E;AAC9E;AACA;EACE,oCAAoC;EACpC,oDAAoD;EACpD,6DAA6D;EAC7D,gCAAgC;AAClC;AACA;;EAEE,mBAAmB;AACrB;AACA;;EAEE,kBAAkB;AACpB;AACA;AACA;;IAEI,mBAAmB;AACvB;AACA;AACA;AACA;;IAEI,kBAAkB;AACtB;AACA",sourcesContent:["/**\n * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/**\n * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/*\n* Ensure proper alignment of the vue material icons\n*/\n.material-design-icon[data-v-b97e1f7a] {\n  display: flex;\n  align-self: center;\n  justify-self: center;\n  align-items: center;\n  justify-content: center;\n}\n.native-datetime-picker[data-v-b97e1f7a] {\n  display: flex;\n  flex-direction: column;\n}\n.native-datetime-picker .native-datetime-picker__label[data-v-b97e1f7a] {\n  margin-block-end: 2px;\n}\n.native-datetime-picker .native-datetime-picker__input[data-v-b97e1f7a] {\n  --input-border-width-offset: calc(var(--border-width-input-focused, 2px) - var(--border-width-input, 2px));\n  width: 100%;\n  flex: 0 0 auto;\n  margin: 0;\n  padding-inline-start: calc(var(--border-radius-element) + var(--input-border-width-offset));\n  padding-inline-end: calc(var(--default-grid-baseline) + var(--input-border-width-offset));\n  border: var(--border-width-input, 2px) solid var(--color-border-maxcontrast);\n}\n.native-datetime-picker .native-datetime-picker__input[data-v-b97e1f7a]:active:not([disabled]), .native-datetime-picker .native-datetime-picker__input[data-v-b97e1f7a]:hover:not([disabled]), .native-datetime-picker .native-datetime-picker__input[data-v-b97e1f7a]:focus:not([disabled]), .native-datetime-picker .native-datetime-picker__input[data-v-b97e1f7a]:focus-within:not([disabled]) {\n  border-color: var(--color-main-text);\n  border-width: var(--border-width-input-focused, 2px);\n  box-shadow: 0 0 0 2px var(--color-main-background) !important;\n  --input-border-width-offset: 0px;\n}\n[data-theme-light] .native-datetime-picker__input[data-v-b97e1f7a],\n[data-themes*=light] .native-datetime-picker__input[data-v-b97e1f7a] {\n  color-scheme: light;\n}\n[data-theme-dark] .native-datetime-picker__input[data-v-b97e1f7a],\n[data-themes*=dark] .native-datetime-picker__input[data-v-b97e1f7a] {\n  color-scheme: dark;\n}\n@media (prefers-color-scheme: light) {\n[data-theme-default] .native-datetime-picker__input[data-v-b97e1f7a],\n  [data-themes*=default] .native-datetime-picker__input[data-v-b97e1f7a] {\n    color-scheme: light;\n}\n}\n@media (prefers-color-scheme: dark) {\n[data-theme-default] .native-datetime-picker__input[data-v-b97e1f7a],\n  [data-themes*=default] .native-datetime-picker__input[data-v-b97e1f7a] {\n    color-scheme: dark;\n}\n}"],sourceRoot:""}]),r.d(e,{},{default:o})},85696(t,e,r){"use strict";r.r(e);var n=r(71354),i=r.n(n),a=r(76314),o=r.n(a)()(i());o.push([t.id,`/**
 * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/**
 * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */
/*
* Ensure proper alignment of the vue material icons
*/
.material-design-icon[data-v-cb828737] {
  display: flex;
  align-self: center;
  justify-self: center;
  align-items: center;
  justify-content: center;
}
[data-v-cb828737] .password-field__input--secure-text {
  -webkit-text-security: disc;
}`,"",{version:3,sources:["webpack://./node_modules/@nextcloud/vue/dist/assets/NcPasswordField-BN4HFgU5.css"],names:[],mappings:"AAAA;;;EAGE;AACF;;;EAGE;AACF;;CAEC;AACD;EACE,aAAa;EACb,kBAAkB;EAClB,oBAAoB;EACpB,mBAAmB;EACnB,uBAAuB;AACzB;AACA;EACE,2BAA2B;AAC7B",sourcesContent:["/**\n * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/**\n * SPDX-FileCopyrightText: 2021 Nextcloud GmbH and Nextcloud contributors\n * SPDX-License-Identifier: AGPL-3.0-or-later\n */\n/*\n* Ensure proper alignment of the vue material icons\n*/\n.material-design-icon[data-v-cb828737] {\n  display: flex;\n  align-self: center;\n  justify-self: center;\n  align-items: center;\n  justify-content: center;\n}\n[data-v-cb828737] .password-field__input--secure-text {\n  -webkit-text-security: disc;\n}"],sourceRoot:""}]),r.d(e,{},{default:o})},56088(t,e,r){var n=r(8025);n.__esModule&&(n=n.default),"string"==typeof n&&(n=[[t.id,n,""]]),n.locals&&(t.exports=n.locals),(0,r(15739).A)("206ad110",n,!0,{})},79885(t,e,r){var n=r(1406);n.__esModule&&(n=n.default),"string"==typeof n&&(n=[[t.id,n,""]]),n.locals&&(t.exports=n.locals),(0,r(15739).A)("5e003e26",n,!0,{})},3380(t,e,r){var n=r(90737);n.__esModule&&(n=n.default),"string"==typeof n&&(n=[[t.id,n,""]]),n.locals&&(t.exports=n.locals),(0,r(15739).A)("37a41ab8",n,!0,{})},29461(t,e,r){var n=r(6462);n.__esModule&&(n=n.default),"string"==typeof n&&(n=[[t.id,n,""]]),n.locals&&(t.exports=n.locals),(0,r(15739).A)("35614784",n,!0,{})},71253(t,e,r){var n=r(85696);n.__esModule&&(n=n.default),"string"==typeof n&&(n=[[t.id,n,""]]),n.locals&&(t.exports=n.locals),(0,r(15739).A)("7da22150",n,!0,{})},39771(t,e,r){"use strict";r(56088);var n=r(20641),i=r(90033),a=r(53751),o=r(22436),s=r(26308),l=r(34163),u=r(3639),c=r(64535),h=r(51420),d=r(52697);(0,o.r)(o.l);let p={name:"NcActionInput",components:{NcDateTimePickerNative:u.N,NcPasswordField:c.N,NcTextField:h._,NcColorPicker:(0,n.$V)(()=>Promise.all([r.e("defaultVendors-node_modules_nextcloud_vue_dist_chunks_NcColorPicker-CGE4Kei4_mjs"),r.e("node_modules_nextcloud_vue_dist_components_NcColorPicker_index_mjs")]).then(r.bind(r,71415))),NcDateTimePicker:(0,n.$V)(()=>Promise.all([r.e("defaultVendors-node_modules_nextcloud_vue_dist_chunks_NcDateTimePicker-CK4rhfEB_mjs"),r.e("node_modules_nextcloud_vue_dist_components_NcDateTimePicker_index_mjs")]).then(r.bind(r,30427))),NcSelect:(0,n.$V)(()=>r.e("node_modules_nextcloud_vue_dist_components_NcSelect_index_mjs").then(r.bind(r,3710)))},mixins:[s.A],inheritAttrs:!1,props:{id:{type:String,default:()=>"action-"+(0,l.c)(),validator:t=>""!==t.trim()},inputId:{type:String,default:()=>"action-input-"+(0,l.c)(),validator:t=>""!==t.trim()},icon:{type:String,default:""},type:{type:String,default:"text",validator:t=>["date","datetime-local","month","multiselect","number","password","search","tel","text","time","url","week","color","email"].includes(t)},idNativeDateTimePicker:{type:String,default:"date-time-picker_id"},isNativePicker:{type:Boolean,default:!1},label:{type:String,default:null},labelOutside:{type:Boolean,default:!0},modelValue:{type:[String,Date,Number,Array],default:""},disabled:{type:Boolean,default:!1},ariaLabel:{type:String,default:""},showTrailingButton:{type:Boolean,default:!0},trailingButtonLabel:{type:String,default:(0,o.a)("Submit")},class:{type:[String,Array,Object],default:""}},emits:["submit","update:modelValue"],computed:{isIconUrl(){try{return new URL(this.icon)}catch{return!1}},isMultiselectType(){return"multiselect"===this.type},nativeDatePickerType(){switch(this.type){case"date":case"month":case"time":case"week":case"datetime-local":return this.type}return!1},datePickerType(){if(!this.isNativePicker)switch(this.type){case"date":case"month":case"time":return this.type;case"datetime-local":return"datetime"}return!1},isFocusable(){return!this.disabled}},methods:{onLeave(){this.$refs.datetimepicker&&this.$refs.datetimepicker.$refs.datepicker&&this.$refs.datetimepicker.$refs.datepicker.closePopup()},onSubmit(t){if(t.preventDefault(),t.stopPropagation(),this.disabled)return!1;this.$emit("submit",t)},onUpdateModelValue(t){this.$emit("update:modelValue",t)}}},f={class:"action-input__icon-wrapper"},g=["disabled"],m={class:"action-input__container"},v=["for"],b={class:"action-input__input-container"},A={key:4,class:"action-input__container"},y=["for"],x={class:"action-input__input-container"},C=(0,d._)(p,[["render",function(t,e,r,o,s,l){let u=(0,n.g2)("NcDateTimePicker"),c=(0,n.g2)("NcDateTimePickerNative"),h=(0,n.g2)("NcSelect"),d=(0,n.g2)("NcPasswordField"),p=(0,n.g2)("NcColorPicker"),C=(0,n.g2)("NcTextField");return(0,n.uX)(),(0,n.CE)("li",{class:(0,i.normalizeClass)(["action",[{"action--disabled":r.disabled},t.$props.class]])},[(0,n.Lk)("span",{class:(0,i.normalizeClass)(["action-input",{"action-input-picker--disabled":r.disabled,"action-input--visible-label":r.labelOutside&&r.label}]),onMouseleave:e[3]||(e[3]=(...t)=>l.onLeave&&l.onLeave(...t))},[(0,n.Lk)("span",f,[(0,n.RG)(t.$slots,"icon",{},()=>[(0,n.Lk)("span",{"aria-hidden":"true",class:(0,i.normalizeClass)(["action-input__icon",[l.isIconUrl?"action-input__icon--url":r.icon]]),style:(0,i.normalizeStyle)({backgroundImage:l.isIconUrl?`url(${r.icon})`:null})},null,6)],!0)]),(0,n.Lk)("form",{ref:"form",class:"action-input__form",disabled:r.disabled,onSubmit:e[2]||(e[2]=(0,a.withModifiers)((...t)=>l.onSubmit&&l.onSubmit(...t),["prevent"]))},[(0,n.Lk)("div",m,[r.label&&r.labelOutside&&!r.isNativePicker?((0,n.uX)(),(0,n.CE)("label",{key:0,class:(0,i.normalizeClass)(["action-input__text-label",{"action-input__text-label--hidden":!r.labelOutside}]),for:r.inputId},(0,i.toDisplayString)(r.label),11,v)):(0,n.Q3)("",!0),(0,n.Lk)("div",b,[l.datePickerType?((0,n.uX)(),(0,n.Wv)(u,(0,n.v6)({key:0,ref:"datetimepicker",modelValue:r.modelValue,style:{"z-index":"99999999999"},placeholder:t.text,disabled:r.disabled,type:l.datePickerType,inputClass:["mx-input",{focusable:l.isFocusable}],class:"action-input__datetimepicker",appendToBody:""},t.$attrs,{"onUpdate:modelValue":l.onUpdateModelValue}),null,16,["modelValue","placeholder","disabled","type","inputClass","onUpdate:modelValue"])):r.isNativePicker?((0,n.uX)(),(0,n.Wv)(c,(0,n.v6)({key:1,id:r.idNativeDateTimePicker,modelValue:r.modelValue,label:r.label,type:l.nativeDatePickerType,inputClass:{focusable:l.isFocusable},class:"action-input__datetimepicker"},t.$attrs,{"onUpdate:modelValue":l.onUpdateModelValue}),null,16,["id","modelValue","label","type","inputClass","onUpdate:modelValue"])):l.isMultiselectType?((0,n.uX)(),(0,n.Wv)(h,(0,n.v6)({key:2,modelValue:r.modelValue,placeholder:t.text,disabled:r.disabled,appendToBody:!1,inputClass:{focusable:l.isFocusable},class:"action-input__multi"},t.$attrs,{"onUpdate:modelValue":l.onUpdateModelValue}),null,16,["modelValue","placeholder","disabled","inputClass","onUpdate:modelValue"])):"password"===r.type?((0,n.uX)(),(0,n.Wv)(d,(0,n.v6)({key:3,id:r.inputId,modelValue:r.modelValue,label:r.label,labelOutside:!r.label||r.labelOutside,placeholder:t.text,disabled:r.disabled,inputClass:{focusable:l.isFocusable},showTrailingButton:r.showTrailingButton&&!r.disabled},t.$attrs,{"onUpdate:modelValue":l.onUpdateModelValue}),null,16,["id","modelValue","label","labelOutside","placeholder","disabled","inputClass","showTrailingButton","onUpdate:modelValue"])):"color"===r.type?((0,n.uX)(),(0,n.CE)("div",A,[r.label&&"color"===r.type?((0,n.uX)(),(0,n.CE)("label",{key:0,class:(0,i.normalizeClass)(["action-input__text-label",{"action-input__text-label--hidden":!r.labelOutside}]),for:r.inputId},(0,i.toDisplayString)(r.label),11,y)):(0,n.Q3)("",!0),(0,n.Lk)("div",x,[(0,n.bF)(p,(0,n.v6)({id:"inputId",modelValue:r.modelValue,class:"colorpicker__trigger"},t.$attrs,{"onUpdate:modelValue":l.onUpdateModelValue,onSubmit:e[0]||(e[0]=e=>t.$refs.form.requestSubmit())}),{default:(0,n.k6)(()=>[(0,n.Lk)("button",{class:(0,i.normalizeClass)(["colorpicker__preview",{focusable:l.isFocusable}]),style:(0,i.normalizeStyle)({"background-color":r.modelValue})},null,6)]),_:1},16,["modelValue","onUpdate:modelValue"])])])):((0,n.uX)(),(0,n.Wv)(C,(0,n.v6)({key:5,id:r.inputId,modelValue:r.modelValue,label:r.label,labelOutside:!r.label||r.labelOutside,placeholder:t.text,disabled:r.disabled,inputClass:{focusable:l.isFocusable},type:r.type,trailingButtonIcon:"arrowRight",trailingButtonLabel:r.trailingButtonLabel,showTrailingButton:r.showTrailingButton&&!r.disabled},t.$attrs,{onTrailingButtonClick:e[1]||(e[1]=e=>t.$refs.form.requestSubmit()),"onUpdate:modelValue":l.onUpdateModelValue}),null,16,["id","modelValue","label","labelOutside","placeholder","disabled","inputClass","type","trailingButtonLabel","showTrailingButton","onUpdate:modelValue"]))])])],40,g)],34)],2)}],["__scopeId","data-v-43230e98"]]);r.d(e,{},{N:C})},66139(t,e,r){"use strict";r(79885);var n=r(20641),i=r(90033),a=r(53751),o=r(52697),s=r(42221),l=r(34163),u=r(65048);let c=["aria-hidden","aria-label"],h=["fill","width","height"],d={d:"M8.59,16.58L13.17,12L8.59,7.41L10,6L16,12L10,18L8.59,16.58Z"},p={key:0},f=(0,o._)({name:"ChevronRightIcon",emits:["click"],props:{title:{type:String},fillColor:{type:String,default:"currentColor"},size:{type:Number,default:24}}},[["render",function(t,e,r,a,o,s){return(0,n.uX)(),(0,n.CE)("span",(0,n.v6)(t.$attrs,{"aria-hidden":r.title?null:"true","aria-label":r.title,class:"material-design-icon chevron-right-icon",role:"img",onClick:e[0]||(e[0]=e=>t.$emit("click",e))}),[((0,n.uX)(),(0,n.CE)("svg",{fill:r.fillColor,class:"material-design-icon__svg",width:r.size,height:r.size,viewBox:"0 0 24 24"},[(0,n.Lk)("path",d,[r.title?((0,n.uX)(),(0,n.CE)("title",p,(0,i.toDisplayString)(r.title),1)):(0,n.Q3)("",!0)])],8,h))],16,c)}]]),g={name:"NcBreadcrumb",components:{NcActions:u.N,ChevronRight:f,NcButton:s.N},inheritAttrs:!1,props:{name:{type:String,required:!0},title:{type:String,default:null},to:{type:[String,Object],default:void 0},href:{type:String,default:void 0},icon:{type:String,default:""},forceIconText:{type:Boolean,default:!1},disableDrop:{type:Boolean,default:!1},forceMenu:{type:Boolean,default:!1},open:{type:Boolean,default:!1},class:{type:[String,Array,Object],default:""}},emits:["dragenter","dragleave","dropped","update:open"],setup(){let t=(0,l.c)();return{actionsContainer:`.vue-crumb[data-crumb-id="${t}"]`,crumbId:t}},data:()=>({hovering:!1}),computed:{linkAttributes(){return this.to?{to:this.to,...this.$attrs}:this.href?{href:this.href,...this.$attrs}:this.$attrs}},methods:{onOpenChange(t){this.$emit("update:open",t)},dropped(t){return!this.disableDrop&&(this.$emit("dropped",t,this.to||this.href),this.$parent.$emit("dropped",t,this.to||this.href),this.hovering=!1,!1)},dragEnter(t){this.$emit("dragenter",t),this.disableDrop||(this.hovering=!0)},dragLeave(t){this.$emit("dragleave",t),this.disableDrop||t.target.contains(t.relatedTarget)||this.$refs.crumb.contains(t.relatedTarget)||(this.hovering=!1)}}},m=["data-crumb-id"],v=(0,o._)(g,[["render",function(t,e,r,o,s,l){let u=(0,n.g2)("NcButton"),c=(0,n.g2)("NcActions"),h=(0,n.g2)("ChevronRight");return(0,n.uX)(),(0,n.CE)("li",{ref:"crumb",class:(0,i.normalizeClass)(["vue-crumb",[{"vue-crumb--hovered":s.hovering},t.$props.class]]),"data-crumb-id":o.crumbId,draggable:"false",onDragstart:(0,a.withModifiers)(()=>{},["prevent"]),onDrop:e[0]||(e[0]=(0,a.withModifiers)((...t)=>l.dropped&&l.dropped(...t),["prevent"])),onDragover:(0,a.withModifiers)(()=>{},["prevent"]),onDragenter:e[1]||(e[1]=(...t)=>l.dragEnter&&l.dragEnter(...t)),onDragleave:e[2]||(e[2]=(...t)=>l.dragLeave&&l.dragLeave(...t))},[(r.name||r.icon||t.$slots.icon)&&!t.$slots.default?((0,n.uX)(),(0,n.Wv)(u,(0,n.v6)({key:0,"aria-label":r.icon?r.name:void 0,variant:"tertiary"},l.linkAttributes),(0,n.eX)({_:2},[t.$slots.icon||r.icon?{name:"icon",fn:(0,n.k6)(()=>[(0,n.RG)(t.$slots,"icon",{},()=>[(0,n.Lk)("span",{class:(0,i.normalizeClass)([r.icon,"icon"])},null,2)],!0)]),key:"0"}:void 0,!(t.$slots.icon||r.icon)||r.forceIconText?{name:"default",fn:(0,n.k6)(()=>[(0,n.eW)((0,i.toDisplayString)(r.name),1)]),key:"1"}:void 0]),1040,["aria-label"])):(0,n.Q3)("",!0),t.$slots.default?((0,n.uX)(),(0,n.Wv)(c,{key:1,ref:"actions",container:o.actionsContainer,forceMenu:r.forceMenu,forceName:"",menuName:r.name,open:r.open,title:r.title,variant:"tertiary","onUpdate:open":l.onOpenChange},{icon:(0,n.k6)(()=>[(0,n.RG)(t.$slots,"menu-icon",{},void 0,!0)]),default:(0,n.k6)(()=>[(0,n.RG)(t.$slots,"default",{},void 0,!0)]),_:3},8,["container","forceMenu","menuName","open","title","onUpdate:open"])):(0,n.Q3)("",!0),(0,n.bF)(h,{class:"vue-crumb__separator",size:20})],42,m)}],["__scopeId","data-v-7cec4a3e"]]);r.d(e,{},{N:v})},4055(t,e,r){"use strict";r(3380);var n=r(61338),i=r(46855),a=r(20641),o=r(90033),s=r(52697),l=r(65048),u=r(71096),c=r(56891),h=r(17834),d=r(66139);let p=["aria-hidden","aria-label"],f=["fill","width","height"],g={d:"M10,4H4C2.89,4 2,4.89 2,6V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V8C22,6.89 21.1,6 20,6H12L10,4Z"},m={key:0},v=(0,s._)({name:"FolderIcon",emits:["click"],props:{title:{type:String},fillColor:{type:String,default:"currentColor"},size:{type:Number,default:24}}},[["render",function(t,e,r,n,i,s){return(0,a.uX)(),(0,a.CE)("span",(0,a.v6)(t.$attrs,{"aria-hidden":r.title?null:"true","aria-label":r.title,class:"material-design-icon folder-icon",role:"img",onClick:e[0]||(e[0]=e=>t.$emit("click",e))}),[((0,a.uX)(),(0,a.CE)("svg",{fill:r.fillColor,class:"material-design-icon__svg",width:r.size,height:r.size,viewBox:"0 0 24 24"},[(0,a.Lk)("path",g,[r.title?((0,a.uX)(),(0,a.CE)("title",m,(0,o.toDisplayString)(r.title),1)):(0,a.Q3)("",!0)])],8,f))],16,p)}]]),b="vue-crumb",A={name:"NcBreadcrumbs",components:{NcActions:l.N,NcActionButton:u.N,NcActionRouter:h.N,NcActionLink:c.N,NcBreadcrumb:d.N,IconFolder:v},props:{rootIcon:{type:String,default:"icon-home"},ariaLabel:{type:String,default:null}},emits:["dropped"],data:()=>({hiddenIndices:[],menuBreadcrumbProps:{name:"",forceMenu:!0,disableDrop:!0,open:!1},breadcrumbsRefs:[]}),created(){window.addEventListener("resize",(0,i.A)(()=>{this.handleWindowResize()},100)),(0,n.B1)("navigation-toggled",this.delayedResize)},mounted(){this.handleWindowResize()},updated(){this.delayedResize(),this.$nextTick(()=>{this.hideCrumbs()})},beforeUnmount(){window.removeEventListener("resize",this.handleWindowResize),(0,n.al)("navigation-toggled",this.delayedResize)},methods:{closeActions(t){this.$refs.actionsBreadcrumb.$el.contains(t.relatedTarget)||(this.menuBreadcrumbProps.open=!1)},async delayedResize(){await this.$nextTick(),this.handleWindowResize()},handleWindowResize(){if(!this.$refs.container)return;let t=this.breadcrumbsRefs.length,e=[],r=this.$refs.container.offsetWidth,n=this.getTotalWidth();this.$refs.breadcrumb__actions&&(n+=this.$refs.breadcrumb__actions.offsetWidth);let i=n-r;i+=64*(i>0);let a=0,o=Math.floor(t/2);for(;i>0&&a<t-2;){let r=o+(a%2?a+1:a)/2*Math.pow(-1,a+t%2);i-=this.getWidth(this.breadcrumbsRefs[r]?.$el,r===this.breadcrumbsRefs.length-1),e.push(r),a++}this.arraysEqual(this.hiddenIndices,e.sort((t,e)=>t-e))||(this.hiddenIndices=e)},arraysEqual(t,e){if(t.length!==e.length)return!1;if(t===e)return!0;if(null===t||null===e)return!1;for(let r=0;r<t.length;++r)if(t[r]!==e[r])return!1;return!0},getTotalWidth(){return this.breadcrumbsRefs.reduce((t,e,r)=>t+this.getWidth(e.$el,r===this.breadcrumbsRefs.length-1),0)},getWidth(t,e){if(!t?.classList)return 0;let r=t.classList.contains(`${b}--hidden`);t.style.minWidth="auto",e&&(t.style.maxWidth="210px"),t.classList.remove(`${b}--hidden`);let n=t.offsetWidth;return r&&t.classList.add(`${b}--hidden`),t.style.minWidth="",t.style.maxWidth="",n},preventDefault:t=>(t.preventDefault&&t.preventDefault(),!1),dragStart(t){return this.preventDefault(t)},dropped(t,e,r){for(let n of(r||this.$emit("dropped",t,e),this.menuBreadcrumbProps.open=!1,document.querySelectorAll(`.${b}`)))n.classList.remove(`${b}--hovered`);return this.preventDefault(t)},dragOver(t){return this.preventDefault(t)},dragEnter(t,e){if(!e&&t.target.closest){let e=t.target.closest(`.${b}`);if(e.classList&&e.classList.contains(b)){for(let t of document.querySelectorAll(`.${b}`))t.classList.remove(`${b}--hovered`);e.classList.add(`${b}--hovered`)}}},dragLeave(t,e){if(!e&&!t.target.contains(t.relatedTarget)&&t.target.closest){let e=t.target.closest(`.${b}`);if(!e.contains(t.relatedTarget))e.classList&&e.classList.contains(b)&&e.classList.remove(`${b}--hovered`)}},hideCrumbs(){this.breadcrumbsRefs.forEach((t,e)=>{t?.$el?.classList&&(this.hiddenIndices.includes(e)?t.$el.classList.add(`${b}--hidden`):t.$el.classList.remove(`${b}--hidden`))})},isBreadcrumb:t=>t?.type?.name==="NcBreadcrumb"},render(){let t=[];if(this.$slots.default?.().forEach(e=>{this.isBreadcrumb(e)?t.push(e):e?.type===a.FK&&e?.children?.forEach?.(e=>{this.isBreadcrumb(e)&&t.push(e)})}),0===t.length)return;t[0]=(0,a.E3)(t[0],{icon:this.rootIcon,ref:"breadcrumbs"});let e=[],r=[...t=t.map((t,r)=>(0,a.E3)(t,{ref:t=>{e[r]=t}}))];this.hiddenIndices.length&&r.splice(Math.round(t.length/2),0,(0,a.h)(d.N,{class:"dropdown",...this.menuBreadcrumbProps,"aria-hidden":!0,ref:"actionsBreadcrumb",key:"actions-breadcrumb-1",onDragenter:()=>{this.menuBreadcrumbProps.open=!0},onDragleave:this.closeActions,"onUpdate:open":t=>{this.menuBreadcrumbProps.open=t}},{default:()=>this.hiddenIndices.filter(e=>e<=t.length-1).map(e=>{let{to:r,href:n,disableDrop:i,name:o,...s}=t[e].props;delete s.ref;let l=u.N,d="";n&&(l=c.N,d=n),r&&(l=h.N,d=r);let p=(0,a.h)(v,{size:20});return(0,a.h)(l,{...s,class:b,href:n||null,to:r||null,draggable:!1,onDragstart:this.dragStart,onDrop:t=>this.dropped(t,d,i),onDragover:this.dragOver,onDragenter:t=>this.dragEnter(t,i),onDragleave:t=>this.dragLeave(t,i)},{default:()=>o,icon:()=>p})})}));let n=[(0,a.h)("nav",{"aria-label":this.ariaLabel},[(0,a.h)("ul",{class:"breadcrumb__crumbs"},[r])])];return(0,l.i)(this.$slots.actions?.())&&n.push((0,a.h)("div",{class:"breadcrumb__actions",ref:"breadcrumb__actions"},this.$slots.actions?.())),this.breadcrumbsRefs=e,(0,a.h)("div",{class:["breadcrumb",{"breadcrumb--collapsed":this.hiddenIndices.length===t.length-2}],ref:"container"},n)}},y=(0,s._)(A,[["__scopeId","data-v-0015282c"]]);r.d(e,{},{N:y})},64535(t,e,r){"use strict";r(71253);var n=r(20641),i=r(50953),a=r(98190),o=r(29504),s=r(87485),l=r(63814),u=r(46855),c=r(51012),h=r(26089),d=r(22436),p=r(3168),f=r(52697);(0,d.r)(d.n);let g=(0,n.pM)({__name:"NcPasswordField",props:(0,n.zz)({class:{},inputClass:{default:""},id:{},label:{},labelOutside:{type:Boolean},placeholder:{},showTrailingButton:{type:Boolean,default:!0},success:{type:Boolean},error:{type:Boolean},helperText:{},disabled:{type:Boolean},pill:{type:Boolean},checkPasswordStrength:{type:Boolean},minlength:{default:void 0},asText:{type:Boolean}},{modelValue:{default:""},modelModifiers:{},visible:{type:Boolean,default:!1},visibleModifiers:{}}),emits:(0,n.zz)(["valid","invalid"],["update:modelValue","update:visible"]),setup(t,{expose:e,emit:r}){let f=(0,n.fn)(t,"modelValue"),g=(0,n.fn)(t,"visible");e({focus:function(t){v.value.focus(t)},select:function(){v.value.select()}});let{password_policy:m}=(0,s.F)(),v=(0,n.rk)("inputField"),b=(0,i.KR)(""),A=(0,i.KR)(),y=(0,n.EW)(()=>{let e={...t};return delete e.checkPasswordStrength,delete e.minlength,delete e.asText,delete e.error,delete e.helperText,delete e.inputClass,delete e.success,e}),x=(0,n.EW)(()=>t.minlength??(t.checkPasswordStrength?m?.minLength:void 0)??void 0);async function C(){if(t.checkPasswordStrength&&f.value)try{let{data:t}=await o.Ay.post((0,l.KT)("apps/password_policy/api/v1/validate"),{password:f.value});if(A.value=t.ocs.data.passed,t.ocs.data.passed){b.value=(0,d.a)("Password is secure"),r("valid");return}b.value=t.ocs.data.reason,r("invalid")}catch(t){p.l.error("Password policy returned an error",{error:t})}}function E(){g.value=!g.value}return(0,n.wB)(f,()=>{A.value=void 0,b.value=""}),(0,n.wB)(f,(0,u.A)(C,500)),(e,r)=>((0,n.uX)(),(0,n.Wv)(h.N,(0,n.v6)(y.value,{ref:"inputField",modelValue:f.value,"onUpdate:modelValue":r[0]||(r[0]=t=>f.value=t),error:t.error||!1===A.value,helperText:t.helperText||b.value,inputClass:[t.inputClass,{"password-field__input--secure-text":!g.value&&t.asText}],minlength:x.value,success:t.success||!0===A.value,trailingButtonLabel:g.value?(0,i.R1)(d.a)("Hide password"):(0,i.R1)(d.a)("Show password"),type:g.value||t.asText?"text":"password",onTrailingButtonClick:E}),(0,n.eX)({"trailing-button-icon":(0,n.k6)(()=>[(0,n.bF)(c.N,{path:g.value?(0,i.R1)(a.q):(0,i.R1)(a.r)},null,8,["path"])]),_:2},[e.$slots.icon?{name:"icon",fn:(0,n.k6)(()=>[(0,n.RG)(e.$slots,"icon",{},void 0,!0)]),key:"0"}:void 0]),1040,["modelValue","error","helperText","inputClass","minlength","success","trailingButtonLabel","type"]))}}),m=(0,f._)(g,[["__scopeId","data-v-cb828737"]]);r.d(e,{},{N:m})},46855(t,e,r){"use strict";function n(t,e=100,r={}){let i,a,o,s;if("function"!=typeof t)throw TypeError(`Expected the first parameter to be a function, got \`${typeof t}\`.`);if(e<0)throw RangeError("`wait` must not be negative.");if("boolean"==typeof r)throw TypeError("The `options` parameter must be an object, not a boolean. Use `{immediate: true}` instead.");let{immediate:l}=r;function u(){let e=i,r=a;return i=void 0,a=void 0,t.apply(e,r)}function c(){let t=Date.now()-s;t<e&&t>=0?o=setTimeout(c,e-t):(o=void 0,l||u())}let h=function(...t){if(i&&this!==i&&Object.getPrototypeOf(this)===Object.getPrototypeOf(i))throw Error("Debounced method called with different contexts of the same prototype.");i=this,a=t,s=Date.now();let r=l&&!o;if(o||(o=setTimeout(c,e)),r)return u()};return Object.defineProperty(h,"isPending",{get:()=>void 0!==o}),h.clear=()=>{o&&(clearTimeout(o),o=void 0,i=void 0,a=void 0)},h.flush=()=>{o&&h.trigger()},h.trigger=()=>{u(),h.clear()},h}r.d(e,{A:()=>n})},44719(t,e,r){"use strict";let n;var i,a,o,s,l,u,c,h,d,p,f,g,m,v,b,A,y=r(65606),x={2(t){function e(t,e,i){t instanceof RegExp&&(t=r(t,i)),e instanceof RegExp&&(e=r(e,i));var a=n(t,e,i);return a&&{start:a[0],end:a[1],pre:i.slice(0,a[0]),body:i.slice(a[0]+t.length,a[1]),post:i.slice(a[1]+e.length)}}function r(t,e){var r=e.match(t);return r?r[0]:null}function n(t,e,r){var n,i,a,o,s,l=r.indexOf(t),u=r.indexOf(e,l+1),c=l;if(l>=0&&u>0){for(n=[],a=r.length;c>=0&&!s;)c==l?(n.push(c),l=r.indexOf(t,c+1)):1==n.length?s=[n.pop(),u]:((i=n.pop())<a&&(a=i,o=u),u=r.indexOf(e,c+1)),c=l<u&&l>=0?l:u;n.length&&(s=[a,o])}return s}t.exports=e,e.range=n},101(t,e,r){var n,i,a,o,s,l,u;((t=r.nmd(t))&&t.exports,i="object"==typeof global&&global).global!==i&&i.window,((a=function(t){this.message=t}).prototype=Error()).name="InvalidCharacterError",o=function(t){throw new a(t)},s="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",l=/[\t\n\f\r ]/g,u={encode:function(t){t=String(t),/[^\0-\xFF]/.test(t)&&o("The string to be encoded contains characters outside of the Latin1 range.");for(var e,r,n,i,a=t.length%3,l="",u=-1,c=t.length-a;++u<c;)e=t.charCodeAt(u)<<16,r=t.charCodeAt(++u)<<8,n=t.charCodeAt(++u),l+=s.charAt((i=e+r+n)>>18&63)+s.charAt(i>>12&63)+s.charAt(i>>6&63)+s.charAt(63&i);return 2==a?(e=t.charCodeAt(u)<<8,r=t.charCodeAt(++u),l+=s.charAt((i=e+r)>>10)+s.charAt(i>>4&63)+s.charAt(i<<2&63)+"="):1==a&&(i=t.charCodeAt(u),l+=s.charAt(i>>2)+s.charAt(i<<4&63)+"=="),l},decode:function(t){var e=(t=String(t).replace(l,"")).length;e%4==0&&(e=(t=t.replace(/==?$/,"")).length),(e%4==1||/[^+a-zA-Z0-9/]/.test(t))&&o("Invalid character: the string to be decoded is not correctly encoded.");for(var r,n,i=0,a="",u=-1;++u<e;)n=s.indexOf(t.charAt(u)),r=i%4?64*r+n:n,i++%4&&(a+=String.fromCharCode(255&r>>(-2*i&6)));return a},version:"1.0.0"},void 0===(n=(function(){return u}).call(e,r,e,t))||(t.exports=n)},172(t,e){e.d=function(t){if(!t)return 0;for(var e=(t=t.toString()).length,r=t.length;r--;){var n=t.charCodeAt(r);56320<=n&&n<=57343&&r--,127<n&&n<=2047?e++:2047<n&&n<=65535&&(e+=2)}return e}},526(t){var e={utf8:{stringToBytes:function(t){return e.bin.stringToBytes(unescape(encodeURIComponent(t)))},bytesToString:function(t){return decodeURIComponent(escape(e.bin.bytesToString(t)))}},bin:{stringToBytes:function(t){for(var e=[],r=0;r<t.length;r++)e.push(255&t.charCodeAt(r));return e},bytesToString:function(t){for(var e=[],r=0;r<t.length;r++)e.push(String.fromCharCode(t[r]));return e.join("")}}};t.exports=e},298(t){var e,r;e="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",t.exports=r={rotl:function(t,e){return t<<e|t>>>32-e},rotr:function(t,e){return t<<32-e|t>>>e},endian:function(t){if(t.constructor==Number)return 0xff00ff&r.rotl(t,8)|0xff00ff00&r.rotl(t,24);for(var e=0;e<t.length;e++)t[e]=r.endian(t[e]);return t},randomBytes:function(t){for(var e=[];t>0;t--)e.push(Math.floor(256*Math.random()));return e},bytesToWords:function(t){for(var e=[],r=0,n=0;r<t.length;r++,n+=8)e[n>>>5]|=t[r]<<24-n%32;return e},wordsToBytes:function(t){for(var e=[],r=0;r<32*t.length;r+=8)e.push(t[r>>>5]>>>24-r%32&255);return e},bytesToHex:function(t){for(var e=[],r=0;r<t.length;r++)e.push((t[r]>>>4).toString(16)),e.push((15&t[r]).toString(16));return e.join("")},hexToBytes:function(t){for(var e=[],r=0;r<t.length;r+=2)e.push(parseInt(t.substr(r,2),16));return e},bytesToBase64:function(t){for(var r=[],n=0;n<t.length;n+=3)for(var i=t[n]<<16|t[n+1]<<8|t[n+2],a=0;a<4;a++)8*n+6*a<=8*t.length?r.push(e.charAt(i>>>6*(3-a)&63)):r.push("=");return r.join("")},base64ToBytes:function(t){t=t.replace(/[^A-Z0-9+\/]/gi,"");for(var r=[],n=0,i=0;n<t.length;i=++n%4)0!=i&&r.push((e.indexOf(t.charAt(n-1))&Math.pow(2,-2*i+8)-1)<<2*i|e.indexOf(t.charAt(n))>>>6-2*i);return r}}},135(t){function e(t){return!!t.constructor&&"function"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}t.exports=function(t){return null!=t&&(e(t)||"function"==typeof t.readFloatLE&&"function"==typeof t.slice&&e(t.slice(0,0))||!!t._isBuffer)}},542(t,e,r){var n,i,a,o,s;n=r(298),i=r(526).utf8,a=r(135),o=r(526).bin,(s=function(t,e){t.constructor==String?t=e&&"binary"===e.encoding?o.stringToBytes(t):i.stringToBytes(t):a(t)?t=Array.prototype.slice.call(t,0):Array.isArray(t)||t.constructor===Uint8Array||(t=t.toString());for(var r=n.bytesToWords(t),l=8*t.length,u=0x67452301,c=-0x10325477,h=-0x67452302,d=0x10325476,p=0;p<r.length;p++)r[p]=0xff00ff&(r[p]<<8|r[p]>>>24)|0xff00ff00&(r[p]<<24|r[p]>>>8);r[l>>>5]|=128<<l%32,r[14+(l+64>>>9<<4)]=l;var f=s._ff,g=s._gg,m=s._hh,v=s._ii;for(p=0;p<r.length;p+=16){var b=u,A=c,y=h,x=d;u=f(u,c,h,d,r[p+0],7,-0x28955b88),d=f(d,u,c,h,r[p+1],12,-0x173848aa),h=f(h,d,u,c,r[p+2],17,0x242070db),c=f(c,h,d,u,r[p+3],22,-0x3e423112),u=f(u,c,h,d,r[p+4],7,-0xa83f051),d=f(d,u,c,h,r[p+5],12,0x4787c62a),h=f(h,d,u,c,r[p+6],17,-0x57cfb9ed),c=f(c,h,d,u,r[p+7],22,-0x2b96aff),u=f(u,c,h,d,r[p+8],7,0x698098d8),d=f(d,u,c,h,r[p+9],12,-0x74bb0851),h=f(h,d,u,c,r[p+10],17,-42063),c=f(c,h,d,u,r[p+11],22,-0x76a32842),u=f(u,c,h,d,r[p+12],7,0x6b901122),d=f(d,u,c,h,r[p+13],12,-0x2678e6d),h=f(h,d,u,c,r[p+14],17,-0x5986bc72),u=g(u,c=f(c,h,d,u,r[p+15],22,0x49b40821),h,d,r[p+1],5,-0x9e1da9e),d=g(d,u,c,h,r[p+6],9,-0x3fbf4cc0),h=g(h,d,u,c,r[p+11],14,0x265e5a51),c=g(c,h,d,u,r[p+0],20,-0x16493856),u=g(u,c,h,d,r[p+5],5,-0x29d0efa3),d=g(d,u,c,h,r[p+10],9,0x2441453),h=g(h,d,u,c,r[p+15],14,-0x275e197f),c=g(c,h,d,u,r[p+4],20,-0x182c0438),u=g(u,c,h,d,r[p+9],5,0x21e1cde6),d=g(d,u,c,h,r[p+14],9,-0x3cc8f82a),h=g(h,d,u,c,r[p+3],14,-0xb2af279),c=g(c,h,d,u,r[p+8],20,0x455a14ed),u=g(u,c,h,d,r[p+13],5,-0x561c16fb),d=g(d,u,c,h,r[p+2],9,-0x3105c08),h=g(h,d,u,c,r[p+7],14,0x676f02d9),u=m(u,c=g(c,h,d,u,r[p+12],20,-0x72d5b376),h,d,r[p+5],4,-378558),d=m(d,u,c,h,r[p+8],11,-0x788e097f),h=m(h,d,u,c,r[p+11],16,0x6d9d6122),c=m(c,h,d,u,r[p+14],23,-0x21ac7f4),u=m(u,c,h,d,r[p+1],4,-0x5b4115bc),d=m(d,u,c,h,r[p+4],11,0x4bdecfa9),h=m(h,d,u,c,r[p+7],16,-0x944b4a0),c=m(c,h,d,u,r[p+10],23,-0x41404390),u=m(u,c,h,d,r[p+13],4,0x289b7ec6),d=m(d,u,c,h,r[p+0],11,-0x155ed806),h=m(h,d,u,c,r[p+3],16,-0x2b10cf7b),c=m(c,h,d,u,r[p+6],23,0x4881d05),u=m(u,c,h,d,r[p+9],4,-0x262b2fc7),d=m(d,u,c,h,r[p+12],11,-0x1924661b),h=m(h,d,u,c,r[p+15],16,0x1fa27cf8),u=v(u,c=m(c,h,d,u,r[p+2],23,-0x3b53a99b),h,d,r[p+0],6,-0xbd6ddbc),d=v(d,u,c,h,r[p+7],10,0x432aff97),h=v(h,d,u,c,r[p+14],15,-0x546bdc59),c=v(c,h,d,u,r[p+5],21,-0x36c5fc7),u=v(u,c,h,d,r[p+12],6,0x655b59c3),d=v(d,u,c,h,r[p+3],10,-0x70f3336e),h=v(h,d,u,c,r[p+10],15,-1051523),c=v(c,h,d,u,r[p+1],21,-0x7a7ba22f),u=v(u,c,h,d,r[p+8],6,0x6fa87e4f),d=v(d,u,c,h,r[p+15],10,-0x1d31920),h=v(h,d,u,c,r[p+6],15,-0x5cfebcec),c=v(c,h,d,u,r[p+13],21,0x4e0811a1),u=v(u,c,h,d,r[p+4],6,-0x8ac817e),d=v(d,u,c,h,r[p+11],10,-0x42c50dcb),h=v(h,d,u,c,r[p+2],15,0x2ad7d2bb),c=v(c,h,d,u,r[p+9],21,-0x14792c6f),u=u+b>>>0,c=c+A>>>0,h=h+y>>>0,d=d+x>>>0}return n.endian([u,c,h,d])})._ff=function(t,e,r,n,i,a,o){var s=t+(e&r|~e&n)+(i>>>0)+o;return(s<<a|s>>>32-a)+e},s._gg=function(t,e,r,n,i,a,o){var s=t+(e&n|r&~n)+(i>>>0)+o;return(s<<a|s>>>32-a)+e},s._hh=function(t,e,r,n,i,a,o){var s=t+(e^r^n)+(i>>>0)+o;return(s<<a|s>>>32-a)+e},s._ii=function(t,e,r,n,i,a,o){var s=t+(r^(e|~n))+(i>>>0)+o;return(s<<a|s>>>32-a)+e},s._blocksize=16,s._digestsize=16,t.exports=function(t,e){if(null==t)throw Error("Illegal argument "+t);var r=n.wordsToBytes(s(t,e));return e&&e.asBytes?r:e&&e.asString?o.bytesToString(r):n.bytesToHex(r)}},285(t,e,r){var n=r(2);t.exports=function(t,e){if(!t)return[];var r=null==(e=e||{}).max?1/0:e.max;return"{}"===t.substr(0,2)&&(t="\\{\\}"+t.substr(2)),(function t(e,r,i){var a=[],s=n("{","}",e);if(!s)return[e];var l=s.pre,c=s.post.length?t(s.post,r,!1):[""];if(/\$$/.test(s.pre))for(var g=0;g<c.length&&g<r;g++){var m=l+"{"+s.body+"}"+c[g];a.push(m)}else{var v,b,A=/^-?\d+\.\.-?\d+(?:\.\.-?\d+)?$/.test(s.body),y=/^[a-zA-Z]\.\.[a-zA-Z](?:\.\.-?\d+)?$/.test(s.body),x=A||y,C=s.body.indexOf(",")>=0;if(!x&&!C)return s.post.match(/,(?!,).*\}/)?t(e=s.pre+"{"+s.body+o+s.post,r,!0):[e];if(x)v=s.body.split(/\.\./);else if(1===(v=function t(e){if(!e)return[""];var r=[],i=n("{","}",e);if(!i)return e.split(",");var a=i.pre,o=i.body,s=i.post,l=a.split(",");l[l.length-1]+="{"+o+"}";var u=t(s);return s.length&&(l[l.length-1]+=u.shift(),l.push.apply(l,u)),r.push.apply(r,l),r}(s.body)).length&&1===(v=t(v[0],r,!1).map(h)).length)return c.map(function(t){return s.pre+v[0]+t});if(x){var E,w=u(v[0]),_=u(v[1]),N=Math.max(v[0].length,v[1].length),P=3==v.length?Math.max(Math.abs(u(v[2])),1):1,S=p;_<w&&(P*=-1,S=f);var k=v.some(d);b=[];for(var T=w;S(T,_);T+=P){if(y)"\\"===(E=String.fromCharCode(T))&&(E="");else if(E=String(T),k){var B=N-E.length;if(B>0){var $=Array(B+1).join("0");E=T<0?"-"+$+E.slice(1):$+E}}b.push(E)}}else{b=[];for(var O=0;O<v.length;O++)b.push.apply(b,t(v[O],r,!1))}for(O=0;O<b.length;O++)for(g=0;g<c.length&&a.length<r;g++)m=l+b[O]+c[g],(!i||x||m)&&a.push(m)}return a})(t.split("\\\\").join(i).split("\\{").join(a).split("\\}").join(o).split("\\,").join(s).split("\\.").join(l),r,!0).map(c)};var i="\0SLASH"+Math.random()+"\0",a="\0OPEN"+Math.random()+"\0",o="\0CLOSE"+Math.random()+"\0",s="\0COMMA"+Math.random()+"\0",l="\0PERIOD"+Math.random()+"\0";function u(t){return parseInt(t,10)==t?parseInt(t,10):t.charCodeAt(0)}function c(t){return t.split(i).join("\\").split(a).join("{").split(o).join("}").split(s).join(",").split(l).join(".")}function h(t){return"{"+t+"}"}function d(t){return/^-?0\d/.test(t)}function p(t,e){return t<=e}function f(t,e){return t>=e}},829(t){function e(t){return(e="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(t){return typeof t}:function(t){return t&&"function"==typeof Symbol&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t})(t)}function r(t){var e="function"==typeof Map?new Map:void 0;return(r=function(t){if(null===t||-1===Function.toString.call(t).indexOf("[native code]"))return t;if("function"!=typeof t)throw TypeError("Super expression must either be null or a function");if(void 0!==e){if(e.has(t))return e.get(t);e.set(t,r)}function r(){return n(t,arguments,a(this).constructor)}return r.prototype=Object.create(t.prototype,{constructor:{value:r,enumerable:!1,writable:!0,configurable:!0}}),i(r,t)})(t)}function n(t,e,r){return(n=!function(){if("u"<typeof Reflect||!Reflect.construct||Reflect.construct.sham)return!1;if("function"==typeof Proxy)return!0;try{return Date.prototype.toString.call(Reflect.construct(Date,[],function(){})),!0}catch(t){return!1}}()?function(t,e,r){var n=[null];n.push.apply(n,e);var a=new(Function.bind.apply(t,n));return r&&i(a,r.prototype),a}:Reflect.construct).apply(null,arguments)}function i(t,e){return(i=Object.setPrototypeOf||function(t,e){return t.__proto__=e,t})(t,e)}function a(t){return(a=Object.setPrototypeOf?Object.getPrototypeOf:function(t){return t.__proto__||Object.getPrototypeOf(t)})(t)}var o=function(t){function r(t){var n,i;return function(t,e){if(!(t instanceof e))throw TypeError("Cannot call a class as a function")}(this,r),(n=(i=a(r).call(this,t))&&("object"===e(i)||"function"==typeof i)?i:function(t){if(void 0===t)throw ReferenceError("this hasn't been initialised - super() hasn't been called");return t}(this)).name="ObjectPrototypeMutationError",n}return function(t,e){if("function"!=typeof e&&null!==e)throw TypeError("Super expression must either be null or a function");t.prototype=Object.create(e&&e.prototype,{constructor:{value:t,writable:!0,configurable:!0}}),e&&i(t,e)}(r,t),r}(r(Error));function s(t,r){for(var n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:function(){},i=r.split("."),a=i.length,o=function(e){var r=i[e];if(!t)return{v:void 0};if("+"===r){if(Array.isArray(t))return{v:t.map(function(r,a){var o=i.slice(e+1);return o.length>0?s(r,o.join("."),n):n(t,a,i,e)})};var a=i.slice(0,e).join(".");throw Error("Object at wildcard (".concat(a,") is not an array"))}t=n(t,r,i,e)},l=0;l<a;l++){var u=o(l);if("object"===e(u))return u.v}return t}function l(t,e){return t.length===e+1}t.exports={set:function(t,r,n){if("object"!=e(t)||null===t||void 0===r)return t;if("number"==typeof r)return t[r]=n,t[r];try{return s(t,r,function(t,e,r,i){if(t===Reflect.getPrototypeOf({}))throw new o("Attempting to mutate Object.prototype");if(!t[e]){var a=Number.isInteger(Number(r[i+1])),s="+"===r[i+1];t[e]=a||s?[]:{}}return l(r,i)&&(t[e]=n),t[e]})}catch(e){if(e instanceof o)throw e;return t}},get:function(t,r){if("object"!=e(t)||null===t||void 0===r)return t;if("number"==typeof r)return t[r];try{return s(t,r,function(t,e){return t[e]})}catch(e){return t}},has:function(t,r){var n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};if("object"!=e(t)||null===t||void 0===r)return!1;if("number"==typeof r)return r in t;try{var i=!1;return s(t,r,function(t,e,r,a){if(!l(r,a))return t&&t[e];i=n.own?t.hasOwnProperty(e):e in t}),i}catch(t){return!1}},hasOwn:function(t,e,r){return this.has(t,e,r||{own:!0})},isIn:function(t,r,n){var i=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{};if("object"!=e(t)||null===t||void 0===r)return!1;try{var a=!1,o=!1;return s(t,r,function(t,r,i,s){return a=a||t===n||!!t&&t[r]===n,o=l(i,s)&&"object"===e(t)&&r in t,t&&t[r]}),i.validPath?a&&o:a}catch(t){return!1}},ObjectPrototypeMutationError:o}},47(t,e,r){var n=r(410),i=function(t){return"string"==typeof t};function a(t,e){for(var r=[],n=0;n<t.length;n++){var i=t[n];i&&"."!==i&&(".."===i?r.length&&".."!==r[r.length-1]?r.pop():e&&r.push(".."):r.push(i))}return r}var o=/^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/,s={};function l(t){return o.exec(t).slice(1)}s.resolve=function(){for(var t="",e=!1,r=arguments.length-1;r>=-1&&!e;r--){var n=r>=0?arguments[r]:y.cwd();if(!i(n))throw TypeError("Arguments to path.resolve must be strings");n&&(t=n+"/"+t,e="/"===n.charAt(0))}return(e?"/":"")+(t=a(t.split("/"),!e).join("/"))||"."},s.normalize=function(t){var e=s.isAbsolute(t),r="/"===t.substr(-1);return(t=a(t.split("/"),!e).join("/"))||e||(t="."),t&&r&&(t+="/"),(e?"/":"")+t},s.isAbsolute=function(t){return"/"===t.charAt(0)},s.join=function(){for(var t="",e=0;e<arguments.length;e++){var r=arguments[e];if(!i(r))throw TypeError("Arguments to path.join must be strings");r&&(t+=t?"/"+r:r)}return s.normalize(t)},s.relative=function(t,e){function r(t){for(var e=0;e<t.length&&""===t[e];e++);for(var r=t.length-1;r>=0&&""===t[r];r--);return e>r?[]:t.slice(e,r+1)}t=s.resolve(t).substr(1),e=s.resolve(e).substr(1);for(var n=r(t.split("/")),i=r(e.split("/")),a=Math.min(n.length,i.length),o=a,l=0;l<a;l++)if(n[l]!==i[l]){o=l;break}var u=[];for(l=o;l<n.length;l++)u.push("..");return(u=u.concat(i.slice(o))).join("/")},s._makeLong=function(t){return t},s.dirname=function(t){var e=l(t),r=e[0],n=e[1];return r||n?(n&&(n=n.substr(0,n.length-1)),r+n):"."},s.basename=function(t,e){var r=l(t)[2];return e&&r.substr(-1*e.length)===e&&(r=r.substr(0,r.length-e.length)),r},s.extname=function(t){return l(t)[3]},s.format=function(t){if(!n.isObject(t))throw TypeError("Parameter 'pathObject' must be an object, not "+typeof t);if(!i(t.root||""))throw TypeError("'pathObject.root' must be a string or undefined, not "+typeof t.root);return(t.dir?t.dir+s.sep:"")+(t.base||"")},s.parse=function(t){if(!i(t))throw TypeError("Parameter 'pathString' must be a string, not "+typeof t);var e=l(t);if(!e||4!==e.length)throw TypeError("Invalid path '"+t+"'");return e[1]=e[1]||"",e[2]=e[2]||"",e[3]=e[3]||"",{root:e[0],dir:e[0]+e[1].slice(0,e[1].length-1),base:e[2],ext:e[3],name:e[2].slice(0,e[2].length-e[3].length)}},s.sep="/",s.delimiter=":",t.exports=s},647(t,e){var r=Object.prototype.hasOwnProperty;function n(t){try{return decodeURIComponent(t.replace(/\+/g," "))}catch(t){return null}}function i(t){try{return encodeURIComponent(t)}catch(t){return null}}e.stringify=function(t,e){var n,a,o=[];for(a in"string"!=typeof(e=e||"")&&(e="?"),t)if(r.call(t,a)){if((n=t[a])||null!=n&&!isNaN(n)||(n=""),a=i(a),n=i(n),null===a||null===n)continue;o.push(a+"="+n)}return o.length?e+o.join("&"):""},e.parse=function(t){for(var e,r=/([^=?#&]+)=?([^&]*)/g,i={};e=r.exec(t);){var a=n(e[1]),o=n(e[2]);null===a||null===o||a in i||(i[a]=o)}return i}},670(t){t.exports=function(t,e){if(e=e.split(":")[0],!(t*=1))return!1;switch(e){case"http":case"ws":return 80!==t;case"https":case"wss":return 443!==t;case"ftp":return 21!==t;case"gopher":return 70!==t;case"file":return!1}return 0!==t}},737(t,e,r){var n=r(670),i=r(647),a=/^[\x00-\x20\u00a0\u1680\u2000-\u200a\u2028\u2029\u202f\u205f\u3000\ufeff]+/,o=/[\n\r\t]/g,s=/^[A-Za-z][A-Za-z0-9+-.]*:\/\//,l=/:\d+$/,u=/^([a-z][a-z0-9.+-]*:)?(\/\/)?([\\/]+)?([\S\s]*)/i,c=/^[a-zA-Z]:/;function h(t){return(t||"").toString().replace(a,"")}var d=[["#","hash"],["?","query"],function(t,e){return g(e.protocol)?t.replace(/\\/g,"/"):t},["/","pathname"],["@","auth",1],[NaN,"host",void 0,1,1],[/:(\d*)$/,"port",void 0,1],[NaN,"hostname",void 0,1,1]],p={hash:1,query:1};function f(t){var e,r=("u">typeof window?window:"u">typeof global?global:"u">typeof self?self:{}).location||{},n={},i=typeof(t=t||r);if("blob:"===t.protocol)n=new v(unescape(t.pathname),{});else if("string"===i)for(e in n=new v(t,{}),p)delete n[e];else if("object"===i){for(e in t)e in p||(n[e]=t[e]);void 0===n.slashes&&(n.slashes=s.test(t.href))}return n}function g(t){return"file:"===t||"ftp:"===t||"http:"===t||"https:"===t||"ws:"===t||"wss:"===t}function m(t,e){t=(t=h(t)).replace(o,""),e=e||{};var r,n=u.exec(t),i=n[1]?n[1].toLowerCase():"",a=!!n[2],s=!!n[3],l=0;return a?s?(r=n[2]+n[3]+n[4],l=n[2].length+n[3].length):(r=n[2]+n[4],l=n[2].length):s?(r=n[3]+n[4],l=n[3].length):r=n[4],"file:"===i?l>=2&&(r=r.slice(2)):g(i)?r=n[4]:i?a&&(r=r.slice(2)):l>=2&&g(e.protocol)&&(r=n[4]),{protocol:i,slashes:a||g(i),slashesCount:l,rest:r}}function v(t,e,r){if(t=(t=h(t)).replace(o,""),!(this instanceof v))return new v(t,e,r);var a,s,l,u,p,b,A=d.slice(),y=typeof e,x=0;for("object"!==y&&"string"!==y&&(r=e,e=null),r&&"function"!=typeof r&&(r=i.parse),a=!(s=m(t||"",e=f(e))).protocol&&!s.slashes,this.slashes=s.slashes||a&&e.slashes,this.protocol=s.protocol||e.protocol||"",t=s.rest,("file:"===s.protocol&&(2!==s.slashesCount||c.test(t))||!s.slashes&&(s.protocol||s.slashesCount<2||!g(this.protocol)))&&(A[3]=[/(.*)/,"pathname"]);x<A.length;x++)"function"!=typeof(u=A[x])?(l=u[0],b=u[1],l!=l?this[b]=t:"string"==typeof l?~(p="@"===l?t.lastIndexOf(l):t.indexOf(l))&&("number"==typeof u[2]?(this[b]=t.slice(0,p),t=t.slice(p+u[2])):(this[b]=t.slice(p),t=t.slice(0,p))):(p=l.exec(t))&&(this[b]=p[1],t=t.slice(0,p.index)),this[b]=this[b]||a&&u[3]&&e[b]||"",u[4]&&(this[b]=this[b].toLowerCase())):t=u(t,this);r&&(this.query=r(this.query)),a&&e.slashes&&"/"!==this.pathname.charAt(0)&&(""!==this.pathname||""!==e.pathname)&&(this.pathname=function(t,e){if(""===t)return e;for(var r=(e||"/").split("/").slice(0,-1).concat(t.split("/")),n=r.length,i=r[n-1],a=!1,o=0;n--;)"."===r[n]?r.splice(n,1):".."===r[n]?(r.splice(n,1),o++):o&&(0===n&&(a=!0),r.splice(n,1),o--);return a&&r.unshift(""),"."!==i&&".."!==i||r.push(""),r.join("/")}(this.pathname,e.pathname)),"/"!==this.pathname.charAt(0)&&g(this.protocol)&&(this.pathname="/"+this.pathname),n(this.port,this.protocol)||(this.host=this.hostname,this.port=""),this.username=this.password="",this.auth&&(~(p=this.auth.indexOf(":"))?(this.username=this.auth.slice(0,p),this.username=encodeURIComponent(decodeURIComponent(this.username)),this.password=this.auth.slice(p+1),this.password=encodeURIComponent(decodeURIComponent(this.password))):this.username=encodeURIComponent(decodeURIComponent(this.auth)),this.auth=this.password?this.username+":"+this.password:this.username),this.origin="file:"!==this.protocol&&g(this.protocol)&&this.host?this.protocol+"//"+this.host:"null",this.href=this.toString()}v.prototype={set:function(t,e,r){switch(t){case"query":"string"==typeof e&&e.length&&(e=(r||i.parse)(e)),this[t]=e;break;case"port":this[t]=e,n(e,this.protocol)?e&&(this.host=this.hostname+":"+e):(this.host=this.hostname,this[t]="");break;case"hostname":this[t]=e,this.port&&(e+=":"+this.port),this.host=e;break;case"host":this[t]=e,l.test(e)?(e=e.split(":"),this.port=e.pop(),this.hostname=e.join(":")):(this.hostname=e,this.port="");break;case"protocol":this.protocol=e.toLowerCase(),this.slashes=!r;break;case"pathname":case"hash":if(e){var a="pathname"===t?"/":"#";this[t]=e.charAt(0)!==a?a+e:e}else this[t]=e;break;case"username":case"password":this[t]=encodeURIComponent(e);break;case"auth":var o=e.indexOf(":");~o?(this.username=e.slice(0,o),this.username=encodeURIComponent(decodeURIComponent(this.username)),this.password=e.slice(o+1),this.password=encodeURIComponent(decodeURIComponent(this.password))):this.username=encodeURIComponent(decodeURIComponent(e))}for(var s=0;s<d.length;s++){var u=d[s];u[4]&&(this[u[1]]=this[u[1]].toLowerCase())}return this.auth=this.password?this.username+":"+this.password:this.username,this.origin="file:"!==this.protocol&&g(this.protocol)&&this.host?this.protocol+"//"+this.host:"null",this.href=this.toString(),this},toString:function(t){t&&"function"==typeof t||(t=i.stringify);var e,r=this.host,n=this.protocol;n&&":"!==n.charAt(n.length-1)&&(n+=":");var a=n+(this.protocol&&this.slashes||g(this.protocol)?"//":"");return this.username?(a+=this.username,this.password&&(a+=":"+this.password),a+="@"):this.password?(a+=":"+this.password,a+="@"):"file:"!==this.protocol&&g(this.protocol)&&!r&&"/"!==this.pathname&&(a+="@"),(":"===r[r.length-1]||l.test(this.hostname)&&!this.port)&&(r+=":"),a+=r+this.pathname,(e="object"==typeof this.query?t(this.query):this.query)&&(a+="?"!==e.charAt(0)?"?"+e:e),this.hash&&(a+=this.hash),a}},v.extractProtocol=m,v.location=f,v.trimLeft=h,v.qs=i,t.exports=v},410(){},388(){},805(){},345(){},800(){}},C={};function E(t){var e=C[t];if(void 0!==e)return e.exports;var r=C[t]={id:t,loaded:!1,exports:{}};return x[t].call(r.exports,r,r.exports,E),r.loaded=!0,r.exports}E.n=t=>{var e=t&&t.__esModule?()=>t.default:()=>t;return E.d(e,{a:e}),e},E.d=(t,e)=>{for(var r in e)E.o(e,r)&&!E.o(t,r)&&Object.defineProperty(t,r,{enumerable:!0,get:e[r]})},E.o=(t,e)=>Object.prototype.hasOwnProperty.call(t,e),E.nmd=t=>(t.paths=[],t.children||(t.children=[]),t);var w=E(737),_=E.n(w);function N(t){if(!P(t))throw Error("Parameter was not an error")}function P(t){return!!t&&"object"==typeof t&&"[object Error]"===Object.prototype.toString.call(t)||t instanceof Error}class S extends Error{constructor(t,e){const r=[...arguments],{options:n,shortMessage:i}=function(t){let e,r="";if(0===t.length)e={};else if(P(t[0]))e={cause:t[0]},r=t.slice(1).join(" ")||"";else if(t[0]&&"object"==typeof t[0])e=Object.assign({},t[0]),r=t.slice(1).join(" ")||"";else{if("string"!=typeof t[0])throw Error("Invalid arguments passed to Layerr");e={},r=r=t.join(" ")||""}return{options:e,shortMessage:r}}(r);let a=i;n.cause&&(a=`${a}: ${n.cause.message}`),super(a),this.message=a,n.name&&"string"==typeof n.name?this.name=n.name:this.name="Layerr",n.cause&&Object.defineProperty(this,"_cause",{value:n.cause}),Object.defineProperty(this,"_info",{value:{}}),n.info&&"object"==typeof n.info&&Object.assign(this._info,n.info),Error.captureStackTrace&&Error.captureStackTrace(this,n.constructorOpt||this.constructor)}static cause(t){return N(t),t._cause&&P(t._cause)?t._cause:null}static fullStack(t){N(t);let e=S.cause(t);return e?`${t.stack}
caused by: ${S.fullStack(e)}`:t.stack??""}static info(t){N(t);let e={},r=S.cause(t);return r&&Object.assign(e,S.info(r)),t._info&&Object.assign(e,t._info),e}toString(){let t=this.name||this.constructor.name||this.constructor.prototype.name;return this.message&&(t=`${t}: ${this.message}`),t}}var k=E(47),T=E.n(k);let B="__PATH_SEPARATOR_POSIX__",$="__PATH_SEPARATOR_WINDOWS__";function O(t){try{let e=t.replace(/\//g,B).replace(/\\\\/g,$);return encodeURIComponent(e).split($).join("\\\\").split(B).join("/")}catch(t){throw new S(t,"Failed encoding path")}}function j(t){return t.startsWith("/")?t:"/"+t}function D(t){let e=t;return"/"!==e[0]&&(e="/"+e),/^.+\/$/.test(e)&&(e=e.substr(0,e.length-1)),e}function L(){for(var t=arguments.length,e=Array(t),r=0;r<t;r++)e[r]=arguments[r];return function(){return function(t){var e=[];if(0===t.length)return"";if("string"!=typeof t[0])throw TypeError("Url must be a string. Received "+t[0]);if(t[0].match(/^[^/:]+:\/*$/)&&t.length>1){var r=t.shift();t[0]=r+t[0]}t[0].match(/^file:\/\/\//)?t[0]=t[0].replace(/^([^/:]+):\/*/,"$1:///"):t[0]=t[0].replace(/^([^/:]+):\/*/,"$1://");for(var n=0;n<t.length;n++){var i=t[n];if("string"!=typeof i)throw TypeError("Url must be a string. Received "+i);""!==i&&(n>0&&(i=i.replace(/^[\/]+/,"")),i=n<t.length-1?i.replace(/[\/]+$/,""):i.replace(/[\/]+$/,"/"),e.push(i))}var a=e.join("/"),o=(a=a.replace(/\/(\?|&|#[^!])/g,"$1")).split("?");return o.shift()+(o.length>0?"?":"")+o.join("&")}("object"==typeof arguments[0]?arguments[0]:[].slice.call(arguments))}(e.reduce((t,e,r)=>((0===r||"/"!==e||"/"===e&&"/"!==t[t.length-1])&&t.push(e),t),[]))}var I=E(542),R=E.n(I);function M(t,e){var r,n,i,a,o,s;let l,u=t.url.replace("//",""),c=-1==u.indexOf("/")?"/":u.slice(u.indexOf("/")),h=t.method?t.method.toUpperCase():"GET",d=!!/(^|,)\s*auth\s*($|,)/.test(e.qop)&&"auth",p=`00000000${e.nc}`.slice(-8),f=(r=e.algorithm,n=e.username,i=e.realm,a=e.password,o=e.nonce,s=e.cnonce,l=e.ha1||R()(`${n}:${i}:${a}`),r&&"md5-sess"===r.toLowerCase()?R()(`${l}:${o}:${s}`):l),g=R()(`${h}:${c}`),m=d?R()(`${f}:${e.nonce}:${p}:${e.cnonce}:${d}:${g}`):R()(`${f}:${e.nonce}:${g}`),v={username:e.username,realm:e.realm,nonce:e.nonce,uri:c,qop:d,response:m,nc:p,cnonce:e.cnonce,algorithm:e.algorithm,opaque:e.opaque},b=[];for(let t in v)v[t]&&("qop"===t||"nc"===t||"algorithm"===t?b.push(`${t}=${v[t]}`):b.push(`${t}="${v[t]}"`));return`Digest ${b.join(", ")}`}function F(t){return"digest"===(t.headers&&t.headers.get("www-authenticate")||"").split(/\s/)[0].toLowerCase()}var U=E(101),V=E.n(U);function G(t){return V().decode(t)}function W(t,e){var r;return`Basic ${r=`${t}:${e}`,V().encode(r)}`}let z="u">typeof WorkerGlobalScope&&self instanceof WorkerGlobalScope?self:"u">typeof window?window:globalThis,X=z.fetch.bind(z);z.Headers,z.Request,z.Response;let q=((i={}).Auto="auto",i.Digest="digest",i.None="none",i.Password="password",i.Token="token",i),H=((a={}).DataTypeNoLength="data-type-no-length",a.InvalidAuthType="invalid-auth-type",a.InvalidOutputFormat="invalid-output-format",a.LinkUnsupportedAuthType="link-unsupported-auth",a.InvalidUpdateRange="invalid-update-range",a.NotSupported="not-supported",a);function Y(t,e,r,n,i){switch(t.authType){case q.Auto:e&&r&&(t.headers.Authorization=W(e,r));break;case q.Digest:t.digest={username:e,password:r,ha1:i,nc:0,algorithm:"md5",hasDigestAuth:!1};break;case q.None:break;case q.Password:t.headers.Authorization=W(e,r);break;case q.Token:t.headers.Authorization=`${n.token_type} ${n.access_token}`;break;default:throw new S({info:{code:H.InvalidAuthType}},`Invalid auth type: ${t.authType}`)}}E(345),E(800);let Z="@@HOTPATCHER",K=()=>{};function Q(t){return{original:t,methods:[t],final:!1}}class J{constructor(){this._configuration={registry:{},getEmptyAction:"null"},this.__type__=Z}get configuration(){return this._configuration}get getEmptyAction(){return this.configuration.getEmptyAction}set getEmptyAction(t){this.configuration.getEmptyAction=t}control(t){let e=arguments.length>1&&void 0!==arguments[1]&&arguments[1];if(!t||t.__type__!==Z)throw Error("Failed taking control of target HotPatcher instance: Invalid type or object");return Object.keys(t.configuration.registry).forEach(r=>{this.configuration.registry.hasOwnProperty(r)?e&&(this.configuration.registry[r]=Object.assign({},t.configuration.registry[r])):this.configuration.registry[r]=Object.assign({},t.configuration.registry[r])}),t._configuration=this.configuration,this}execute(t){let e=this.get(t)||K;for(var r=arguments.length,n=Array(r>1?r-1:0),i=1;i<r;i++)n[i-1]=arguments[i];return e(...n)}get(t){let e=this.configuration.registry[t];if(!e)switch(this.getEmptyAction){case"null":return null;case"throw":throw Error(`Failed handling method request: No method provided for override: ${t}`);default:throw Error(`Failed handling request which resulted in an empty method: Invalid empty-action specified: ${this.getEmptyAction}`)}return function(){for(var t=arguments.length,e=Array(t),r=0;r<t;r++)e[r]=arguments[r];if(0===e.length)throw Error("Failed creating sequence: No functions provided");return function(){for(var t=arguments.length,r=Array(t),n=0;n<t;n++)r[n]=arguments[n];let i=r;for(;e.length>0;)i=[e.shift().apply(this,i)];return i[0]}}(...e.methods)}isPatched(t){return!!this.configuration.registry[t]}patch(t,e){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},{chain:n=!1}=r;if(this.configuration.registry[t]&&this.configuration.registry[t].final)throw Error(`Failed patching '${t}': Method marked as being final`);if("function"!=typeof e)throw Error(`Failed patching '${t}': Provided method is not a function`);if(n)this.configuration.registry[t]?this.configuration.registry[t].methods.push(e):this.configuration.registry[t]=Q(e);else if(this.isPatched(t)){let{original:r}=this.configuration.registry[t];this.configuration.registry[t]=Object.assign(Q(e),{original:r})}else this.configuration.registry[t]=Q(e);return this}patchInline(t,e){this.isPatched(t)||this.patch(t,e);for(var r=arguments.length,n=Array(r>2?r-2:0),i=2;i<r;i++)n[i-2]=arguments[i];return this.execute(t,...n)}plugin(t){for(var e=arguments.length,r=Array(e>1?e-1:0),n=1;n<e;n++)r[n-1]=arguments[n];return r.forEach(e=>{this.patch(t,e,{chain:!0})}),this}restore(t){if(!this.isPatched(t))throw Error(`Failed restoring method: No method present for key: ${t}`);if("function"!=typeof this.configuration.registry[t].original)throw Error(`Failed restoring method: Original method not found or of invalid type for key: ${t}`);return this.configuration.registry[t].methods=[this.configuration.registry[t].original],this}setFinal(t){if(!this.configuration.registry.hasOwnProperty(t))throw Error(`Failed marking '${t}' as final: No method found for key`);return this.configuration.registry[t].final=!0,this}}let tt=null;function te(){return tt||(tt=new J),tt}function tr(t){return!function(t){if("object"!=typeof t||null===t||"[object Object]"!=Object.prototype.toString.call(t))return!1;if(null===Object.getPrototypeOf(t))return!0;let e=t;for(;null!==Object.getPrototypeOf(e);)e=Object.getPrototypeOf(e);return Object.getPrototypeOf(t)===e}(t)?Object.setPrototypeOf(Object.assign({},t),Object.getPrototypeOf(t)):Object.assign({},t)}function tn(){for(var t=arguments.length,e=Array(t),r=0;r<t;r++)e[r]=arguments[r];let n=null,i=[...e];for(;i.length>0;){let t=i.shift();n=n?function t(e,r){let n=tr(e);return Object.keys(r).forEach(e=>{n.hasOwnProperty(e)?Array.isArray(r[e])?n[e]=Array.isArray(n[e])?[...n[e],...r[e]]:[...r[e]]:"object"==typeof r[e]&&r[e]?n[e]="object"==typeof n[e]&&n[e]?t(n[e],r[e]):tr(r[e]):n[e]=r[e]:n[e]=r[e]}),n}(n,t):tr(t)}return n}function ti(){for(var t=arguments.length,e=Array(t),r=0;r<t;r++)e[r]=arguments[r];if(0===e.length)return{};let n={};return e.reduce((t,e)=>(Object.keys(e).forEach(r=>{let i=r.toLowerCase();n.hasOwnProperty(i)?t[n[i]]=e[r]:(n[i]=r,t[r]=e[r])}),t),{})}E(805);let ta="function"==typeof ArrayBuffer,{toString:to}=Object.prototype;function ts(t){return ta&&(t instanceof ArrayBuffer||"[object ArrayBuffer]"===to.call(t))}function tl(t){return null!=t&&null!=t.constructor&&"function"==typeof t.constructor.isBuffer&&t.constructor.isBuffer(t)}function tu(t){return function(){for(var e=[],r=0;r<arguments.length;r++)e[r]=arguments[r];try{return Promise.resolve(t.apply(this,e))}catch(t){return Promise.reject(t)}}}function tc(t,e,r){return r?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let th=tu(function(t){let e=t._digest;return delete t._digest,e.hasDigestAuth&&(t=tn(t,{headers:{Authorization:M(t,e)}})),tc(tg(t),function(r){var n,i;let a=!1;return n=function(t){return a?t:r},(i=function(){if(401==r.status)return e.hasDigestAuth=function(t,e){if(!F(t))return!1;let r=/([a-z0-9_-]+)=(?:"([^"]+)"|([a-z0-9_-]+))/gi;for(;;){let n=t.headers&&t.headers.get("www-authenticate")||"",i=r.exec(n);if(!i)break;e[i[1]]=i[2]||i[3]}return e.nc+=1,e.cnonce=function(){let t="";for(let e=0;e<32;++e)t=`${t}${"abcdef0123456789"[Math.floor(16*Math.random())]}`;return t}(),!0}(r,e),function(){if(e.hasDigestAuth)return tc(tg(t=tn(t,{headers:{Authorization:M(t,e)}})),function(t){return 401==t.status?e.hasDigestAuth=!1:e.nc++,a=!0,t})}();e.nc++}())&&i.then?i.then(n):n(i)})}),td=tu(function(t,e){return tc(tg(t),function(r){return r.ok?(e.authType=q.Password,r):401==r.status&&F(r)?(e.authType=q.Digest,Y(e,e.username,e.password,void 0,void 0),t._digest=e.digest,th(t)):r})}),tp=tu(function(t,e){return e.authType===q.Auto?td(t,e):t._digest?th(t):tg(t)});function tf(t,e,r){let n=tr(t);return n.headers=ti(e.headers,n.headers||{},r.headers||{}),void 0!==r.data&&(n.data=r.data),r.signal&&(n.signal=r.signal),e.httpAgent&&(n.httpAgent=e.httpAgent),e.httpsAgent&&(n.httpsAgent=e.httpsAgent),e.digest&&(n._digest=e.digest),"boolean"==typeof e.withCredentials&&(n.withCredentials=e.withCredentials),n}function tg(t){let e=te();return e.patchInline("request",t=>e.patchInline("fetch",X,t.url,function(t){let e={},r={method:t.method};if(t.headers&&(e=ti(e,t.headers)),void 0!==t.data){let[n,i]=function(t){if("string"==typeof t||tl(t)||ts(t))return[t,{}];if(t&&"object"==typeof t)return[JSON.stringify(t),{"content-type":"application/json"}];throw Error("Unable to convert request body: Unexpected body type: "+typeof t)}(t.data);r.body=n,e=ti(e,i)}return t.signal&&(r.signal=t.signal),t.withCredentials&&(r.credentials="include"),r.headers=e,r}(t)),t)}var tm=E(285);let tv=t=>{if("string"!=typeof t)throw TypeError("invalid pattern");if(t.length>65536)throw TypeError("pattern is too long")},tb={"[:alnum:]":["\\p{L}\\p{Nl}\\p{Nd}",!0],"[:alpha:]":["\\p{L}\\p{Nl}",!0],"[:ascii:]":["\\x00-\\x7f",!1],"[:blank:]":["\\p{Zs}\\t",!0],"[:cntrl:]":["\\p{Cc}",!0],"[:digit:]":["\\p{Nd}",!0],"[:graph:]":["\\p{Z}\\p{C}",!0,!0],"[:lower:]":["\\p{Ll}",!0],"[:print:]":["\\p{C}",!0],"[:punct:]":["\\p{P}",!0],"[:space:]":["\\p{Z}\\t\\r\\n\\v\\f",!0],"[:upper:]":["\\p{Lu}",!0],"[:word:]":["\\p{L}\\p{Nl}\\p{Nd}\\p{Pc}",!0],"[:xdigit:]":["A-Fa-f0-9",!1]},tA=t=>t.replace(/[[\]\\-]/g,"\\$&"),ty=(t,e)=>{if("["!==t.charAt(e))throw Error("not in a brace expression");let r=[],n=[],i=e+1,a=!1,o=!1,s=!1,l=!1,u=e,c="";t:for(;i<t.length;){let h=t.charAt(i);if("!"!==h&&"^"!==h||i!==e+1){if("]"===h&&a&&!s){u=i+1;break}if(a=!0,"\\"!==h||s){if("["===h&&!s){for(let[a,[s,l,u]]of Object.entries(tb))if(t.startsWith(a,i)){if(c)return["$.",!1,t.length-e,!0];i+=a.length,u?n.push(s):r.push(s),o=o||l;continue t}}s=!1,c?(h>c?r.push(tA(c)+"-"+tA(h)):h===c&&r.push(tA(h)),c="",i++):t.startsWith("-]",i+1)?(r.push(tA(h+"-")),i+=2):t.startsWith("-",i+1)?(c=h,i+=2):(r.push(tA(h)),i++)}else s=!0,i++}else l=!0,i++}if(u<i)return["",!1,0,!1];if(!r.length&&!n.length)return["$.",!1,t.length-e,!0];if(0===n.length&&1===r.length&&/^\\?.$/.test(r[0])&&!l)return[(2===r[0].length?r[0].slice(-1):r[0]).replace(/[-[\]{}()*+?.,\\^$|#\s]/g,"\\$&"),!1,u-e,!1];let h="["+(l?"^":"")+r.join("")+"]",d="["+(l?"":"^")+n.join("")+"]";return[r.length&&n.length?"("+h+"|"+d+")":r.length?h:d,o,u-e,!0]},tx=function(t){let{windowsPathsNoEscape:e=!1}=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e?t.replace(/\[([^\/\\])\]/g,"$1"):t.replace(/((?!\\).|^)\[([^\/\\])\]/g,"$1$2").replace(/\\([^\/])/g,"$1")},tC=new Set(["!","?","+","*","@"]),tE=t=>tC.has(t),tw=new Map([["!",["@"]],["?",["?","@"]],["@",["@"]],["*",["*","+","?","@"]],["+",["+","@"]]]),t_=new Map([["!",["?"]],["@",["?"]],["+",["?","*"]]]),tN=new Map([["!",["?","@"]],["?",["?","@"]],["@",["?","@"]],["*",["*","+","?","@"]],["+",["+","@","?","*"]]]),tP=new Map([["!",new Map([["!","@"]])],["?",new Map([["*","*"],["+","*"]])],["@",new Map([["!","!"],["?","?"],["@","@"],["*","*"],["+","+"]])],["+",new Map([["?","*"],["*","*"]])]]),tS="(?!\\.)",tk=new Set(["[","."]),tT=new Set(["..","."]),tB=new Set("().*{}+?[]^$\\!"),t$="[^/]",tO=t$+"*?",tj=t$+"+?";class tD{type;#t;#e;#r=!1;#n=[];#i;#a;#o;#s=!1;#l;#u;#c=!1;constructor(t,e){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};this.type=t,t&&(this.#e=!0),this.#i=e,this.#t=this.#i?this.#i.#t:this,this.#l=this.#t===this?r:this.#t.#l,this.#o=this.#t===this?[]:this.#t.#o,"!"!==t||this.#t.#s||this.#o.push(this),this.#a=this.#i?this.#i.#n.length:0}get hasMagic(){if(void 0!==this.#e)return this.#e;for(let t of this.#n)if("string"!=typeof t&&(t.type||t.hasMagic))return this.#e=!0;return this.#e}toString(){return void 0!==this.#u?this.#u:this.type?this.#u=this.type+"("+this.#n.map(t=>String(t)).join("|")+")":this.#u=this.#n.map(t=>String(t)).join("")}#h(){let t;if(this!==this.#t)throw Error("should only call on root");if(this.#s)return this;for(this.toString(),this.#s=!0;t=this.#o.pop();){if("!"!==t.type)continue;let e=t,r=e.#i;for(;r;){for(let n=e.#a+1;!r.type&&n<r.#n.length;n++)for(let e of t.#n){if("string"==typeof e)throw Error("string part in extglob AST??");e.copyIn(r.#n[n])}r=(e=r).#i}}return this}push(){for(var t=arguments.length,e=Array(t),r=0;r<t;r++)e[r]=arguments[r];for(let t of e)if(""!==t){if("string"!=typeof t&&!(t instanceof b&&t.#i===this))throw Error("invalid part: "+t);this.#n.push(t)}}toJSON(){let t=null===this.type?this.#n.slice().map(t=>"string"==typeof t?t:t.toJSON()):[this.type,...this.#n.map(t=>t.toJSON())];return this.isStart()&&!this.type&&t.unshift([]),this.isEnd()&&(this===this.#t||this.#t.#s&&"!"===this.#i?.type)&&t.push({}),t}isStart(){if(this.#t===this)return!0;if(!this.#i?.isStart())return!1;if(0===this.#a)return!0;let t=this.#i;for(let e=0;e<this.#a;e++){let r=t.#n[e];if(!(r instanceof b&&"!"===r.type))return!1}return!0}isEnd(){if(this.#t===this||"!"===this.#i?.type)return!0;if(!this.#i?.isEnd())return!1;if(!this.type)return this.#i?.isEnd();let t=this.#i?this.#i.#n.length:0;return this.#a===t-1}copyIn(t){"string"==typeof t?this.push(t):this.push(t.clone(this))}clone(t){let e=new b(this.type,t);for(let t of this.#n)e.copyIn(t);return e}static #d(t,e,r,n,i){let a=n.maxExtglobRecursion??2,o=!1,s=!1,l=-1,u=!1;if(null===e.type){let c=r,h="";for(;c<t.length;){let r=t.charAt(c++);if(o||"\\"===r)o=!o,h+=r;else if(s)c===l+1?"^"!==r&&"!"!==r||(u=!0):"]"!==r||c===l+2&&u||(s=!1),h+=r;else if("["!==r)if(!n.noext&&tE(r)&&"("===t.charAt(c)&&i<=a){e.push(h),h="";let a=new b(r,e);c=b.#d(t,a,c,n,i+1),e.push(a)}else h+=r;else s=!0,l=c,u=!1,h+=r}return e.push(h),c}let c=r+1,h=new b(null,e),d=[],p="";for(;c<t.length;){let r=t.charAt(c++);if(o||"\\"===r)o=!o,p+=r;else if(s)c===l+1?"^"!==r&&"!"!==r||(u=!0):"]"!==r||c===l+2&&u||(s=!1),p+=r;else if("["!==r)if(tE(r)&&"("===t.charAt(c)&&(i<=a||e&&e.#p(r))){let a=e&&e.#p(r)?0:1;h.push(p),p="";let o=new b(r,h);h.push(o),c=b.#d(t,o,c,n,i+a)}else if("|"!==r){if(")"===r)return""===p&&0===e.#n.length&&(e.#c=!0),h.push(p),p="",e.push(...d,h),c;p+=r}else h.push(p),p="",d.push(h),h=new b(null,e);else s=!0,l=c,u=!1,p+=r}return e.type=null,e.#e=void 0,e.#n=[t.substring(r-1)],c}#f(t){return this.#g(t,t_)}#g(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:tw;if(!t||"object"!=typeof t||null!==t.type||1!==t.#n.length||null===this.type)return!1;let r=t.#n[0];return!(!r||"object"!=typeof r||null===r.type)&&this.#p(r.type,e)}#p(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:tN;return!!e.get(this.type)?.includes(t)}#m(t,e){let r=t.#n[0],n=new b(null,r,this.options);n.#n.push(""),r.push(n),this.#v(t,e)}#v(t,e){let r=t.#n[0];for(let t of(this.#n.splice(e,1,...r.#n),r.#n))"object"==typeof t&&(t.#i=this);this.#u=void 0}#b(t){let e=tP.get(this.type);return!!e?.has(t)}#A(t){if(!t||"object"!=typeof t||null!==t.type||1!==t.#n.length||null===this.type||1!==this.#n.length)return!1;let e=t.#n[0];return!(!e||"object"!=typeof e||null===e.type)&&this.#b(e.type)}#y(t){let e=tP.get(this.type),r=t.#n[0],n=e?.get(r.type);if(!n)return!1;for(let t of(this.#n=r.#n,this.#n))"object"==typeof t&&(t.#i=this);this.type=n,this.#u=void 0,this.#c=!1}#x(){if(tE(this.type)){let t=0,e=!1;do{e=!0;for(let t=0;t<this.#n.length;t++){let r=this.#n[t];"object"==typeof r&&(r.#x(),this.#g(r)?(e=!1,this.#v(r,t)):this.#f(r)?(e=!1,this.#m(r,t)):this.#A(r)&&(e=!1,this.#y(r)))}}while(!e&&++t<10)}else for(let t of this.#n)"object"==typeof t&&t.#x();this.#u=void 0}static fromGlob(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},r=new b(null,void 0,e);return b.#d(t,r,0,e,0),r}toMMPattern(){if(this!==this.#t)return this.#t.toMMPattern();let t=this.toString(),[e,r,n,i]=this.toRegExpSource();return n||this.#e||this.#l.nocase&&!this.#l.nocaseMagicOnly&&t.toUpperCase()!==t.toLowerCase()?Object.assign(RegExp(`^${e}$`,(this.#l.nocase?"i":"")+(i?"u":"")),{_src:e,_glob:t}):r}get options(){return this.#l}toRegExpSource(t){let e=t??!!this.#l.dot;if(this.#t===this&&(this.#x(),this.#h()),!tE(this.type)){let r=this.isStart()&&this.isEnd(),n=this.#n.map(e=>{let[n,i,a,o]="string"==typeof e?b.#C(e,this.#e,r):e.toRegExpSource(t);return this.#e=this.#e||a,this.#r=this.#r||o,n}).join(""),i="";if(this.isStart()&&"string"==typeof this.#n[0]&&(1!==this.#n.length||!tT.has(this.#n[0]))){let r=e&&tk.has(n.charAt(0))||n.startsWith("\\.")&&tk.has(n.charAt(2))||n.startsWith("\\.\\.")&&tk.has(n.charAt(4)),a=!e&&!t&&tk.has(n.charAt(0));i=r?"(?!(?:^|/)\\.\\.?(?:$|/))":a?tS:""}let a="";return this.isEnd()&&this.#t.#s&&"!"===this.#i?.type&&(a="(?:$|\\/)"),[i+n+a,tx(n),this.#e=!!this.#e,this.#r]}let r="*"===this.type||"+"===this.type,n="!"===this.type?"(?:(?!(?:":"(?:",i=this.#E(e);if(this.isStart()&&this.isEnd()&&!i&&"!"!==this.type){let t=this.toString();return this.#n=[t],this.type=null,this.#e=void 0,[t,tx(this.toString()),!1,!1]}let a=!r||t||e?"":this.#E(!0);a===i&&(a=""),a&&(i=`(?:${i})(?:${a})*?`);return["!"===this.type&&this.#c?(this.isStart()&&!e?tS:"")+tj:n+i+("!"===this.type?"))"+(!this.isStart()||e||t?"":tS)+tO+")":"@"===this.type?")":"?"===this.type?")?":"+"===this.type&&a?")":"*"===this.type&&a?")?":`)${this.type}`),tx(i),this.#e=!!this.#e,this.#r]}#E(t){return this.#n.map(e=>{if("string"==typeof e)throw Error("string type in extglob ast??");let[r,n,i,a]=e.toRegExpSource(t);return this.#r=this.#r||a,r}).filter(t=>!(this.isStart()&&this.isEnd()&&!t)).join("|")}static #C(t,e){let r=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=!1,i="",a=!1,o=!1;for(let s=0;s<t.length;s++){let l=t.charAt(s);if(n)n=!1,i+=(tB.has(l)?"\\":"")+l,o=!1;else if("\\"!==l){if("["===l){let[r,n,l,u]=ty(t,s);if(l){i+=r,a=a||n,s+=l-1,e=e||u,o=!1;continue}}if("*"!==l)o=!1,"?"!==l?i+=l.replace(/[-[\]{}()*+?.,\\^$|#\s]/g,"\\$&"):(i+=t$,e=!0);else{if(o)continue;o=!0,i+=r&&/^[*]+$/.test(t)?tj:tO,e=!0}}else s===t.length-1?i+="\\\\":n=!0}return[i,tx(t),!!e,a]}}b=tD;let tL=function(t,e){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return tv(e),!(!r.nocomment&&"#"===e.charAt(0))&&new t0(e,r).match(t)},tI=/^\*+([^+@!?\*\[\(]*)$/,tR=/^\*+\.\*+$/,tM=t=>!t.startsWith(".")&&t.includes("."),tF=t=>"."!==t&&".."!==t&&t.includes("."),tU=/^\.\*+$/,tV=t=>"."!==t&&".."!==t&&t.startsWith("."),tG=/^\*+$/,tW=t=>0!==t.length&&!t.startsWith("."),tz=t=>0!==t.length&&"."!==t&&".."!==t,tX=/^\?+([^+@!?\*\[\(]*)?$/,tq=t=>{let[e]=t,r=e.length;return t=>t.length===r&&!t.startsWith(".")},tH=t=>{let[e]=t,r=e.length;return t=>t.length===r&&"."!==t&&".."!==t},tY="object"==typeof y&&y?"object"==typeof y.env&&y.env&&y.env.__MINIMATCH_TESTING_PLATFORM__||y.platform:"posix";tL.sep="win32"===tY?"\\":"/";let tZ=Symbol("globstar **");tL.GLOBSTAR=tZ,tL.filter=function(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return r=>tL(r,t,e)};let tK=function(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return Object.assign({},t,e)};tL.defaults=t=>{if(!t||"object"!=typeof t||!Object.keys(t).length)return tL;let e=tL;return Object.assign(function(r,n){return e(r,n,tK(t,arguments.length>2&&void 0!==arguments[2]?arguments[2]:{}))},{Minimatch:class extends e.Minimatch{constructor(e){super(e,tK(t,arguments.length>1&&void 0!==arguments[1]?arguments[1]:{}))}static defaults(r){return e.defaults(tK(t,r)).Minimatch}},AST:class extends e.AST{constructor(e,r){super(e,r,tK(t,arguments.length>2&&void 0!==arguments[2]?arguments[2]:{}))}static fromGlob(r){let n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e.AST.fromGlob(r,tK(t,n))}},unescape:function(r){let n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e.unescape(r,tK(t,n))},escape:function(r){let n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e.escape(r,tK(t,n))},filter:function(r){let n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e.filter(r,tK(t,n))},defaults:r=>e.defaults(tK(t,r)),makeRe:function(r){let n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e.makeRe(r,tK(t,n))},braceExpand:function(r){let n=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e.braceExpand(r,tK(t,n))},match:function(r,n){let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return e.match(r,n,tK(t,i))},sep:e.sep,GLOBSTAR:tZ})};let tQ=function(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return tv(t),e.nobrace||!/\{(?:(?!\{).)*\}/.test(t)?[t]:tm(t)};tL.braceExpand=tQ,tL.makeRe=function(t){return new t0(t,arguments.length>1&&void 0!==arguments[1]?arguments[1]:{}).makeRe()},tL.match=function(t,e){let r=new t0(e,arguments.length>2&&void 0!==arguments[2]?arguments[2]:{});return t=t.filter(t=>r.match(t)),r.options.nonull&&!t.length&&t.push(e),t};let tJ=/[?*]|[+@!]\(.*?\)|\[|\]/;class t0{options;set;pattern;windowsPathsNoEscape;nonegate;negate;comment;empty;preserveMultipleSlashes;partial;globSet;globParts;nocase;isWindows;platform;windowsNoMagicRoot;maxGlobstarRecursion;regexp;constructor(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};tv(t),e=e||{},this.options=e,this.maxGlobstarRecursion=e.maxGlobstarRecursion??200,this.pattern=t,this.platform=e.platform||tY,this.isWindows="win32"===this.platform,this.windowsPathsNoEscape=!!e.windowsPathsNoEscape||!1===e.allowWindowsEscape,this.windowsPathsNoEscape&&(this.pattern=this.pattern.replace(/\\/g,"/")),this.preserveMultipleSlashes=!!e.preserveMultipleSlashes,this.regexp=null,this.negate=!1,this.nonegate=!!e.nonegate,this.comment=!1,this.empty=!1,this.partial=!!e.partial,this.nocase=!!this.options.nocase,this.windowsNoMagicRoot=void 0!==e.windowsNoMagicRoot?e.windowsNoMagicRoot:!(!this.isWindows||!this.nocase),this.globSet=[],this.globParts=[],this.set=[],this.make()}hasMagic(){if(this.options.magicalBraces&&this.set.length>1)return!0;for(let t of this.set)for(let e of t)if("string"!=typeof e)return!0;return!1}debug(){}make(){let t=this.pattern,e=this.options;if(!e.nocomment&&"#"===t.charAt(0))return void(this.comment=!0);if(!t)return void(this.empty=!0);this.parseNegate(),this.globSet=[...new Set(this.braceExpand())],e.debug&&(this.debug=function(){return console.error(...arguments)}),this.debug(this.pattern,this.globSet);let r=this.globSet.map(t=>this.slashSplit(t));this.globParts=this.preprocess(r),this.debug(this.pattern,this.globParts);let n=this.globParts.map((t,e,r)=>{if(this.isWindows&&this.windowsNoMagicRoot){let e=!(""!==t[0]||""!==t[1]||"?"!==t[2]&&tJ.test(t[2])||tJ.test(t[3])),r=/^[a-z]:/i.test(t[0]);if(e)return[...t.slice(0,4),...t.slice(4).map(t=>this.parse(t))];if(r)return[t[0],...t.slice(1).map(t=>this.parse(t))]}return t.map(t=>this.parse(t))});if(this.debug(this.pattern,n),this.set=n.filter(t=>-1===t.indexOf(!1)),this.isWindows)for(let t=0;t<this.set.length;t++){let e=this.set[t];""===e[0]&&""===e[1]&&"?"===this.globParts[t][2]&&"string"==typeof e[3]&&/^[a-z]:$/i.test(e[3])&&(e[2]="?")}this.debug(this.pattern,this.set)}preprocess(t){if(this.options.noglobstar)for(let e=0;e<t.length;e++)for(let r=0;r<t[e].length;r++)"**"===t[e][r]&&(t[e][r]="*");let{optimizationLevel:e=1}=this.options;return e>=2?(t=this.firstPhasePreProcess(t),t=this.secondPhasePreProcess(t)):t=e>=1?this.levelOneOptimize(t):this.adjascentGlobstarOptimize(t),t}adjascentGlobstarOptimize(t){return t.map(t=>{let e=-1;for(;-1!==(e=t.indexOf("**",e+1));){let r=e;for(;"**"===t[r+1];)r++;r!==e&&t.splice(e,r-e)}return t})}levelOneOptimize(t){return t.map(t=>0===(t=t.reduce((t,e)=>{let r=t[t.length-1];return"**"===e&&"**"===r||(".."===e&&r&&".."!==r&&"."!==r&&"**"!==r?t.pop():t.push(e)),t},[])).length?[""]:t)}levelTwoFileOptimize(t){Array.isArray(t)||(t=this.slashSplit(t));let e=!1;do{if(e=!1,!this.preserveMultipleSlashes){for(let r=1;r<t.length-1;r++){let n=t[r];1===r&&""===n&&""===t[0]||"."!==n&&""!==n||(e=!0,t.splice(r,1),r--)}"."!==t[0]||2!==t.length||"."!==t[1]&&""!==t[1]||(e=!0,t.pop())}let r=0;for(;-1!==(r=t.indexOf("..",r+1));){let n=t[r-1];n&&"."!==n&&".."!==n&&"**"!==n&&(e=!0,t.splice(r-1,2),r-=2)}}while(e);return 0===t.length?[""]:t}firstPhasePreProcess(t){let e=!1;do for(let r of(e=!1,t)){let n=-1;for(;-1!==(n=r.indexOf("**",n+1));){let i=n;for(;"**"===r[i+1];)i++;i>n&&r.splice(n+1,i-n);let a=r[n+1],o=r[n+2],s=r[n+3];if(".."!==a||!o||"."===o||".."===o||!s||"."===s||".."===s)continue;e=!0,r.splice(n,1);let l=r.slice(0);l[n]="**",t.push(l),n--}if(!this.preserveMultipleSlashes){for(let t=1;t<r.length-1;t++){let n=r[t];1===t&&""===n&&""===r[0]||"."!==n&&""!==n||(e=!0,r.splice(t,1),t--)}"."!==r[0]||2!==r.length||"."!==r[1]&&""!==r[1]||(e=!0,r.pop())}let i=0;for(;-1!==(i=r.indexOf("..",i+1));){let t=r[i-1];if(t&&"."!==t&&".."!==t&&"**"!==t){e=!0;let t=1===i&&"**"===r[i+1]?["."]:[];r.splice(i-1,2,...t),0===r.length&&r.push(""),i-=2}}}while(e);return t}secondPhasePreProcess(t){for(let e=0;e<t.length-1;e++)for(let r=e+1;r<t.length;r++){let n=this.partsMatch(t[e],t[r],!this.preserveMultipleSlashes);if(n){t[e]=[],t[r]=n;break}}return t.filter(t=>t.length)}partsMatch(t,e){let r=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=0,i=0,a=[],o="";for(;n<t.length&&i<e.length;)if(t[n]===e[i])a.push("b"===o?e[i]:t[n]),n++,i++;else if(r&&"**"===t[n]&&e[i]===t[n+1])a.push(t[n]),n++;else if(r&&"**"===e[i]&&t[n]===e[i+1])a.push(e[i]),i++;else if("*"!==t[n]||!e[i]||!this.options.dot&&e[i].startsWith(".")||"**"===e[i]){if("*"!==e[i]||!t[n]||!this.options.dot&&t[n].startsWith(".")||"**"===t[n]||"a"===o)return!1;o="b",a.push(e[i]),n++,i++}else{if("b"===o)return!1;o="a",a.push(t[n]),n++,i++}return t.length===e.length&&a}parseNegate(){if(this.nonegate)return;let t=this.pattern,e=!1,r=0;for(let n=0;n<t.length&&"!"===t.charAt(n);n++)e=!e,r++;r&&(this.pattern=t.slice(r)),this.negate=e}matchOne(t,e){let r=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=0,i=0;if(this.isWindows){let r="string"==typeof t[0]&&/^[a-z]:$/i.test(t[0]),a=!r&&""===t[0]&&""===t[1]&&"?"===t[2]&&/^[a-z]:$/i.test(t[3]),o="string"==typeof e[0]&&/^[a-z]:$/i.test(e[0]),s=a?3:r?0:void 0,l=!o&&""===e[0]&&""===e[1]&&"?"===e[2]&&"string"==typeof e[3]&&/^[a-z]:$/i.test(e[3])?3:o?0:void 0;if("number"==typeof s&&"number"==typeof l){let[r,a]=[t[s],e[l]];r.toLowerCase()===a.toLowerCase()&&(e[l]=r,i=l,n=s)}}let{optimizationLevel:a=1}=this.options;return a>=2&&(t=this.levelTwoFileOptimize(t)),e.includes(tZ)?this.#w(t,e,r,n,i):this.#_(t,e,r,n,i)}#w(t,e,r,n,i){let a=e.indexOf(tZ,i),o=e.lastIndexOf(tZ),[s,l,u]=r?[e.slice(i,a),e.slice(a+1),[]]:[e.slice(i,a),e.slice(a+1,o),e.slice(o+1)];if(s.length){let e=t.slice(n,n+s.length);if(!this.#_(e,s,r,0,0))return!1;n+=s.length}let c=0;if(u.length){if(u.length+n>t.length)return!1;let e=t.length-u.length;if(this.#_(t,u,r,e,0))c=u.length;else{if(""!==t[t.length-1]||n+u.length===t.length||(e--,!this.#_(t,u,r,e,0)))return!1;c=u.length+1}}if(!l.length){let e=!!c;for(let r=n;r<t.length-c;r++){let n=String(t[r]);if(e=!0,"."===n||".."===n||!this.options.dot&&n.startsWith("."))return!1}return r||e}let h=[[[],0]],d=h[0],p=0,f=[0];for(let t of l)t===tZ?(f.push(p),d=[[],0],h.push(d)):(d[0].push(t),p++);let g=h.length-1,m=t.length-c;for(let t of h)t[1]=m-(f[g--]+t[0].length);return!!this.#N(t,h,n,0,r,0,!!c)}#N(t,e,r,n,i,a,o){let s=e[n];if(!s){for(let e=r;e<t.length;e++){o=!0;let r=t[e];if("."===r||".."===r||!this.options.dot&&r.startsWith("."))return!1}return o}let[l,u]=s;for(;r<=u;){if(this.#_(t.slice(0,r+l.length),l,i,r,0)&&a<this.maxGlobstarRecursion){let s=this.#N(t,e,r+l.length,n+1,i,a+1,o);if(!1!==s)return s}let s=t[r];if("."===s||".."===s||!this.options.dot&&s.startsWith("."))return!1;r++}return i||null}#_(t,e,r,n,i){let a,o,s,l;for(a=n,o=i,l=t.length,s=e.length;a<l&&o<s;a++,o++){this.debug("matchOne loop");let r,n=e[o],i=t[a];if(this.debug(e,n,i),!1===n||n===tZ||("string"==typeof n?(r=i===n,this.debug("string match",n,i,r)):(r=n.test(i),this.debug("pattern match",n,i,r)),!r))return!1}if(a===l&&o===s)return!0;if(a===l)return r;if(o===s)return a===l-1&&""===t[a];throw Error("wtf?")}braceExpand(){return tQ(this.pattern,this.options)}parse(t){tv(t);let e=this.options;if("**"===t)return tZ;if(""===t)return"";let r,n=null;(r=t.match(tG))?n=e.dot?tz:tW:(r=t.match(tI))?n=(e.nocase?e.dot?t=>(t=t.toLowerCase(),e=>e.toLowerCase().endsWith(t)):t=>(t=t.toLowerCase(),e=>!e.startsWith(".")&&e.toLowerCase().endsWith(t)):e.dot?t=>e=>e.endsWith(t):t=>e=>!e.startsWith(".")&&e.endsWith(t))(r[1]):(r=t.match(tX))?n=(e.nocase?e.dot?t=>{let[e,r=""]=t,n=tH([e]);return r?(r=r.toLowerCase(),t=>n(t)&&t.toLowerCase().endsWith(r)):n}:t=>{let[e,r=""]=t,n=tq([e]);return r?(r=r.toLowerCase(),t=>n(t)&&t.toLowerCase().endsWith(r)):n}:e.dot?t=>{let[e,r=""]=t,n=tH([e]);return r?t=>n(t)&&t.endsWith(r):n}:t=>{let[e,r=""]=t,n=tq([e]);return r?t=>n(t)&&t.endsWith(r):n})(r):(r=t.match(tR))?n=e.dot?tF:tM:(r=t.match(tU))&&(n=tV);let i=tD.fromGlob(t,this.options).toMMPattern();return n&&"object"==typeof i&&Reflect.defineProperty(i,"test",{value:n}),i}makeRe(){if(this.regexp||!1===this.regexp)return this.regexp;let t=this.set;if(!t.length)return this.regexp=!1,this.regexp;let e=this.options,r=e.noglobstar?"[^/]*?":e.dot?"(?:(?!(?:\\/|^)(?:\\.{1,2})($|\\/)).)*?":"(?:(?!(?:\\/|^)\\.).)*?",n=new Set(e.nocase?["i"]:[]),i=t.map(t=>{let e=t.map(t=>{if(t instanceof RegExp)for(let e of t.flags.split(""))n.add(e);return"string"==typeof t?t.replace(/[-[\]{}()*+?.,\\^$|#\s]/g,"\\$&"):t===tZ?tZ:t._src});return e.forEach((t,n)=>{let i=e[n+1],a=e[n-1];t===tZ&&a!==tZ&&(void 0===a?void 0!==i&&i!==tZ?e[n+1]="(?:\\/|"+r+"\\/)?"+i:e[n]=r:void 0===i?e[n-1]=a+"(?:\\/|"+r+")?":i!==tZ&&(e[n-1]=a+"(?:\\/|\\/"+r+"\\/)"+i,e[n+1]=tZ))}),e.filter(t=>t!==tZ).join("/")}).join("|"),[a,o]=t.length>1?["(?:",")"]:["",""];i="^"+a+i+o+"$",this.negate&&(i="^(?!"+i+").+$");try{this.regexp=new RegExp(i,[...n].join(""))}catch(t){this.regexp=!1}return this.regexp}slashSplit(t){return this.preserveMultipleSlashes?t.split("/"):this.isWindows&&/^\/\/[^\/]+/.test(t)?["",...t.split(/\/+/)]:t.split(/\/+/)}match(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:this.partial;if(this.debug("match",t,this.pattern),this.comment)return!1;if(this.empty)return""===t;if("/"===t&&e)return!0;let r=this.options;this.isWindows&&(t=t.split("\\").join("/"));let n=this.slashSplit(t);this.debug(this.pattern,"split",n);let i=this.set;this.debug(this.pattern,"set",i);let a=n[n.length-1];if(!a)for(let t=n.length-2;!a&&t>=0;t--)a=n[t];for(let t=0;t<i.length;t++){let o=i[t],s=n;if(r.matchBase&&1===o.length&&(s=[a]),this.matchOne(s,o,e))return!!r.flipNegate||!this.negate}return!r.flipNegate&&this.negate}static defaults(t){return tL.defaults(t).Minimatch}}function t1(t){let e=Error(`${arguments.length>1&&void 0!==arguments[1]?arguments[1]:""}Invalid response: ${t.status} ${t.statusText}`);return e.status=t.status,e.response=t,e}function t2(t,e){let{status:r}=e;if(401===r&&t.digest)return e;if(r>=400)throw t1(e);return e}function t3(t,e){return arguments.length>2&&void 0!==arguments[2]&&arguments[2]?{data:e,headers:t.headers?function(t){let e={};for(let r of t.keys())e[r]=t.get(r);return e}(t.headers):{},status:t.status,statusText:t.statusText}:e}tL.AST=tD,tL.Minimatch=t0,tL.escape=function(t){let{windowsPathsNoEscape:e=!1}=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};return e?t.replace(/[?*()[\]]/g,"[$&]"):t.replace(/[?*()[\]\\]/g,"\\$&")},tL.unescape=tx;let t4=(A=function(t,e,r){var n,i;let a=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{},o=tf({url:L(t.remoteURL,O(e)),method:"COPY",headers:{Destination:L(t.remoteURL,O(r)),Overwrite:!1===a.overwrite?"F":"T",Depth:a.shallow?"0":"infinity"}},t,a);return n=function(e){t2(t,e)},(i=tp(o,t))&&i.then||(i=Promise.resolve(i)),n?i.then(n):i},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(A.apply(this,t))}catch(t){return Promise.reject(t)}}),t8=":A-Za-z_\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD",t9=RegExp("^["+t8+"]["+t8+"\\-.\\d\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$");function t7(t,e){let r=[],n=e.exec(t);for(;n;){let i=[];i.startIndex=e.lastIndex-n[0].length;let a=n.length;for(let t=0;t<a;t++)i.push(n[t]);r.push(i),n=e.exec(t)}return r}let t6=function(t){return null!=t9.exec(t)},t5=["hasOwnProperty","toString","valueOf","__defineGetter__","__defineSetter__","__lookupGetter__","__lookupSetter__"],et=["__proto__","constructor","prototype"],ee=t=>t5.includes(t)?"__"+t:t,er={preserveOrder:!1,attributeNamePrefix:"@_",attributesGroupName:!1,textNodeName:"#text",ignoreAttributes:!0,removeNSPrefix:!1,allowBooleanAttributes:!1,parseTagValue:!0,parseAttributeValue:!1,trimValues:!0,cdataPropName:!1,numberParseOptions:{hex:!0,leadingZeros:!0,eNotation:!0},tagValueProcessor:function(t,e){return e},attributeValueProcessor:function(t,e){return e},stopNodes:[],alwaysCreateTextNode:!1,isArray:()=>!1,commentPropName:!1,unpairedTags:[],processEntities:!0,htmlEntities:!1,entityDecoder:null,ignoreDeclaration:!1,ignorePiTags:!1,transformTagName:!1,transformAttributeName:!1,updateTag:function(t,e,r){return t},captureMetaData:!1,maxNestedTags:100,strictReservedNames:!0,jPath:!0,onDangerousProperty:ee},en=function(t){let e=Object.assign({},er,t);for(let{value:t,name:r}of[{value:e.attributeNamePrefix,name:"attributeNamePrefix"},{value:e.attributesGroupName,name:"attributesGroupName"},{value:e.textNodeName,name:"textNodeName"},{value:e.cdataPropName,name:"cdataPropName"},{value:e.commentPropName,name:"commentPropName"}])t&&function(t,e){if("string"!=typeof t)return;let r=t.toLowerCase();if(t5.some(t=>r===t.toLowerCase())||et.some(t=>r===t.toLowerCase()))throw Error(`[SECURITY] Invalid ${e}: "${t}" is a reserved JavaScript keyword that could cause prototype pollution`)}(t,r);return null===e.onDangerousProperty&&(e.onDangerousProperty=ee),e.processEntities=function t(e,r){return"boolean"==typeof e?{enabled:e,maxEntitySize:1e4,maxExpansionDepth:1e4,maxTotalExpansions:1/0,maxExpandedLength:1e5,maxEntityCount:1e3,allowedTags:null,tagFilter:null,appliesTo:"all"}:"object"==typeof e&&null!==e?{enabled:!1!==e.enabled,maxEntitySize:Math.max(1,e.maxEntitySize??1e4),maxExpansionDepth:Math.max(1,e.maxExpansionDepth??1e4),maxTotalExpansions:Math.max(1,e.maxTotalExpansions??1/0),maxExpandedLength:Math.max(1,e.maxExpandedLength??1e5),maxEntityCount:Math.max(1,e.maxEntityCount??1e3),allowedTags:e.allowedTags??null,tagFilter:e.tagFilter??null,appliesTo:e.appliesTo??"all"}:t(!0)}(e.processEntities,e.htmlEntities),e.unpairedTagsSet=new Set(e.unpairedTags),e.stopNodes&&Array.isArray(e.stopNodes)&&(e.stopNodes=e.stopNodes.map(t=>"string"==typeof t&&t.startsWith("*.")?".."+t.substring(2):t)),e};n="function"!=typeof Symbol?"@@xmlMetadata":Symbol("XML Node Metadata");class ei{constructor(t){this.tagname=t,this.child=[],this[":@"]=Object.create(null)}add(t,e){"__proto__"===t&&(t="#__proto__"),this.child.push({[t]:e})}addChild(t,e){"__proto__"===t.tagname&&(t.tagname="#__proto__"),t[":@"]&&Object.keys(t[":@"]).length>0?this.child.push({[t.tagname]:t.child,":@":t[":@"]}):this.child.push({[t.tagname]:t.child}),void 0!==e&&(this.child[this.child.length-1][n]={startIndex:e})}static getMetaDataSymbol(){return n}}class ea{constructor(t){this.suppressValidationErr=!t,this.options=t}readDocType(t,e){let r=Object.create(null),n=0;if("O"!==t[e+3]||"C"!==t[e+4]||"T"!==t[e+5]||"Y"!==t[e+6]||"P"!==t[e+7]||"E"!==t[e+8])throw Error("Invalid Tag instead of DOCTYPE");{e+=9;let i=1,a=!1,o=!1;for(;e<t.length;e++)if("<"!==t[e]||o)if(">"===t[e]){if(o?"-"===t[e-1]&&"-"===t[e-2]&&(o=!1,i--):i--,0===i)break}else"["===t[e]?a=!0:t[e];else{if(a&&es(t,"!ENTITY",e)){let i,a;if(e+=7,[i,a,e]=this.readEntityExp(t,e+1,this.suppressValidationErr),-1===a.indexOf("&")){if(!1!==this.options.enabled&&null!=this.options.maxEntityCount&&n>=this.options.maxEntityCount)throw Error(`Entity count (${n+1}) exceeds maximum allowed (${this.options.maxEntityCount})`);r[i]=a,n++}}else if(a&&es(t,"!ELEMENT",e)){e+=8;let{index:r}=this.readElementExp(t,e+1);e=r}else if(a&&es(t,"!ATTLIST",e))e+=8;else if(a&&es(t,"!NOTATION",e)){e+=9;let{index:r}=this.readNotationExp(t,e+1,this.suppressValidationErr);e=r}else{if(!es(t,"!--",e))throw Error("Invalid DOCTYPE");o=!0}i++}if(0!==i)throw Error("Unclosed DOCTYPE")}return{entities:r,i:e}}readEntityExp(t,e){let r=e=eo(t,e);for(;e<t.length&&!/\s/.test(t[e])&&'"'!==t[e]&&"'"!==t[e];)e++;let n=t.substring(r,e);if(el(n),e=eo(t,e),!this.suppressValidationErr){if("SYSTEM"===t.substring(e,e+6).toUpperCase())throw Error("External entities are not supported");if("%"===t[e])throw Error("Parameter entities are not supported")}let i="";if([e,i]=this.readIdentifierVal(t,e,"entity"),!1!==this.options.enabled&&null!=this.options.maxEntitySize&&i.length>this.options.maxEntitySize)throw Error(`Entity "${n}" size (${i.length}) exceeds maximum allowed size (${this.options.maxEntitySize})`);return[n,i,--e]}readNotationExp(t,e){let r=e=eo(t,e);for(;e<t.length&&!/\s/.test(t[e]);)e++;let n=t.substring(r,e);this.suppressValidationErr||el(n),e=eo(t,e);let i=t.substring(e,e+6).toUpperCase();if(!this.suppressValidationErr&&"SYSTEM"!==i&&"PUBLIC"!==i)throw Error(`Expected SYSTEM or PUBLIC, found "${i}"`);e+=i.length,e=eo(t,e);let a=null,o=null;if("PUBLIC"===i)[e,a]=this.readIdentifierVal(t,e,"publicIdentifier"),'"'!==t[e=eo(t,e)]&&"'"!==t[e]||([e,o]=this.readIdentifierVal(t,e,"systemIdentifier"));else if("SYSTEM"===i&&([e,o]=this.readIdentifierVal(t,e,"systemIdentifier"),!this.suppressValidationErr&&!o))throw Error("Missing mandatory system identifier for SYSTEM notation");return{notationName:n,publicIdentifier:a,systemIdentifier:o,index:--e}}readIdentifierVal(t,e,r){let n="",i=t[e];if('"'!==i&&"'"!==i)throw Error(`Expected quoted string, found "${i}"`);let a=++e;for(;e<t.length&&t[e]!==i;)e++;if(n=t.substring(a,e),t[e]!==i)throw Error(`Unterminated ${r} value`);return[++e,n]}readElementExp(t,e){let r=e=eo(t,e);for(;e<t.length&&!/\s/.test(t[e]);)e++;let n=t.substring(r,e);if(!this.suppressValidationErr&&!t6(n))throw Error(`Invalid element name: "${n}"`);let i="";if("E"===t[e=eo(t,e)]&&es(t,"MPTY",e))e+=4;else if("A"===t[e]&&es(t,"NY",e))e+=2;else if("("===t[e]){let r=++e;for(;e<t.length&&")"!==t[e];)e++;if(i=t.substring(r,e),")"!==t[e])throw Error("Unterminated content model")}else if(!this.suppressValidationErr)throw Error(`Invalid Element Expression, found "${t[e]}"`);return{elementName:n,contentModel:i.trim(),index:e}}readAttlistExp(t,e){let r=e=eo(t,e);for(;e<t.length&&!/\s/.test(t[e]);)e++;let n=t.substring(r,e);for(el(n),r=e=eo(t,e);e<t.length&&!/\s/.test(t[e]);)e++;let i=t.substring(r,e);if(!el(i))throw Error(`Invalid attribute name: "${i}"`);e=eo(t,e);let a="";if("NOTATION"===t.substring(e,e+8).toUpperCase()){if(a="NOTATION","("!==t[e=eo(t,e+=8)])throw Error(`Expected '(', found "${t[e]}"`);e++;let r=[];for(;e<t.length&&")"!==t[e];){let n=e;for(;e<t.length&&"|"!==t[e]&&")"!==t[e];)e++;let i=t.substring(n,e);if(!el(i=i.trim()))throw Error(`Invalid notation name: "${i}"`);r.push(i),"|"===t[e]&&(e=eo(t,++e))}if(")"!==t[e])throw Error("Unterminated list of notations");e++,a+=" ("+r.join("|")+")"}else{let r=e;for(;e<t.length&&!/\s/.test(t[e]);)e++;if(a+=t.substring(r,e),!this.suppressValidationErr&&!["CDATA","ID","IDREF","IDREFS","ENTITY","ENTITIES","NMTOKEN","NMTOKENS"].includes(a.toUpperCase()))throw Error(`Invalid attribute type: "${a}"`)}e=eo(t,e);let o="";return"#REQUIRED"===t.substring(e,e+8).toUpperCase()?(o="#REQUIRED",e+=8):"#IMPLIED"===t.substring(e,e+7).toUpperCase()?(o="#IMPLIED",e+=7):[e,o]=this.readIdentifierVal(t,e,"ATTLIST"),{elementName:n,attributeName:i,attributeType:a,defaultValue:o,index:e}}}let eo=(t,e)=>{for(;e<t.length&&/\s/.test(t[e]);)e++;return e};function es(t,e,r){for(let n=0;n<e.length;n++)if(e[n]!==t[r+n+1])return!1;return!0}function el(t){if(t6(t))return t;throw Error(`Invalid entity name ${t}`)}let eu=/^[-+]?0x[a-fA-F0-9]+$/,ec=/^([\-\+])?(0*)([0-9]*(\.[0-9]*)?)$/,eh={hex:!0,leadingZeros:!0,decimalPoint:".",eNotation:!0,infinity:"original"},ed=/^([-+])?(0*)(\d*(\.\d*)?[eE][-\+]?\d+)$/;class ep{constructor(t){this._matcher=t}get separator(){return this._matcher.separator}getCurrentTag(){let t=this._matcher.path;return t.length>0?t[t.length-1].tag:void 0}getCurrentNamespace(){let t=this._matcher.path;return t.length>0?t[t.length-1].namespace:void 0}getAttrValue(t){let e=this._matcher.path;if(0!==e.length)return e[e.length-1].values?.[t]}hasAttr(t){let e=this._matcher.path;if(0===e.length)return!1;let r=e[e.length-1];return void 0!==r.values&&t in r.values}getPosition(){let t=this._matcher.path;return 0===t.length?-1:t[t.length-1].position??0}getCounter(){let t=this._matcher.path;return 0===t.length?-1:t[t.length-1].counter??0}getIndex(){return this.getPosition()}getDepth(){return this._matcher.path.length}toString(t){let e=!(arguments.length>1&&void 0!==arguments[1])||arguments[1];return this._matcher.toString(t,e)}toArray(){return this._matcher.path.map(t=>t.tag)}matches(t){return this._matcher.matches(t)}matchesAny(t){return t.matchesAny(this._matcher)}}class ef{constructor(){let t=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{};this.separator=t.separator||".",this.path=[],this.siblingStacks=[],this._pathStringCache=null,this._view=new ep(this)}push(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:null,r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:null;this._pathStringCache=null,this.path.length>0&&(this.path[this.path.length-1].values=void 0);let n=this.path.length;this.siblingStacks[n]||(this.siblingStacks[n]=new Map);let i=this.siblingStacks[n],a=r?`${r}:${t}`:t,o=i.get(a)||0,s=0;for(let t of i.values())s+=t;i.set(a,o+1);let l={tag:t,position:s,counter:o};null!=r&&(l.namespace=r),null!=e&&(l.values=e),this.path.push(l)}pop(){if(0===this.path.length)return;this._pathStringCache=null;let t=this.path.pop();return this.siblingStacks.length>this.path.length+1&&(this.siblingStacks.length=this.path.length+1),t}updateCurrent(t){if(this.path.length>0){let e=this.path[this.path.length-1];null!=t&&(e.values=t)}}getCurrentTag(){return this.path.length>0?this.path[this.path.length-1].tag:void 0}getCurrentNamespace(){return this.path.length>0?this.path[this.path.length-1].namespace:void 0}getAttrValue(t){if(0!==this.path.length)return this.path[this.path.length-1].values?.[t]}hasAttr(t){if(0===this.path.length)return!1;let e=this.path[this.path.length-1];return void 0!==e.values&&t in e.values}getPosition(){return 0===this.path.length?-1:this.path[this.path.length-1].position??0}getCounter(){return 0===this.path.length?-1:this.path[this.path.length-1].counter??0}getIndex(){return this.getPosition()}getDepth(){return this.path.length}toString(t){let e=!(arguments.length>1&&void 0!==arguments[1])||arguments[1],r=t||this.separator;if(r===this.separator&&!0===e){if(null!==this._pathStringCache)return this._pathStringCache;let t=this.path.map(t=>t.namespace?`${t.namespace}:${t.tag}`:t.tag).join(r);return this._pathStringCache=t,t}return this.path.map(t=>e&&t.namespace?`${t.namespace}:${t.tag}`:t.tag).join(r)}toArray(){return this.path.map(t=>t.tag)}reset(){this._pathStringCache=null,this.path=[],this.siblingStacks=[]}matches(t){let e=t.segments;return 0!==e.length&&(t.hasDeepWildcard()?this._matchWithDeepWildcard(e):this._matchSimple(e))}_matchSimple(t){if(this.path.length!==t.length)return!1;for(let e=0;e<t.length;e++)if(!this._matchSegment(t[e],this.path[e],e===this.path.length-1))return!1;return!0}_matchWithDeepWildcard(t){let e=this.path.length-1,r=t.length-1;for(;r>=0&&e>=0;){let n=t[r];if("deep-wildcard"===n.type){if(--r<0)return!0;let n=t[r],i=!1;for(let t=e;t>=0;t--)if(this._matchSegment(n,this.path[t],t===this.path.length-1)){e=t-1,r--,i=!0;break}if(!i)return!1}else{if(!this._matchSegment(n,this.path[e],e===this.path.length-1))return!1;e--,r--}}return r<0}_matchSegment(t,e,r){if("*"!==t.tag&&t.tag!==e.tag||void 0!==t.namespace&&"*"!==t.namespace&&t.namespace!==e.namespace||void 0!==t.attrName&&(!r||!e.values||!(t.attrName in e.values)||void 0!==t.attrValue&&String(e.values[t.attrName])!==String(t.attrValue)))return!1;if(void 0!==t.position){if(!r)return!1;let n=e.counter??0;if("first"===t.position&&0!==n||"odd"===t.position&&n%2!=1||"even"===t.position&&n%2!=0||"nth"===t.position&&n!==t.positionValue)return!1}return!0}matchesAny(t){return t.matchesAny(this)}snapshot(){return{path:this.path.map(t=>({...t})),siblingStacks:this.siblingStacks.map(t=>new Map(t))}}restore(t){this._pathStringCache=null,this.path=t.path.map(t=>({...t})),this.siblingStacks=t.siblingStacks.map(t=>new Map(t))}readOnly(){return this._view}}class eg{constructor(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},r=arguments.length>2?arguments[2]:void 0;this.pattern=t,this.separator=e.separator||".",this.segments=this._parse(t),this.data=r,this._hasDeepWildcard=this.segments.some(t=>"deep-wildcard"===t.type),this._hasAttributeCondition=this.segments.some(t=>void 0!==t.attrName),this._hasPositionSelector=this.segments.some(t=>void 0!==t.position)}_parse(t){let e=[],r=0,n="";for(;r<t.length;)t[r]===this.separator?r+1<t.length&&t[r+1]===this.separator?(n.trim()&&(e.push(this._parseSegment(n.trim())),n=""),e.push({type:"deep-wildcard"}),r+=2):(n.trim()&&e.push(this._parseSegment(n.trim())),n="",r++):(n+=t[r],r++);return n.trim()&&e.push(this._parseSegment(n.trim())),e}_parseSegment(t){let e={type:"tag"},r=null,n=t,i=t.match(/^([^\[]+)(\[[^\]]*\])(.*)$/);if(i&&(n=i[1]+i[3],i[2])){let t=i[2].slice(1,-1);t&&(r=t)}let a,o,s=n;if(n.includes("::")){let e=n.indexOf("::");if(a=n.substring(0,e).trim(),s=n.substring(e+2).trim(),!a)throw Error(`Invalid namespace in pattern: ${t}`)}let l=null;if(s.includes(":")){let t=s.lastIndexOf(":"),e=s.substring(0,t).trim(),r=s.substring(t+1).trim();["first","last","odd","even"].includes(r)||/^nth\(\d+\)$/.test(r)?(o=e,l=r):o=s}else o=s;if(!o)throw Error(`Invalid segment pattern: ${t}`);if(e.tag=o,a&&(e.namespace=a),r)if(r.includes("=")){let t=r.indexOf("=");e.attrName=r.substring(0,t).trim(),e.attrValue=r.substring(t+1).trim()}else e.attrName=r.trim();if(l){let t=l.match(/^nth\((\d+)\)$/);t?(e.position="nth",e.positionValue=parseInt(t[1],10)):e.position=l}return e}get length(){return this.segments.length}hasDeepWildcard(){return this._hasDeepWildcard}hasAttributeCondition(){return this._hasAttributeCondition}hasPositionSelector(){return this._hasPositionSelector}toString(){return this.pattern}}class em{constructor(){this._byDepthAndTag=new Map,this._wildcardByDepth=new Map,this._deepWildcards=[],this._patterns=new Set,this._sealed=!1}add(t){if(this._sealed)throw TypeError("ExpressionSet is sealed. Create a new ExpressionSet to add more expressions.");if(this._patterns.has(t.pattern))return this;if(this._patterns.add(t.pattern),t.hasDeepWildcard())return this._deepWildcards.push(t),this;let e=t.length,r=t.segments[t.segments.length-1],n=r?.tag;if(n&&"*"!==n){let r=`${e}:${n}`;this._byDepthAndTag.has(r)||this._byDepthAndTag.set(r,[]),this._byDepthAndTag.get(r).push(t)}else this._wildcardByDepth.has(e)||this._wildcardByDepth.set(e,[]),this._wildcardByDepth.get(e).push(t);return this}addAll(t){for(let e of t)this.add(e);return this}has(t){return this._patterns.has(t.pattern)}get size(){return this._patterns.size}seal(){return this._sealed=!0,this}get isSealed(){return this._sealed}matchesAny(t){return null!==this.findMatch(t)}findMatch(t){let e=t.getDepth(),r=`${e}:${t.getCurrentTag()}`,n=this._byDepthAndTag.get(r);if(n){for(let e=0;e<n.length;e++)if(t.matches(n[e]))return n[e]}let i=this._wildcardByDepth.get(e);if(i){for(let e=0;e<i.length;e++)if(t.matches(i[e]))return i[e]}for(let e=0;e<this._deepWildcards.length;e++)if(t.matches(this._deepWildcards[e]))return this._deepWildcards[e];return null}}let ev={cent:"\xa2",pound:"\xa3",curren:"\xa4",yen:"\xa5",euro:"€",dollar:"$",euro:"€",fnof:"ƒ",inr:"₹",af:"؋",birr:"ብር",peso:"₱",rub:"₽",won:"₩",yuan:"\xa5",cedil:"\xb8"},eb={amp:"&",apos:"'",gt:">",lt:"<",quot:'"'},eA={nbsp:"\xa0",copy:"\xa9",reg:"\xae",trade:"™",mdash:"—",ndash:"–",hellip:"…",laquo:"\xab",raquo:"\xbb",lsquo:"‘",rsquo:"’",ldquo:"“",rdquo:"”",bull:"•",para:"\xb6",sect:"\xa7",deg:"\xb0",frac12:"\xbd",frac14:"\xbc",frac34:"\xbe"},ey=new Set("!?\\\\/[]$%{}^&*()<>|+");function ex(t){if("#"===t[0])throw Error(`[EntityReplacer] Invalid character '#' in entity name: "${t}"`);for(let e of t)if(ey.has(e))throw Error(`[EntityReplacer] Invalid character '${e}' in entity name: "${t}"`);return t}function eC(){let t=Object.create(null);for(var e=arguments.length,r=Array(e),n=0;n<e;n++)r[n]=arguments[n];for(let e of r)if(e)for(let r of Object.keys(e)){let n=e[r];if("string"==typeof n)t[r]=n;else if(n&&"object"==typeof n&&void 0!==n.val){let e=n.val;"string"==typeof e&&(t[r]=e)}}return t}let eE="external",ew="base",e_=Object.freeze({allow:0,leave:1,remove:2,throw:3}),eN=new Set([9,10,13]);class eP{constructor(){var t;let e=arguments.length>0&&void 0!==arguments[0]?arguments[0]:{};this._limit=e.limit||{},this._maxTotalExpansions=this._limit.maxTotalExpansions||0,this._maxExpandedLength=this._limit.maxExpandedLength||0,this._postCheck="function"==typeof e.postCheck?e.postCheck:t=>t,this._limitTiers=new Set((t=this._limit.applyLimitsTo??eE)&&t!==eE?"all"===t?["all"]:t===ew?[ew]:Array.isArray(t)?t:[eE]:[eE]),this._numericAllowed=e.numericAllowed??!0,this._baseMap=eC(eb,e.namedEntities||null),this._externalMap=Object.create(null),this._inputMap=Object.create(null),this._totalExpansions=0,this._expandedLength=0,this._removeSet=new Set(e.remove&&Array.isArray(e.remove)?e.remove:[]),this._leaveSet=new Set(e.leave&&Array.isArray(e.leave)?e.leave:[]);const r=function(t){return t?{xmlVersion:1.1===t.xmlVersion?1.1:1,onLevel:e_[t.onNCR]??e_.allow,nullLevel:Math.max(e_[t.nullNCR]??e_.remove,e_.remove)}:{xmlVersion:1,onLevel:e_.allow,nullLevel:e_.remove}}(e.ncr);this._ncrXmlVersion=r.xmlVersion,this._ncrOnLevel=r.onLevel,this._ncrNullLevel=r.nullLevel}setExternalEntities(t){if(t)for(let e of Object.keys(t))ex(e);this._externalMap=eC(t)}addExternalEntity(t,e){ex(t),"string"==typeof e&&-1===e.indexOf("&")&&(this._externalMap[t]=e)}addInputEntities(t){this._totalExpansions=0,this._expandedLength=0,this._inputMap=eC(t)}reset(){return this._inputMap=Object.create(null),this._totalExpansions=0,this._expandedLength=0,this}setXmlVersion(t){this._ncrXmlVersion=1.1===t?1.1:1}decode(t){if("string"!=typeof t||0===t.length)return t;let e=[],r=t.length,n=0,i=0,a=this._maxTotalExpansions>0,o=this._maxExpandedLength>0,s=a||o;for(;i<r;){let l,u;if(38!==t.charCodeAt(i)){i++;continue}let c=i+1;for(;c<r&&59!==t.charCodeAt(c)&&c-i<=32;)c++;if(c>=r||59!==t.charCodeAt(c)){i++;continue}let h=t.slice(i+1,c);if(0===h.length){i++;continue}if(this._removeSet.has(h))l="",void 0===u&&(u=eE);else{if(this._leaveSet.has(h)){i++;continue}if(35===h.charCodeAt(0)){let t=this._resolveNCR(h);if(void 0===t){i++;continue}l=t,u=ew}else{let t=this._resolveName(h);l=t?.value,u=t?.tier}}if(void 0!==l){if(i>n&&e.push(t.slice(n,i)),e.push(l),i=n=c+1,s&&this._tierCounts(u)){if(a&&(this._totalExpansions++,this._totalExpansions>this._maxTotalExpansions))throw Error(`[EntityReplacer] Entity expansion count limit exceeded: ${this._totalExpansions} > ${this._maxTotalExpansions}`);if(o){let t=l.length-(h.length+2);if(t>0&&(this._expandedLength+=t,this._expandedLength>this._maxExpandedLength))throw Error(`[EntityReplacer] Expanded content length limit exceeded: ${this._expandedLength} > ${this._maxExpandedLength}`)}}}else i++}n<r&&e.push(t.slice(n));let l=0===e.length?t:e.join("");return this._postCheck(l,t)}_tierCounts(t){return!!this._limitTiers.has("all")||this._limitTiers.has(t)}_resolveName(t){return t in this._inputMap?{value:this._inputMap[t],tier:eE}:t in this._externalMap?{value:this._externalMap[t],tier:eE}:t in this._baseMap?{value:this._baseMap[t],tier:ew}:void 0}_classifyNCR(t){return 0===t?this._ncrNullLevel:t>=55296&&t<=57343||1===this._ncrXmlVersion&&t>=1&&t<=31&&!eN.has(t)?e_.remove:-1}_applyNCRAction(t,e,r){switch(t){case e_.allow:return String.fromCodePoint(r);case e_.remove:return"";case e_.leave:return;case e_.throw:throw Error(`[EntityDecoder] Prohibited numeric character reference &${e}; (U+${r.toString(16).toUpperCase().padStart(4,"0")})`);default:return String.fromCodePoint(r)}}_resolveNCR(t){let e,r=t.charCodeAt(1);if(Number.isNaN(e=120===r||88===r?parseInt(t.slice(2),16):parseInt(t.slice(1),10))||e<0||e>1114111)return;let n=this._classifyNCR(e);if(!this._numericAllowed&&n<e_.remove)return;let i=-1===n?this._ncrOnLevel:Math.max(this._ncrOnLevel,n);return this._applyNCRAction(i,t,e)}}class eS{constructor(t,e){var r;this.options=t,this.currentNode=null,this.tagsNodeStack=[],this.parseXml=eO,this.parseTextData=ek,this.resolveNameSpace=eT,this.buildAttributesMap=e$,this.isItStopNode=eI,this.replaceEntitiesValue=eD,this.readStopNodeData=eF,this.saveTextToParentTag=eL,this.addChild=ej,this.ignoreAttributesFn="function"==typeof(r=this.options.ignoreAttributes)?r:Array.isArray(r)?t=>{for(let e of r)if("string"==typeof e&&t===e||e instanceof RegExp&&e.test(t))return!0}:()=>!1,this.entityExpansionCount=0,this.currentExpandedLength=0;let n={...eb};this.options.entityDecoder?this.entityDecoder=this.options.entityDecoder:("object"==typeof this.options.htmlEntities?n=this.options.htmlEntities:!0===this.options.htmlEntities&&(n={...eA,...ev}),this.entityDecoder=new eP({namedEntities:{...n,...e},numericAllowed:this.options.htmlEntities,limit:{maxTotalExpansions:this.options.processEntities.maxTotalExpansions,maxExpandedLength:this.options.processEntities.maxExpandedLength,applyLimitsTo:this.options.processEntities.appliesTo}})),this.matcher=new ef,this.readonlyMatcher=this.matcher.readOnly(),this.isCurrentNodeStopNode=!1,this.stopNodeExpressionsSet=new em;const i=this.options.stopNodes;if(i&&i.length>0){for(let t=0;t<i.length;t++){const e=i[t];"string"==typeof e?this.stopNodeExpressionsSet.add(new eg(e)):e instanceof eg&&this.stopNodeExpressionsSet.add(e)}this.stopNodeExpressionsSet.seal()}}}function ek(t,e,r,n,i,a,o){let s=this.options;if(void 0!==t&&(s.trimValues&&!n&&(t=t.trim()),t.length>0)){o||(t=this.replaceEntitiesValue(t,e,r));let n=s.jPath?r.toString():r,l=s.tagValueProcessor(e,t,n,i,a);return null==l?t:typeof l!=typeof t||l!==t?l:s.trimValues||t.trim()===t?eU(t,s.parseTagValue,s.numberParseOptions):t}}function eT(t){if(this.options.removeNSPrefix){let e=t.split(":"),r="/"===t.charAt(0)?"/":"";if("xmlns"===e[0])return"";2===e.length&&(t=r+e[1])}return t}let eB=RegExp("([^\\s=]+)\\s*(=\\s*(['\"])([\\s\\S]*?)\\3)?","gm");function e$(t,e,r){let n=arguments.length>3&&void 0!==arguments[3]&&arguments[3],i=this.options;if(!0===n||!0!==i.ignoreAttributes&&"string"==typeof t){let n=t7(t,eB),a=n.length,o={},s=Array(a),l=!1,u={};for(let t=0;t<a;t++){let e=this.resolveNameSpace(n[t][1]),a=n[t][4];if(e.length&&void 0!==a){let n=a;i.trimValues&&(n=n.trim()),n=this.replaceEntitiesValue(n,r,this.readonlyMatcher),s[t]=n,u[e]=n,l=!0}}l&&"object"==typeof e&&e.updateCurrent&&e.updateCurrent(u);let c=i.jPath?e.toString():this.readonlyMatcher,h=!1;for(let t=0;t<a;t++){let e=this.resolveNameSpace(n[t][1]);if(this.ignoreAttributesFn(e,c))continue;let r=i.attributeNamePrefix+e;if(e.length)if(i.transformAttributeName&&(r=i.transformAttributeName(r)),r=eG(r,i),void 0!==n[t][4]){let n=s[t],a=i.attributeValueProcessor(e,n,c);o[r]=null==a?n:typeof a!=typeof n||a!==n?a:eU(n,i.parseAttributeValue,i.numberParseOptions),h=!0}else i.allowBooleanAttributes&&(o[r]=!0,h=!0)}if(!h)return;if(i.attributesGroupName&&!i.preserveOrder){let t={};return t[i.attributesGroupName]=o,t}return o}}let eO=function(t){t=t.replace(/\r\n?/g,"\n");let e=new ei("!xml"),r=e,n="";this.matcher.reset(),this.entityDecoder.reset(),this.entityExpansionCount=0,this.currentExpandedLength=0;let i=this.options,a=new ea(i.processEntities),o=t.length;for(let s=0;s<o;s++)if("<"===t[s]){let l=t.charCodeAt(s+1);if(47===l){let e=eR(t,">",s,"Closing Tag is not closed."),a=t.substring(s+2,e).trim();if(i.removeNSPrefix){let t=a.indexOf(":");-1!==t&&(a=a.substr(t+1))}a=eV(i.transformTagName,a,"",i).tagName,r&&(n=this.saveTextToParentTag(n,r,this.readonlyMatcher));let o=this.matcher.getCurrentTag();if(a&&i.unpairedTagsSet.has(a))throw Error(`Unpaired tag can not be used as closing tag: </${a}>`);o&&i.unpairedTagsSet.has(o)&&(this.matcher.pop(),this.tagsNodeStack.pop()),this.matcher.pop(),this.isCurrentNodeStopNode=!1,r=this.tagsNodeStack.pop(),n="",s=e}else if(63===l){let e=eM(t,s,!1,"?>");if(!e)throw Error("Pi Tag is not closed.");n=this.saveTextToParentTag(n,r,this.readonlyMatcher);let a=this.buildAttributesMap(e.tagExp,this.matcher,e.tagName,!0);if(a){let t=a[this.options.attributeNamePrefix+"version"];this.entityDecoder.setXmlVersion(Number(t)||1)}if(i.ignoreDeclaration&&"?xml"===e.tagName||i.ignorePiTags);else{let t=new ei(e.tagName);t.add(i.textNodeName,""),e.tagName!==e.tagExp&&e.attrExpPresent&&!0!==i.ignoreAttributes&&(t[":@"]=a),this.addChild(r,t,this.readonlyMatcher,s)}s=e.closeIndex+1}else if(33===l&&45===t.charCodeAt(s+2)&&45===t.charCodeAt(s+3)){let e=eR(t,"--\x3e",s+4,"Comment is not closed.");if(i.commentPropName){let a=t.substring(s+4,e-2);n=this.saveTextToParentTag(n,r,this.readonlyMatcher),r.add(i.commentPropName,[{[i.textNodeName]:a}])}s=e}else if(33===l&&68===t.charCodeAt(s+2)){let e=a.readDocType(t,s);this.entityDecoder.addInputEntities(e.entities),s=e.i}else if(33===l&&91===t.charCodeAt(s+2)){let e=eR(t,"]]>",s,"CDATA is not closed.")-2,a=t.substring(s+9,e);n=this.saveTextToParentTag(n,r,this.readonlyMatcher);let o=this.parseTextData(a,r.tagname,this.readonlyMatcher,!0,!1,!0,!0);null==o&&(o=""),i.cdataPropName?r.add(i.cdataPropName,[{[i.textNodeName]:a}]):r.add(i.textNodeName,o),s=e+2}else{let a=eM(t,s,i.removeNSPrefix);if(!a){let e=t.substring(Math.max(0,s-50),Math.min(o,s+50));throw Error(`readTagExp returned undefined at position ${s}. Context: "${e}"`)}let l=a.tagName,u=a.rawTagName,c=a.tagExp,h=a.attrExpPresent,d=a.closeIndex;if({tagName:l,tagExp:c}=eV(i.transformTagName,l,c,i),i.strictReservedNames&&(l===i.commentPropName||l===i.cdataPropName||l===i.textNodeName||l===i.attributesGroupName))throw Error(`Invalid tag name: ${l}`);r&&n&&"!xml"!==r.tagname&&(n=this.saveTextToParentTag(n,r,this.readonlyMatcher,!1));let p=r;p&&i.unpairedTagsSet.has(p.tagname)&&(r=this.tagsNodeStack.pop(),this.matcher.pop());let f=!1;c.length>0&&c.lastIndexOf("/")===c.length-1&&(f=!0,c="/"===l[l.length-1]?l=l.substr(0,l.length-1):c.substr(0,c.length-1),h=l!==c);let g,m=null;g=function(t){if(!t||"string"!=typeof t)return;let e=t.indexOf(":");if(-1!==e&&e>0){let r=t.substring(0,e);if("xmlns"!==r)return r}}(u),l!==e.tagname&&this.matcher.push(l,{},g),l!==c&&h&&(m=this.buildAttributesMap(c,this.matcher,l))&&function(t,e){if(!t)return;let r=e.attributesGroupName?t[e.attributesGroupName]:t;if(!r)return;let n={};for(let t in r)t.startsWith(e.attributeNamePrefix)?n[t.substring(e.attributeNamePrefix.length)]=r[t]:n[t]=r[t]}(m,i),l!==e.tagname&&(this.isCurrentNodeStopNode=this.isItStopNode());let v=s;if(this.isCurrentNodeStopNode){let e="";if(f)s=a.closeIndex;else if(i.unpairedTagsSet.has(l))s=a.closeIndex;else{let r=this.readStopNodeData(t,u,d+1);if(!r)throw Error(`Unexpected end of ${u}`);s=r.i,e=r.tagContent}let n=new ei(l);m&&(n[":@"]=m),n.add(i.textNodeName,e),this.matcher.pop(),this.isCurrentNodeStopNode=!1,this.addChild(r,n,this.readonlyMatcher,v)}else{if(f){({tagName:l,tagExp:c}=eV(i.transformTagName,l,c,i));let t=new ei(l);m&&(t[":@"]=m),this.addChild(r,t,this.readonlyMatcher,v),this.matcher.pop(),this.isCurrentNodeStopNode=!1}else{if(i.unpairedTagsSet.has(l)){let t=new ei(l);m&&(t[":@"]=m),this.addChild(r,t,this.readonlyMatcher,v),this.matcher.pop(),this.isCurrentNodeStopNode=!1,s=a.closeIndex;continue}{let t=new ei(l);if(this.tagsNodeStack.length>i.maxNestedTags)throw Error("Maximum nested tags exceeded");this.tagsNodeStack.push(r),m&&(t[":@"]=m),this.addChild(r,t,this.readonlyMatcher,v),r=t}}n="",s=d}}}else n+=t[s];return e.child};function ej(t,e,r,n){this.options.captureMetaData||(n=void 0);let i=this.options.jPath?r.toString():r,a=this.options.updateTag(e.tagname,i,e[":@"]);!1===a||("string"==typeof a&&(e.tagname=a),t.addChild(e,n))}function eD(t,e,r){let n=this.options.processEntities;if(!n||!n.enabled)return t;if(n.allowedTags){let i=this.options.jPath?r.toString():r;if(!(Array.isArray(n.allowedTags)?n.allowedTags.includes(e):n.allowedTags(e,i)))return t}if(n.tagFilter){let i=this.options.jPath?r.toString():r;if(!n.tagFilter(e,i))return t}return this.entityDecoder.decode(t)}function eL(t,e,r,n){return t&&(void 0===n&&(n=0===e.child.length),void 0!==(t=this.parseTextData(t,e.tagname,r,!1,!!e[":@"]&&0!==Object.keys(e[":@"]).length,n))&&""!==t&&e.add(this.options.textNodeName,t),t=""),t}function eI(){return 0!==this.stopNodeExpressionsSet.size&&this.matcher.matchesAny(this.stopNodeExpressionsSet)}function eR(t,e,r,n){let i=t.indexOf(e,r);if(-1===i)throw Error(n);return i+e.length-1}function eM(t,e,r){let n=function(t,e){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:">",n=0,i=t.length,a=r.charCodeAt(0),o=r.length>1?r.charCodeAt(1):-1,s="",l=e;for(let r=e;r<i;r++){let e=t.charCodeAt(r);if(n)e===n&&(n=0);else if(34===e||39===e)n=e;else if(e===a){if(-1===o||t.charCodeAt(r+1)===o)return{data:s+=t.substring(l,r),index:r}}else 9!==e||n||(s+=t.substring(l,r)+" ",l=r+1)}}(t,e+1,arguments.length>3&&void 0!==arguments[3]?arguments[3]:">");if(!n)return;let i=n.data,a=n.index,o=i.search(/\s/),s=i,l=!0;-1!==o&&(s=i.substring(0,o),i=i.substring(o+1).trimStart());let u=s;if(r){let t=s.indexOf(":");-1!==t&&(l=(s=s.substr(t+1))!==n.data.substr(t+1))}return{tagName:s,tagExp:i,closeIndex:a,attrExpPresent:l,rawTagName:u}}function eF(t,e,r){let n=r,i=1,a=t.length;for(;r<a;r++)if("<"===t[r]){let a=t.charCodeAt(r+1);if(47===a){let a=function(t,e,r){let n=t.indexOf(">",e);if(-1===n)throw Error(r);return n}(t,r,`${e} is not closed`);if(t.substring(r+2,a).trim()===e&&0==--i)return{tagContent:t.substring(n,r),i:a};r=a}else if(63===a)r=eR(t,"?>",r+1,"StopNode is not closed.");else if(33===a&&45===t.charCodeAt(r+2)&&45===t.charCodeAt(r+3))r=eR(t,"--\x3e",r+3,"StopNode is not closed.");else if(33===a&&91===t.charCodeAt(r+2))r=eR(t,"]]>",r,"StopNode is not closed.")-2;else{let n=eM(t,r,">");n&&((n&&n.tagName)===e&&"/"!==n.tagExp[n.tagExp.length-1]&&i++,r=n.closeIndex)}}}function eU(t,e,r){if(e&&"string"==typeof t){let e=t.trim();return"true"===e||"false"!==e&&function(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{};if(e=Object.assign({},eh,e),!t||"string"!=typeof t)return t;let r=t.trim();if(0===r.length||void 0!==e.skipLike&&e.skipLike.test(r))return t;if("0"===r)return 0;if(e.hex&&eu.test(r)){var n;if(parseInt)return parseInt(r,16);if(Number.parseInt)return Number.parseInt(r,16);if(window&&window.parseInt)return window.parseInt(r,16);throw Error("parseInt, Number.parseInt, window.parseInt are not supported")}if(isFinite(r)){if(r.includes("e")||r.includes("E"))return function(t,e,r){if(!r.eNotation)return t;let n=e.match(ed);if(n){let i=n[1]||"",a=-1===n[3].indexOf("e")?"E":"e",o=n[2],s=i?t[o.length+1]===a:t[o.length]===a;return o.length>1&&s?t:(1!==o.length||!n[3].startsWith(`.${a}`)&&n[3][0]!==a)&&o.length>0?r.leadingZeros&&!s?Number(e=(n[1]||"")+n[3]):t:Number(e)}return t}(t,r,e);{let i=ec.exec(r);if(i){let a=i[1]||"",o=i[2],s=((n=i[3])&&-1!==n.indexOf(".")&&("."===(n=n.replace(/0+$/,""))?n="0":"."===n[0]?n="0"+n:"."===n[n.length-1]&&(n=n.substring(0,n.length-1))),n),l=a?"."===t[o.length+1]:"."===t[o.length];if(!e.leadingZeros&&(o.length>1||1===o.length&&!l))return t;{let n=Number(r),i=String(n);if(0===n)return n;if(-1!==i.search(/[eE]/))return e.eNotation?n:t;if(-1!==r.indexOf("."))return"0"===i||i===s||i===`${a}${s}`?n:t;let l=o?s:r;return o?l===i||a+l===i?n:t:l===i||l===a+i?n:t}}return t}}var i=Number(r);switch(e.infinity.toLowerCase()){case"null":return null;case"infinity":return i;case"string":return i===1/0?"Infinity":"-Infinity";default:return t}}(t,r)}return void 0!==t?t:""}function eV(t,e,r,n){if(t){let n=t(e);r===e&&(r=n),e=n}return{tagName:e=eG(e,n),tagExp:r}}function eG(t,e){if(et.includes(t))throw Error(`[SECURITY] Invalid name: "${t}" is a reserved JavaScript keyword that could cause prototype pollution`);return t5.includes(t)?e.onDangerousProperty(t):t}let eW=ei.getMetaDataSymbol(),ez={allowBooleanAttributes:!1,unpairedTags:[]};function eX(t){return" "===t||"	"===t||"\n"===t||"\r"===t}function eq(t,e){let r=e;for(;e<t.length;e++)if("?"!=t[e]&&" "!=t[e]);else{let n=t.substr(r,e-r);if(e>5&&"xml"===n)return eK("InvalidXml","XML declaration allowed only at the start of the document.",eQ(t,e));if("?"==t[e]&&">"==t[e+1]){e++;break}}return e}function eH(t,e){if(t.length>e+5&&"-"===t[e+1]&&"-"===t[e+2]){for(e+=3;e<t.length;e++)if("-"===t[e]&&"-"===t[e+1]&&">"===t[e+2]){e+=2;break}}else if(t.length>e+8&&"D"===t[e+1]&&"O"===t[e+2]&&"C"===t[e+3]&&"T"===t[e+4]&&"Y"===t[e+5]&&"P"===t[e+6]&&"E"===t[e+7]){let r=1;for(e+=8;e<t.length;e++)if("<"===t[e])r++;else if(">"===t[e]&&0==--r)break}else if(t.length>e+9&&"["===t[e+1]&&"C"===t[e+2]&&"D"===t[e+3]&&"A"===t[e+4]&&"T"===t[e+5]&&"A"===t[e+6]&&"["===t[e+7]){for(e+=8;e<t.length;e++)if("]"===t[e]&&"]"===t[e+1]&&">"===t[e+2]){e+=2;break}}return e}let eY=RegExp("(\\s*)([^\\s=]+)(\\s*=)?(\\s*(['\"])(([\\s\\S])*?)\\5)?","g");function eZ(t,e){let r=t7(t,eY),n={};for(let t=0;t<r.length;t++){if(0===r[t][1].length)return eK("InvalidAttr","Attribute '"+r[t][2]+"' has no space in starting.",eJ(r[t]));if(void 0!==r[t][3]&&void 0===r[t][4])return eK("InvalidAttr","Attribute '"+r[t][2]+"' is without value.",eJ(r[t]));if(void 0===r[t][3]&&!e.allowBooleanAttributes)return eK("InvalidAttr","boolean attribute '"+r[t][2]+"' is not allowed.",eJ(r[t]));let i=r[t][2];if(!t6(i))return eK("InvalidAttr","Attribute '"+i+"' is an invalid name.",eJ(r[t]));if(Object.prototype.hasOwnProperty.call(n,i))return eK("InvalidAttr","Attribute '"+i+"' is repeated.",eJ(r[t]));n[i]=1}return!0}function eK(t,e,r){return{err:{code:t,msg:e,line:r.line||r,col:r.col}}}function eQ(t,e){let r=t.substring(0,e).split(/\r?\n/);return{line:r.length,col:r[r.length-1].length+1}}function eJ(t){return t.startIndex+t[1].length}class e0{constructor(t){this.externalEntities={},this.options=en(t)}parse(t,e){var r;if("string"!=typeof t&&t.toString)t=t.toString();else if("string"!=typeof t)throw Error("XML data is accepted in String or Bytes[] form.");if(e){!0===e&&(e={});let r=function(t,e){e=Object.assign({},ez,e);let r=[],n=!1,i=!1;"\uFEFF"===t[0]&&(t=t.substr(1));for(let a=0;a<t.length;a++)if("<"===t[a]&&"?"===t[a+1]){if(a+=2,(a=eq(t,a)).err)return a}else{if("<"!==t[a]){if(eX(t[a]))continue;return eK("InvalidChar","char '"+t[a]+"' is not expected.",eQ(t,a))}{let o=a;if("!"===t[++a]){a=eH(t,a);continue}{let s=!1;"/"===t[a]&&(s=!0,a++);let l="";for(;a<t.length&&">"!==t[a]&&" "!==t[a]&&"	"!==t[a]&&"\n"!==t[a]&&"\r"!==t[a];a++)l+=t[a];if("/"===(l=l.trim())[l.length-1]&&(l=l.substring(0,l.length-1),a--),!t6(l))return eK("InvalidTag",0===l.trim().length?"Invalid space after '<'.":"Tag '"+l+"' is an invalid name.",eQ(t,a));let u=function(t,e){let r="",n="",i=!1;for(;e<t.length;e++){if('"'===t[e]||"'"===t[e])""===n?n=t[e]:n!==t[e]||(n="");else if(">"===t[e]&&""===n){i=!0;break}r+=t[e]}return""===n&&{value:r,index:e,tagClosed:i}}(t,a);if(!1===u)return eK("InvalidAttr","Attributes for '"+l+"' have open quote.",eQ(t,a));let c=u.value;if(a=u.index,"/"===c[c.length-1]){let r=a-c.length,i=eZ(c=c.substring(0,c.length-1),e);if(!0!==i)return eK(i.err.code,i.err.msg,eQ(t,r+i.err.line));n=!0}else if(s){if(!u.tagClosed)return eK("InvalidTag","Closing tag '"+l+"' doesn't have proper closing.",eQ(t,a));if(c.trim().length>0)return eK("InvalidTag","Closing tag '"+l+"' can't have attributes or invalid starting.",eQ(t,o));if(0===r.length)return eK("InvalidTag","Closing tag '"+l+"' has not been opened.",eQ(t,o));{let e=r.pop();if(l!==e.tagName){let r=eQ(t,e.tagStartPos);return eK("InvalidTag","Expected closing tag '"+e.tagName+"' (opened in line "+r.line+", col "+r.col+") instead of closing tag '"+l+"'.",eQ(t,o))}0==r.length&&(i=!0)}}else{let s=eZ(c,e);if(!0!==s)return eK(s.err.code,s.err.msg,eQ(t,a-c.length+s.err.line));if(!0===i)return eK("InvalidXml","Multiple possible root nodes found.",eQ(t,a));-1!==e.unpairedTags.indexOf(l)||r.push({tagName:l,tagStartPos:o}),n=!0}for(a++;a<t.length;a++)if("<"===t[a]){if("!"===t[a+1]){a=eH(t,++a);continue}if("?"!==t[a+1])break;if((a=eq(t,++a)).err)return a}else if("&"===t[a]){let e=function(t,e){if(";"===t[++e])return -1;if("#"===t[e]){var r=++e;let n=/\d/;for("x"===t[r]&&(r++,n=/[\da-fA-F]/);r<t.length;r++){if(";"===t[r])return r;if(!t[r].match(n))break}return -1}let n=0;for(;e<t.length;e++,n++)if(!(t[e].match(/\w/)&&n<20)){if(";"===t[e])break;return -1}return e}(t,a);if(-1==e)return eK("InvalidChar","char '&' is not expected.",eQ(t,a));a=e}else if(!0===i&&!eX(t[a]))return eK("InvalidXml","Extra text at the end",eQ(t,a));"<"===t[a]&&a--}}}return n?1==r.length?eK("InvalidTag","Unclosed tag '"+r[0].tagName+"'.",eQ(t,r[0].tagStartPos)):!(r.length>0)||eK("InvalidXml","Invalid '"+JSON.stringify(r.map(t=>t.tagName),null,4).replace(/\r?\n/g,"")+"' found.",{line:1,col:1}):eK("InvalidXml","Start tag expected.",1)}(t,e);if(!0!==r)throw Error(`${r.err.msg}:${r.err.line}:${r.err.col}`)}let n=new eS(this.options,this.externalEntities),i=n.parseXml(t);return this.options.preserveOrder||void 0===i?i:(r=this.options,function t(e,r,n,i){let a,o={};for(let s=0;s<e.length;s++){let l=e[s],u=function(t){let e=Object.keys(t);for(let t=0;t<e.length;t++){let r=e[t];if(":@"!==r)return r}}(l);if(void 0!==u&&u!==r.textNodeName){let t=function(t,e){if(!t||"object"!=typeof t)return{};if(!e)return t;let r={};for(let n in t)n.startsWith(e)?r[n.substring(e.length)]=t[n]:r[n]=t[n];return r}(l[":@"]||{},r.attributeNamePrefix);n.push(u,t)}if(u===r.textNodeName)void 0===a?a=l[u]:a+=""+l[u];else{if(void 0===u)continue;if(l[u]){let e=t(l[u],r,n,i),a=function(t,e){let{textNodeName:r}=e,n=Object.keys(t).length;return 0===n||!(1!==n||!t[r]&&"boolean"!=typeof t[r]&&0!==t[r])}(e,r);if(l[":@"]?function(t,e,r,n){if(e){let i=Object.keys(e),a=i.length;for(let o=0;o<a;o++){let a=i[o],s=a.startsWith(n.attributeNamePrefix)?a.substring(n.attributeNamePrefix.length):a,l=n.jPath?r.toString()+"."+s:r;n.isArray(a,l,!0,!0)?t[a]=[e[a]]:t[a]=e[a]}}}(e,l[":@"],i,r):1!==Object.keys(e).length||void 0===e[r.textNodeName]||r.alwaysCreateTextNode?0===Object.keys(e).length&&(r.alwaysCreateTextNode?e[r.textNodeName]="":e=""):e=e[r.textNodeName],void 0!==l[eW]&&"object"==typeof e&&null!==e&&(e[eW]=l[eW]),void 0!==o[u]&&Object.prototype.hasOwnProperty.call(o,u))Array.isArray(o[u])||(o[u]=[o[u]]),o[u].push(e);else{let t=r.jPath?i.toString():i;r.isArray(u,t,a)?o[u]=[e]:o[u]=e}void 0!==u&&u!==r.textNodeName&&n.pop()}}}return"string"==typeof a?a.length>0&&(o[r.textNodeName]=a):void 0!==a&&(o[r.textNodeName]=a),o}(i,r,n.matcher,n.readonlyMatcher))}addEntity(t,e){if(-1!==e.indexOf("&"))throw Error("Entity value can't have '&'");if(-1!==t.indexOf("&")||-1!==t.indexOf(";"))throw Error("An entity must be set without '&' and ';'. Eg. use '#xD' for '&#xD;'");if("&"===e)throw Error("An entity with value '&' is not permitted");this.externalEntities[t]=e}static getMetaDataSymbol(){return ei.getMetaDataSymbol()}}var e1=E(829),e2=E.n(e1),e3=((o=e3||{}).Array="array",o.Object="object",o.Original="original",o);function e4(t){return"string"==typeof t?t:t.toString(".",!1)}function e8(t,e){if(!t.endsWith("propstat.prop.displayname"))return e}function e9(t,e){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:e3.Original,n=e2().get(t,e);return"array"===r&&!1===Array.isArray(n)?[n]:"object"===r&&Array.isArray(n)?n[0]:n}function e7(t,e){return e=e??{attributeNamePrefix:"@",attributeParsers:[],tagParsers:[e8]},new Promise(r=>{r(function(t){let{multistatus:e}=t;if(""===e)return{multistatus:{response:[]}};if(!e)throw Error("Invalid response: No root multistatus found");let r={multistatus:Array.isArray(e)?e[0]:e};return e2().set(r,"multistatus.response",e9(r,"multistatus.response",e3.Array)),e2().set(r,"multistatus.response",e2().get(r,"multistatus.response").map(t=>{let e;return(e=Object.assign({},t)).status?e2().set(e,"status",e9(e,"status",e3.Object)):(e2().set(e,"propstat",e9(e,"propstat",e3.Object)),e2().set(e,"propstat.prop",e9(e,"propstat.prop",e3.Object))),e})),r}((function(t){let{attributeNamePrefix:e,attributeParsers:r,entityDecoder:n,tagParsers:i}=t,a={allowBooleanAttributes:!0,attributeNamePrefix:e,textNodeName:"text",ignoreAttributes:!1,removeNSPrefix:!0,jPath:!1,numberParseOptions:{hex:!0,leadingZeros:!1},attributeValueProcessor(t,e,n){let i=e4(n);for(let t of r)try{let r=t(i,e);if(r!==e)return r}catch(t){}return e},tagValueProcessor(t,e,r){let n=e4(r);for(let t of i)try{let r=t(n,e);if(r!==e)return r}catch(t){}return e}};return n&&(a.entityDecoder=new eP({limit:{maxTotalExpansions:n.limit?.maxTotalExpansions??0,maxExpandedLength:n.limit?.maxExpandedLength??0}})),new e0(a)})(e).parse(t)))})}function e6(t,e){let r=arguments.length>2&&void 0!==arguments[2]&&arguments[2],{getlastmodified:n=null,getcontentlength:i="0",resourcetype:a=null,getcontenttype:o=null,getetag:s=null}=t,l=a&&"object"==typeof a&&void 0!==a.collection?"directory":"file",u={filename:e,basename:T().basename(e),lastmod:n,size:parseInt(i,10),type:l,etag:"string"==typeof s?s.replace(/"/g,""):null};return"file"===l&&(u.mime=o&&"string"==typeof o?o.split(";")[0]:""),r&&(void 0!==t.displayname&&(t.displayname=String(t.displayname)),u.props=t),u}function e5(t,e,r){return r?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let rt=(s=function(t,e){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},{details:n=!1}=r;return e5(tp(tf({url:L(t.remoteURL,O(e)),method:"PROPFIND",headers:{Accept:"text/plain,application/xml",Depth:"0"}},t,r),t),function(r){return t2(t,r),e5(r.text(),function(i){return e5(e7(i,t.parsing),function(t){return t3(r,function(t,e){let r=arguments.length>2&&void 0!==arguments[2]&&arguments[2],n=null;try{t.multistatus.response[0].propstat&&(n=t.multistatus.response[0])}catch(t){}if(!n)throw Error("Failed getting item stat: bad response");let{propstat:{prop:i,status:a}}=n,[o,s,l]=a.split(" ",3),u=parseInt(s,10);if(u>=400){let t=Error(`Invalid response: ${u} ${l}`);throw t.status=u,t}return e6(i,D(e),r)}(t,e,n),n)})})})},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(s.apply(this,t))}catch(t){return Promise.reject(t)}});function re(t,e,r){return r?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let rr=rn(function(t,e){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},n=function(t){if(!t||"/"===t)return[];let e=t,r=[];do r.push(e),e=T().dirname(e);while(e&&"/"!==e);return r}(D(e));n.sort((t,e)=>t.length>e.length?1:e.length>t.length?-1:0);let i=!1;return function(t,e,r){if("function"==typeof t[ro]){var n,i,a,o,s,l,u,c=t[ro]();if(function t(r){try{for(;!(s=c.next()).done;)if((r=e(s.value))&&r.then){if(!ru(r))return void r.then(t,u||(u=rs.bind(null,l=new rl,2)));r=r.v}l?rs(l,1,r):l=r}catch(t){rs(l||(l=new rl),2,t)}}(),c.return){var h=function(t){try{s.done||c.return()}catch(t){}return t};if(l&&l.then)return l.then(h,function(t){throw h(t)});h()}return l}if(!("length"in t))throw TypeError("Object is not iterable");for(var d=[],p=0;p<t.length;p++)d.push(t[p]);return n=function(t){return e(d[t])},o=-1,function t(e){try{for(;++o<d.length&&(!r||!r());)if((e=n(o))&&e.then){if(!ru(e))return void e.then(t,a||(a=rs.bind(null,i=new rl,2)));e=e.v}i?rs(i,1,e):i=e}catch(t){rs(i||(i=new rl),2,t)}}(),i}(n,function(n){var a,o;return o=function(){var a=function(e){if(404===e.status)return i=!0,ra(rc(t,n,{...r,recursive:!1}));throw e};try{var o=re(rt(t,n),function(t){if("directory"!==t.type)throw Error(`Path includes a file: ${e}`)})}catch(t){return a(t)}return o&&o.then?o.then(void 0,a):o},(a=function(){if(i)return ra(rc(t,n,{...r,recursive:!1}))}())&&a.then?a.then(o):o()},function(){return!1})});function rn(t){return function(){for(var e=[],r=0;r<arguments.length;r++)e[r]=arguments[r];try{return Promise.resolve(t.apply(this,e))}catch(t){return Promise.reject(t)}}}function ri(){}function ra(t,e){if(!e)return t&&t.then?t.then(ri):Promise.resolve()}let ro="u">typeof Symbol?Symbol.iterator||(Symbol.iterator=Symbol("Symbol.iterator")):"@@iterator";function rs(t,e,r){if(!t.s){if(r instanceof rl){if(!r.s)return void(r.o=rs.bind(null,t,e));1&e&&(e=r.s),r=r.v}if(r&&r.then)return void r.then(rs.bind(null,t,e),rs.bind(null,t,2));t.s=e,t.v=r;let n=t.o;n&&n(t)}}let rl=function(){function t(){}return t.prototype.then=function(e,r){let n=new t,i=this.s;if(i){let t=1&i?e:r;if(t){try{rs(n,1,t(this.v))}catch(t){rs(n,2,t)}return n}return this}return this.o=function(t){try{let i=t.v;1&t.s?rs(n,1,e?e(i):i):r?rs(n,1,r(i)):rs(n,2,i)}catch(t){rs(n,2,t)}},n},t}();function ru(t){return t instanceof rl&&1&t.s}let rc=rn(function(t,e){var r;let n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return!0===n.recursive?rr(t,e,n):re(tp(tf({url:L(t.remoteURL,(r=O(e)).endsWith("/")?r:r+"/"),method:"MKCOL"},t,n),t),function(e){t2(t,e)})});var rh=E(388),rd=E.n(rh);let rp=(l=function(t,e){var r,n;let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},a={};if("object"==typeof i.range&&"number"==typeof i.range.start){let t=`bytes=${i.range.start}-`;"number"==typeof i.range.end&&(t=`${t}${i.range.end}`),a.Range=t}let o=tf({url:L(t.remoteURL,O(e)),method:"GET",headers:a},t,i);return r=function(e){if(t2(t,e),a.Range&&206!==e.status){let t=Error(`Invalid response code for partial request: ${e.status}`);throw t.status=e.status,t}return i.callback&&setTimeout(()=>{i.callback(e)},0),e.body},(n=tp(o,t))&&n.then||(n=Promise.resolve(n)),r?n.then(r):n},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(l.apply(this,t))}catch(t){return Promise.reject(t)}}),rf=()=>{},rg=(u=function(t,e,r){var n,i;r.url||(r.url=L(t.remoteURL,O(e)));let a=tf(r,t,{});return i=function(e){return t2(t,e),e},(n=tp(a,t))&&n.then||(n=Promise.resolve(n)),i?n.then(i):n},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(u.apply(this,t))}catch(t){return Promise.reject(t)}}),rm=(c=function(t,e){var r,n;let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},a=tf({url:L(t.remoteURL,O(e)),method:"DELETE"},t,i);return n=function(e){t2(t,e)},(r=tp(a,t))&&r.then||(r=Promise.resolve(r)),n?r.then(n):r},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(c.apply(this,t))}catch(t){return Promise.reject(t)}}),rv=(h=function(t,e){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return function(n){try{var i,a,o,s=(i=rt(t,e,r),a=function(){return!0},o?a?a():i:(i&&i.then||(i=Promise.resolve(i)),a?i.then(a):i))}catch(t){return n(t)}return s&&s.then?s.then(void 0,n):s}(function(t){if(404===t.status)return!1;throw t})},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(h.apply(this,t))}catch(t){return Promise.reject(t)}});function rb(t,e,r){return r?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let rA=(d=function(t,e){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return rb(tp(tf({url:L(t.remoteURL,O(e),"/"),method:"PROPFIND",headers:{Accept:"text/plain,application/xml",Depth:r.deep?"infinity":"1"}},t,r),t),function(n){return t2(t,n),rb(n.text(),function(i){if(!i)throw Error("Failed parsing directory contents: Empty response");return rb(e7(i,t.parsing),function(i){var a,o;let s=j(e),l=function(t,e,r){let n=arguments.length>3&&void 0!==arguments[3]&&arguments[3],i=arguments.length>4&&void 0!==arguments[4]&&arguments[4],a=T().join(e,"/"),{multistatus:{response:o}}=t,s=o.map(t=>{let e=function(t){try{return t.replace(/^https?:\/\/[^\/]+/,"")}catch(t){throw new S(t,"Failed normalising HREF")}}(t.href),{propstat:{prop:r}}=t;return e6(r,"/"===a?decodeURIComponent(D(e)):D(T().relative(decodeURIComponent(a),decodeURIComponent(e))),n)});return i?s:s.filter(t=>t.basename&&("file"===t.type||t.filename!==r.replace(/\/$/,"")))}(i,j(t.remoteBasePath||t.remotePath),s,r.details,r.includeSelf);return r.glob&&(a=l,o=r.glob,l=a.filter(t=>tL(t.filename,o,{matchBase:!0}))),t3(n,l,r.details)})})})},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(d.apply(this,t))}catch(t){return Promise.reject(t)}});function ry(t){return function(){for(var e=[],r=0;r<arguments.length;r++)e[r]=arguments[r];try{return Promise.resolve(t.apply(this,e))}catch(t){return Promise.reject(t)}}}let rx=ry(function(t,e){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return rC(tp(tf({url:L(t.remoteURL,O(e)),method:"GET",headers:{Accept:"text/plain"},transformResponse:[r_]},t,r),t),function(e){return t2(t,e),rC(e.text(),function(t){return t3(e,t,r.details)})})});function rC(t,e,r){return r?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let rE=ry(function(t,e){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{};return rC(tp(tf({url:L(t.remoteURL,O(e)),method:"GET"},t,r),t),function(e){var n,i,a;let o;return t2(t,e),n=function(){return rC(e.arrayBuffer(),function(t){o=t})},i=function(){return t3(e,o,r.details)},(a=n())&&a.then?a.then(i):i()})}),rw=ry(function(t,e){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},{format:n="binary"}=r;if("binary"!==n&&"text"!==n)throw new S({info:{code:H.InvalidOutputFormat}},`Invalid output format: ${n}`);return"text"===n?rx(t,e,r):rE(t,e,r)}),r_=t=>t;function rN(t){let e=Object.keys(t);for(let r=0;r<e.length;r++){let n=e[r];if(Object.prototype.hasOwnProperty.call(t,n)&&":@"!==n)return n}}function rP(t,e,r){let n="";if(t&&!e.ignoreAttributes)for(let i in t){let a;Object.prototype.hasOwnProperty.call(t,i)&&(!0===(a=r?t[i]:rS(a=e.attributeValueProcessor(i,t[i]),e))&&e.suppressBooleanAttributes?n+=` ${i.substr(e.attributeNamePrefix.length)}`:n+=` ${i.substr(e.attributeNamePrefix.length)}="${a}"`)}return n}function rS(t,e){if(t&&t.length>0&&e.processEntities)for(let r=0;r<e.entities.length;r++){let n=e.entities[r];t=t.replace(n.regex,n.val)}return t}let rk={attributeNamePrefix:"@_",attributesGroupName:!1,textNodeName:"#text",ignoreAttributes:!0,cdataPropName:!1,format:!1,indentBy:"  ",suppressEmptyNode:!1,suppressUnpairedNode:!0,suppressBooleanAttributes:!0,tagValueProcessor:function(t,e){return e},attributeValueProcessor:function(t,e){return e},preserveOrder:!1,commentPropName:!1,unpairedTags:[],entities:[{regex:RegExp("&","g"),val:"&amp;"},{regex:RegExp(">","g"),val:"&gt;"},{regex:RegExp("<","g"),val:"&lt;"},{regex:RegExp("'","g"),val:"&apos;"},{regex:RegExp('"',"g"),val:"&quot;"}],processEntities:!0,stopNodes:[],oneListGroup:!1,maxNestedTags:100,jPath:!0};function rT(t){var e;if(this.options=Object.assign({},rk,t),this.options.stopNodes&&Array.isArray(this.options.stopNodes)&&(this.options.stopNodes=this.options.stopNodes.map(t=>"string"==typeof t&&t.startsWith("*.")?".."+t.substring(2):t)),this.stopNodeExpressions=[],this.options.stopNodes&&Array.isArray(this.options.stopNodes))for(let t=0;t<this.options.stopNodes.length;t++){let e=this.options.stopNodes[t];"string"==typeof e?this.stopNodeExpressions.push(new eg(e)):e instanceof eg&&this.stopNodeExpressions.push(e)}!0===this.options.ignoreAttributes||this.options.attributesGroupName?this.isAttribute=function(){return!1}:(this.ignoreAttributesFn="function"==typeof(e=this.options.ignoreAttributes)?e:Array.isArray(e)?t=>{for(let r of e)if("string"==typeof r&&t===r||r instanceof RegExp&&r.test(t))return!0}:()=>!1,this.attrPrefixLen=this.options.attributeNamePrefix.length,this.isAttribute=rO),this.processTextOrObjNode=rB,this.options.format?(this.indentate=r$,this.tagEndChar=">\n",this.newLine="\n"):(this.indentate=function(){return""},this.tagEndChar=">",this.newLine="")}function rB(t,e,r,n){let i=this.extractAttributes(t);if(n.push(e,i),this.checkStopNode(n)){let i=this.buildRawContent(t),a=this.buildAttributesForStopNode(t);return n.pop(),this.buildObjectNode(i,e,a,r)}let a=this.j2x(t,r+1,n);return n.pop(),void 0!==t[this.options.textNodeName]&&1===Object.keys(t).length?this.buildTextValNode(t[this.options.textNodeName],e,a.attrStr,r,n):this.buildObjectNode(a.val,e,a.attrStr,r)}function r$(t){return this.options.indentBy.repeat(t)}function rO(t){return!(!t.startsWith(this.options.attributeNamePrefix)||t===this.options.textNodeName)&&t.substr(this.attrPrefixLen)}function rj(t,e,r){return r?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}function rD(t){return function(){for(var e=[],r=0;r<arguments.length;r++)e[r]=arguments[r];try{return Promise.resolve(t.apply(this,e))}catch(t){return Promise.reject(t)}}}rT.prototype.build=function(t){if(this.options.preserveOrder)return function(t,e){let r="";e.format&&e.indentBy.length>0&&(r="\n");let n=[];if(e.stopNodes&&Array.isArray(e.stopNodes))for(let t=0;t<e.stopNodes.length;t++){let r=e.stopNodes[t];"string"==typeof r?n.push(new eg(r)):r instanceof eg&&n.push(r)}return function t(e,r,n,i,a){let o="",s=!1;if(r.maxNestedTags&&i.getDepth()>r.maxNestedTags)throw Error("Maximum nested tags exceeded");if(!Array.isArray(e))return null!=e?rS(e.toString(),r):"";for(let l=0;l<e.length;l++){let u,c=e[l],h=rN(c);if(void 0===h)continue;let d=function(t,e){if(!t||e.ignoreAttributes)return null;let r={},n=!1;for(let i in t)Object.prototype.hasOwnProperty.call(t,i)&&(r[i.startsWith(e.attributeNamePrefix)?i.substr(e.attributeNamePrefix.length):i]=t[i],n=!0);return n?r:null}(c[":@"],r);i.push(h,d);let p=function(t,e){if(!e||0===e.length)return!1;for(let r=0;r<e.length;r++)if(t.matches(e[r]))return!0;return!1}(i,a);if(h===r.textNodeName){let t=c[h];p||(t=rS(t=r.tagValueProcessor(h,t),r)),s&&(o+=n),o+=t,s=!1,i.pop();continue}if(h===r.cdataPropName){s&&(o+=n);let t=c[h][0][r.textNodeName];o+=`<![CDATA[${String(t).replace(/\]\]>/g,"]]]]><![CDATA[>")}]]>`,s=!1,i.pop();continue}if(h===r.commentPropName){let t=c[h][0][r.textNodeName];o+=n+`<!--${String(t).replace(/--/g,"- -").replace(/-$/,"- ")}-->`,s=!0,i.pop();continue}if("?"===h[0]){let t=rP(c[":@"],r,p),e="?xml"===h?"":n,a=c[h][0][r.textNodeName];a=0!==a.length?" "+a:"",o+=e+`<${h}${a}${t}?>`,s=!0,i.pop();continue}let f=n;""!==f&&(f+=r.indentBy);let g=n+`<${h}${rP(c[":@"],r,p)}`;u=p?function t(e,r){if(!Array.isArray(e))return null!=e?e.toString():"";let n="";for(let i=0;i<e.length;i++){let a=e[i],o=rN(a);if(o===r.textNodeName)n+=a[o];else if(o===r.cdataPropName)n+=a[o][0][r.textNodeName];else if(o===r.commentPropName)n+=a[o][0][r.textNodeName];else{if(o&&"?"===o[0])continue;if(o){let e=function(t,e){let r="";if(t&&!e.ignoreAttributes)for(let n in t){if(!Object.prototype.hasOwnProperty.call(t,n))continue;let i=t[n];!0===i&&e.suppressBooleanAttributes?r+=` ${n.substr(e.attributeNamePrefix.length)}`:r+=` ${n.substr(e.attributeNamePrefix.length)}="${i}"`}return r}(a[":@"],r),i=t(a[o],r);i&&0!==i.length?n+=`<${o}${e}>${i}</${o}>`:n+=`<${o}${e}/>`}}}return n}(c[h],r):t(c[h],r,f,i,a),-1!==r.unpairedTags.indexOf(h)?r.suppressUnpairedNode?o+=g+">":o+=g+"/>":u&&0!==u.length||!r.suppressEmptyNode?u&&u.endsWith(">")?o+=g+`>${u}${n}</${h}>`:(o+=g+">",u&&""!==n&&(u.includes("/>")||u.includes("</"))?o+=n+r.indentBy+u+n:o+=u,o+=`</${h}>`):o+=g+"/>",s=!0,i.pop()}return o}(t,e,r,new ef,n)}(t,this.options);{Array.isArray(t)&&this.options.arrayNodeName&&this.options.arrayNodeName.length>1&&(t={[this.options.arrayNodeName]:t});let e=new ef;return this.j2x(t,0,e).val}},rT.prototype.j2x=function(t,e,r){let n="",i="";if(this.options.maxNestedTags&&r.getDepth()>=this.options.maxNestedTags)throw Error("Maximum nested tags exceeded");let a=this.options.jPath?r.toString():r,o=this.checkStopNode(r);for(let s in t)if(Object.prototype.hasOwnProperty.call(t,s))if(void 0===t[s])this.isAttribute(s)&&(i+="");else if(null===t[s])this.isAttribute(s)||s===this.options.cdataPropName?i+="":"?"===s[0]?i+=this.indentate(e)+"<"+s+"?"+this.tagEndChar:i+=this.indentate(e)+"<"+s+"/"+this.tagEndChar;else if(t[s]instanceof Date)i+=this.buildTextValNode(t[s],s,"",e,r);else if("object"!=typeof t[s]){let l=this.isAttribute(s);if(l&&!this.ignoreAttributesFn(l,a))n+=this.buildAttrPairStr(l,""+t[s],o);else if(!l)if(s===this.options.textNodeName){let e=this.options.tagValueProcessor(s,""+t[s]);i+=this.replaceEntitiesValue(e)}else{r.push(s);let n=this.checkStopNode(r);if(r.pop(),n){let r=""+t[s];i+=""===r?this.indentate(e)+"<"+s+this.closeTag(s)+this.tagEndChar:this.indentate(e)+"<"+s+">"+r+"</"+s+this.tagEndChar}else i+=this.buildTextValNode(t[s],s,"",e,r)}}else if(Array.isArray(t[s])){let n=t[s].length,a="",o="";for(let l=0;l<n;l++){let n=t[s][l];if(void 0===n);else if(null===n)"?"===s[0]?i+=this.indentate(e)+"<"+s+"?"+this.tagEndChar:i+=this.indentate(e)+"<"+s+"/"+this.tagEndChar;else if("object"==typeof n)if(this.options.oneListGroup){r.push(s);let t=this.j2x(n,e+1,r);r.pop(),a+=t.val,this.options.attributesGroupName&&n.hasOwnProperty(this.options.attributesGroupName)&&(o+=t.attrStr)}else a+=this.processTextOrObjNode(n,s,e,r);else if(this.options.oneListGroup){let t=this.options.tagValueProcessor(s,n);a+=t=this.replaceEntitiesValue(t)}else{r.push(s);let t=this.checkStopNode(r);if(r.pop(),t){let t=""+n;a+=""===t?this.indentate(e)+"<"+s+this.closeTag(s)+this.tagEndChar:this.indentate(e)+"<"+s+">"+t+"</"+s+this.tagEndChar}else a+=this.buildTextValNode(n,s,"",e,r)}}this.options.oneListGroup&&(a=this.buildObjectNode(a,s,o,e)),i+=a}else if(this.options.attributesGroupName&&s===this.options.attributesGroupName){let e=Object.keys(t[s]),r=e.length;for(let i=0;i<r;i++)n+=this.buildAttrPairStr(e[i],""+t[s][e[i]],o)}else i+=this.processTextOrObjNode(t[s],s,e,r);return{attrStr:n,val:i}},rT.prototype.buildAttrPairStr=function(t,e,r){return r||(e=this.options.attributeValueProcessor(t,""+e),e=this.replaceEntitiesValue(e)),this.options.suppressBooleanAttributes&&"true"===e?" "+t:" "+t+'="'+e+'"'},rT.prototype.extractAttributes=function(t){if(!t||"object"!=typeof t)return null;let e={},r=!1;if(this.options.attributesGroupName&&t[this.options.attributesGroupName]){let n=t[this.options.attributesGroupName];for(let t in n)Object.prototype.hasOwnProperty.call(n,t)&&(e[t.startsWith(this.options.attributeNamePrefix)?t.substring(this.options.attributeNamePrefix.length):t]=n[t],r=!0)}else for(let n in t){if(!Object.prototype.hasOwnProperty.call(t,n))continue;let i=this.isAttribute(n);i&&(e[i]=t[n],r=!0)}return r?e:null},rT.prototype.buildRawContent=function(t){if("string"==typeof t)return t;if("object"!=typeof t||null===t)return String(t);if(void 0!==t[this.options.textNodeName])return t[this.options.textNodeName];let e="";for(let r in t){if(!Object.prototype.hasOwnProperty.call(t,r)||this.isAttribute(r)||this.options.attributesGroupName&&r===this.options.attributesGroupName)continue;let n=t[r];if(r===this.options.textNodeName)e+=n;else if(Array.isArray(n)){for(let t of n)if("string"==typeof t||"number"==typeof t)e+=`<${r}>${t}</${r}>`;else if("object"==typeof t&&null!==t){let n=this.buildRawContent(t),i=this.buildAttributesForStopNode(t);e+=""===n?`<${r}${i}/>`:`<${r}${i}>${n}</${r}>`}}else if("object"==typeof n&&null!==n){let t=this.buildRawContent(n),i=this.buildAttributesForStopNode(n);e+=""===t?`<${r}${i}/>`:`<${r}${i}>${t}</${r}>`}else e+=`<${r}>${n}</${r}>`}return e},rT.prototype.buildAttributesForStopNode=function(t){if(!t||"object"!=typeof t)return"";let e="";if(this.options.attributesGroupName&&t[this.options.attributesGroupName]){let r=t[this.options.attributesGroupName];for(let t in r){if(!Object.prototype.hasOwnProperty.call(r,t))continue;let n=t.startsWith(this.options.attributeNamePrefix)?t.substring(this.options.attributeNamePrefix.length):t,i=r[t];!0===i&&this.options.suppressBooleanAttributes?e+=" "+n:e+=" "+n+'="'+i+'"'}}else for(let r in t){if(!Object.prototype.hasOwnProperty.call(t,r))continue;let n=this.isAttribute(r);if(n){let i=t[r];!0===i&&this.options.suppressBooleanAttributes?e+=" "+n:e+=" "+n+'="'+i+'"'}}return e},rT.prototype.buildObjectNode=function(t,e,r,n){if(""===t)return"?"===e[0]?this.indentate(n)+"<"+e+r+"?"+this.tagEndChar:this.indentate(n)+"<"+e+r+this.closeTag(e)+this.tagEndChar;{let i="</"+e+this.tagEndChar,a="";return"?"===e[0]&&(a="?",i=""),(r||""===r)&&-1===t.indexOf("<")?this.indentate(n)+"<"+e+r+a+">"+t+i:!1!==this.options.commentPropName&&e===this.options.commentPropName&&0===a.length?this.indentate(n)+`<!--${t}-->`+this.newLine:this.indentate(n)+"<"+e+r+a+this.tagEndChar+t+this.indentate(n)+i}},rT.prototype.closeTag=function(t){let e="";return -1!==this.options.unpairedTags.indexOf(t)?this.options.suppressUnpairedNode||(e="/"):e=this.options.suppressEmptyNode?"/":`></${t}`,e},rT.prototype.checkStopNode=function(t){if(!this.stopNodeExpressions||0===this.stopNodeExpressions.length)return!1;for(let e=0;e<this.stopNodeExpressions.length;e++)if(t.matches(this.stopNodeExpressions[e]))return!0;return!1},rT.prototype.buildTextValNode=function(t,e,r,n,i){if(!1!==this.options.cdataPropName&&e===this.options.cdataPropName){let e=String(t).replace(/\]\]>/g,"]]]]><![CDATA[>");return this.indentate(n)+`<![CDATA[${e}]]>`+this.newLine}if(!1!==this.options.commentPropName&&e===this.options.commentPropName){let e=String(t).replace(/--/g,"- -").replace(/-$/,"- ");return this.indentate(n)+`<!--${e}-->`+this.newLine}if("?"===e[0])return this.indentate(n)+"<"+e+r+"?"+this.tagEndChar;{let i=this.options.tagValueProcessor(e,t);return""===(i=this.replaceEntitiesValue(i))?this.indentate(n)+"<"+e+r+this.closeTag(e)+this.tagEndChar:this.indentate(n)+"<"+e+r+">"+i+"</"+e+this.tagEndChar}},rT.prototype.replaceEntitiesValue=function(t){if(t&&t.length>0&&this.options.processEntities)for(let e=0;e<this.options.entities.length;e++){let r=this.options.entities[e];t=t.replace(r.regex,r.val)}return t};let rL=rD(function(t,e,r){let n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{};return rj(tp(tf({url:L(t.remoteURL,O(e)),method:"UNLOCK",headers:{"Lock-Token":r}},t,n),t),function(e){if(t2(t,e),204!==e.status&&200!==e.status)throw t1(e)})}),rI=rD(function(t,e){var r;let n=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},{refreshToken:i,timeout:a=rR}=n,o={Accept:"text/plain,application/xml",Timeout:a};return i&&(o.If=i),rj(tp(tf({url:L(t.remoteURL,O(e)),method:"LOCK",headers:o,data:(r=t.contactHref,new rT({attributeNamePrefix:"@_",format:!0,ignoreAttributes:!1,suppressEmptyNode:!0}).build(function t(e,r){let n={...e};for(let e in n)n.hasOwnProperty(e)&&(n[e]&&"object"==typeof n[e]&&-1===e.indexOf(":")?(n[`${r}:${e}`]=t(n[e],r),delete n[e]):!1===/^@_/.test(e)&&(n[`${r}:${e}`]=n[e],delete n[e]));return n}({lockinfo:{"@_xmlns:d":"DAV:",lockscope:{exclusive:{}},locktype:{write:{}},owner:{href:r}}},"d")))},t,n),t),function(e){return t2(t,e),rj(e.text(),function(t){let r=new e0({removeNSPrefix:!0,parseAttributeValue:!0,parseTagValue:!0}).parse(t),n=e2().get(r,"prop.lockdiscovery.activelock.locktoken.href"),i=e2().get(r,"prop.lockdiscovery.activelock.timeout");if(!n)throw t1(e,"No lock token received: ");return{token:n,serverTimeout:i}})})}),rR="Infinite, Second-4100000000";function rM(t,e,r){return r?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let rF=(p=function(t){let e=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},r=e.path||"/";return rM(tp(tf({url:L(t.remoteURL,r),method:"PROPFIND",headers:{Accept:"text/plain,application/xml",Depth:"0"}},t,e),t),function(r){return t2(t,r),rM(r.text(),function(n){return rM(e7(n,t.parsing),function(t){return t3(r,function(t){try{let[e]=t.multistatus.response,{propstat:{prop:{"quota-used-bytes":r,"quota-available-bytes":n}}}=e;return void 0!==r&&void 0!==n?{used:parseInt(String(r),10),available:function(t){switch(String(t)){case"-3":return"unlimited";case"-2":case"-1":return"unknown";default:return parseInt(String(t),10)}}(n)}:null}catch(t){}return null}(t),e.details)})})})},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(p.apply(this,t))}catch(t){return Promise.reject(t)}});function rU(t,e,r){return r?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let rV=(f=function(t,e){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},{details:n=!1}=r;return rU(tp(tf({url:L(t.remoteURL,O(e)),method:"SEARCH",headers:{Accept:"text/plain,application/xml","Content-Type":t.headers["Content-Type"]||"application/xml; charset=utf-8"}},t,r),t),function(r){return t2(t,r),rU(r.text(),function(i){return rU(e7(i,t.parsing),function(t){let i;return t3(r,((i={truncated:!1,results:[]}).truncated=t.multistatus.response.some(t=>"507"===(t.status||t.propstat?.status).split(" ",3)?.[1]&&t.href.replace(/\/$/,"").endsWith(O(e).replace(/\/$/,""))),t.multistatus.response.forEach(t=>{if(void 0===t.propstat)return;let e=t.href.split("/").map(decodeURIComponent).join("/");i.results.push(e6(t.propstat.prop,e,n))}),i),n)})})})},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(f.apply(this,t))}catch(t){return Promise.reject(t)}}),rG=(g=function(t,e,r){var n,i;let a=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{},o=tf({url:L(t.remoteURL,O(e)),method:"MOVE",headers:{Destination:L(t.remoteURL,O(r)),Overwrite:!1===a.overwrite?"F":"T"}},t,a);return n=function(e){t2(t,e)},(i=tp(o,t))&&i.then||(i=Promise.resolve(i)),n?i.then(n):i},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(g.apply(this,t))}catch(t){return Promise.reject(t)}});var rW=E(172);let rz=(m=function(t,e,r){var n,i;let a=arguments.length>3&&void 0!==arguments[3]?arguments[3]:{},{contentLength:o=!0,overwrite:s=!0}=a,l={"Content-Type":"application/octet-stream"};!1===o||(l["Content-Length"]="number"==typeof o?`${o}`:`${function(t){if(ts(t))return t.byteLength;if(tl(t))return t.length;if("string"==typeof t)return(0,rW.d)(t);throw new S({info:{code:H.DataTypeNoLength}},"Cannot calculate data length: Invalid type")}(r)}`),s||(l["If-None-Match"]="*");let u=tf({url:L(t.remoteURL,O(e)),method:"PUT",headers:l,data:r},t,a);return i=function(e){try{t2(t,e)}catch(t){if(412!==t.status||s)throw t;return!1}return!0},(n=tp(u,t))&&n.then||(n=Promise.resolve(n)),i?n.then(i):n},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(m.apply(this,t))}catch(t){return Promise.reject(t)}}),rX=(v=function(t,e){var r,n;let i=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},a=tf({url:L(t.remoteURL,O(e)),method:"OPTIONS"},t,i);return n=function(e){try{t2(t,e)}catch(t){throw t}return{compliance:(e.headers.get("DAV")??"").split(",").map(t=>t.trim()),server:e.headers.get("Server")??""}},(r=tp(a,t))&&r.then||(r=Promise.resolve(r)),n?r.then(n):r},function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];try{return Promise.resolve(v.apply(this,t))}catch(t){return Promise.reject(t)}});function rq(t,e,r){return r?e?e(t):t:(t&&t.then||(t=Promise.resolve(t)),e?t.then(e):t)}let rH=rK(function(t,e,r,n,i){let a=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};if(r>n||r<0)throw new S({info:{code:H.InvalidUpdateRange}},`Invalid update range ${r} for partial update`);let o={"Content-Type":"application/octet-stream","Content-Length":""+(n-r+1),"Content-Range":`bytes ${r}-${n}/*`};return rq(tp(tf({url:L(t.remoteURL,O(e)),method:"PUT",headers:o,data:i},t,a),t),function(e){t2(t,e)})});function rY(t,e){var r=t();return r&&r.then?r.then(e):e(r)}let rZ=rK(function(t,e,r,n,i){let a=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};if(r>n||r<0)throw new S({info:{code:H.InvalidUpdateRange}},`Invalid update range ${r} for partial update`);let o={"Content-Type":"application/x-sabredav-partialupdate","Content-Length":""+(n-r+1),"X-Update-Range":`bytes=${r}-${n}`};return rq(tp(tf({url:L(t.remoteURL,O(e)),method:"PATCH",headers:o,data:i},t,a),t),function(e){t2(t,e)})});function rK(t){return function(){for(var e=[],r=0;r<arguments.length;r++)e[r]=arguments[r];try{return Promise.resolve(t.apply(this,e))}catch(t){return Promise.reject(t)}}}let rQ=rK(function(t,e,r,n,i){let a=arguments.length>5&&void 0!==arguments[5]?arguments[5]:{};return rq(rX(t,e,a),function(o){let s=!1;return rY(function(){if(o.compliance.includes("sabredav-partialupdate"))return rq(rZ(t,e,r,n,i,a),function(t){return s=!0,t})},function(l){let u=!1;return s?l:rY(function(){if(o.server.includes("Apache")&&o.compliance.includes("<http://apache.org/dav/propset/fs/1>"))return rq(rH(t,e,r,n,i,a),function(t){return u=!0,t})},function(t){if(u)return t;throw new S({info:{code:H.NotSupported}},"Not supported")})})})});function rJ(t){let e,r=arguments.length>1&&void 0!==arguments[1]?arguments[1]:{},{authType:n=null,remoteBasePath:i,contactHref:a="https://github.com/perry-mitchell/webdav-client/blob/master/LOCK_CONTACT.md",entityDecoder:o,ha1:s,headers:l={},httpAgent:u,httpsAgent:c,password:h,token:d,username:p,withCredentials:f}=r,g=n;g||(g=p||h?q.Password:q.None);let m={authType:g,remoteBasePath:i,contactHref:a,ha1:s,headers:Object.assign({},l),httpAgent:u,httpsAgent:c,password:h,parsing:{attributeNamePrefix:r.attributeNamePrefix??"@",attributeParsers:[],entityDecoder:o,tagParsers:[e8]},remotePath:((e=new(_())(t).pathname).length<=0&&(e="/"),D(e)),remoteURL:t,token:d,username:p,withCredentials:f};return Y(m,p,h,d,s),{copyFile:(t,e,r)=>t4(m,t,e,r),createDirectory:(t,e)=>rc(m,t,e),createReadStream:(t,e)=>(function(t,e){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},n=new(0,rd().PassThrough);return rp(t,e,r).then(t=>{t.pipe(n)}).catch(t=>{n.emit("error",t)}),n})(m,t,e),createWriteStream:(t,e,r)=>(function(t,e){let r=arguments.length>2&&void 0!==arguments[2]?arguments[2]:{},n=arguments.length>3&&void 0!==arguments[3]?arguments[3]:rf,i=new(0,rd().PassThrough),a={};return!1===r.overwrite&&(a["If-None-Match"]="*"),tp(tf({url:L(t.remoteURL,O(e)),method:"PUT",headers:a,data:i,maxRedirects:0},t,r),t).then(e=>t2(t,e)).then(t=>{setTimeout(()=>{n(t)},0)}).catch(t=>{i.emit("error",t)}),i})(m,t,e,r),customRequest:(t,e)=>rg(m,t,e),deleteFile:(t,e)=>rm(m,t,e),exists:(t,e)=>rv(m,t,e),getDirectoryContents:(t,e)=>rA(m,t,e),getFileContents:(t,e)=>rw(m,t,e),getFileDownloadLink:t=>(function(t,e){let r=L(t.remoteURL,O(e)),n=/^https:/i.test(r)?"https":"http";switch(t.authType){case q.None:break;case q.Password:{let e=G(t.headers.Authorization.replace(/^Basic /i,"").trim());r=r.replace(/^https?:\/\//,`${n}://${e}@`);break}default:throw new S({info:{code:H.LinkUnsupportedAuthType}},`Unsupported auth type for file link: ${t.authType}`)}return r})(m,t),getFileUploadLink:t=>(function(t,e){let r=`${L(t.remoteURL,O(e))}?Content-Type=application/octet-stream`,n=/^https:/i.test(r)?"https":"http";switch(t.authType){case q.None:break;case q.Password:{let e=G(t.headers.Authorization.replace(/^Basic /i,"").trim());r=r.replace(/^https?:\/\//,`${n}://${e}@`);break}default:throw new S({info:{code:H.LinkUnsupportedAuthType}},`Unsupported auth type for file link: ${t.authType}`)}return r})(m,t),getHeaders:()=>Object.assign({},m.headers),getQuota:t=>rF(m,t),lock:(t,e)=>rI(m,t,e),moveFile:(t,e,r)=>rG(m,t,e,r),putFileContents:(t,e,r)=>rz(m,t,e,r),partialUpdateFileContents:(t,e,r,n,i)=>rQ(m,t,e,r,n,i),getDAVCompliance:t=>rX(m,t),search:(t,e)=>rV(m,t,e),setHeaders:t=>{m.headers=Object.assign({},t)},stat:(t,e)=>rt(m,t,e),unlock:(t,e,r)=>rL(m,t,e,r),registerAttributeParser:t=>{m.parsing.attributeParsers.push(t)},registerTagParser:t=>{m.parsing.tagParsers.push(t)}}}r.d(e,{Gu:()=>te,UU:()=>rJ,h4:()=>e7})}}]);
//# sourceMappingURL=calendar-defaultVendors-node_modules_nextcloud_vue_dist_assets_NcDateTimePickerNative-BP6eg8aU_css-nod-ea584e.js.map?v=6863f4486040e955